#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#define DIFMAX 6
#define MAXSTATES 2364

#define STATE_SINGLE 0
#define STATE_INSIDE -1
#define NMAX 1001
#define INF 666666666

int state[MAXSTATES][DIFMAX];
int state_hash[1<<18];
char A[NMAX][NMAX];
int minp[2][MAXSTATES], minc[2][MAXSTATES];
int ss[DIFMAX + 1];
int i, j, si, sj, k, n, s, snou, N, K, X, M, c, a, vmax, vmin, nstates, fstate, lstate, extrac;

void ins_hash()
{
	int i, h, s;

	for (s = 0; s < nstates; s++)
	{
		h = 0;

		for (i = 0; i < K; i++)
			h = h * 8 + (state[s][i] + 1);

		state_hash[h] = s;
	}
}

int getStateNumber(int st[])
{
	int i, h;

	h = 0;

	for (i = 0; i < K; i++)
		h = h * 8 + (st[i] + 1);

	return state_hash[h];

	/*

	// binary search to find the desired state, in case the states are lexicographically sorted

	int li = 0, ls = NSTATES - 1, mid, i, maimic, maimare;

	while (li <= ls)
	{
		mid = (li + ls) >> 1;

		maimic = maimare = 0;

		for (i = 0; i < K; i++)
			if (st[i] < state[mid][i])
			{
				maimic = 1;
				break;
			}
			else
			if (st[i] > state[mid][i])
			{
				maimare = 1;
				break;
			}

		//fprintf(stderr, "li=%d, ls=%d, mid=%d, maimic=%d, maimare=%d\n", li, ls, mid, maimic, maimare);

		if (maimic)
			ls = mid - 1;
		else
		if (maimare)
			li = mid + 1;
		else // egal
			return mid;
	}
	*/

	return -1;
}

int used[DIFMAX + 3];

void adjustState(int st[])
{
	int i, k;

	for (i = 0; i <= K + 1; i++)
		used[i] = 0;

	//fprintf(stderr, "* before adjustment:");
	//for (i = 0; i < K; i++)
	//	fprintf(stderr, " %d", st[i]);
	//fprintf(stderr, "\n");

	k = 0;
	for (i = 0; i < K; i++)
		if (st[i] > 0)
		{
			if (used[st[i]])
				st[i] = used[st[i]];
			else
			{
				used[st[i]] = ++k;
				st[i] = k;
			}
		}

	//fprintf(stderr, "  after adjustment:");
	//for (i = 0; i < DIFMAX; i++)
	//	fprintf(stderr, " %d", st[i]);
	//fprintf(stderr, "\n");
}

void genStates(int niv)
{
	int i, maxp, allsingle, allinside;

	if (niv >= K)
	{
		allsingle = 1;
		for (i = 0; i < K; i++)
			if (ss[i] != STATE_SINGLE)
			{
				allsingle = 0;
				break;
			}

		if (allsingle)
			fstate = nstates;

		allinside = 1;
		for (i = 0; i < K; i++)
			if (ss[i] != STATE_INSIDE)
			{
				allinside = 0;
				break;
			}

		if (allinside)
			lstate = nstates;

		for (i = 0; i < K; i++)
			state[nstates][i] = ss[i];

		nstates++;
	}
	else
	{
		if (ss[niv] == 0)
		{
			ss[niv] = STATE_INSIDE;
			genStates(niv + 1);

			ss[niv] = STATE_SINGLE;
			genStates(niv + 1);

			for (i = maxp = 0; i < niv; i++)
				if (ss[i] > maxp)
					maxp = ss[i];

			maxp++;
			ss[niv] = maxp;

			genStates(niv + 1);

			for (i = niv + 1; i < K; i++)
				if (ss[i] == 0)
				{
					ss[i] = maxp;
					genStates(niv + 1);
					ss[i] = 0;
				}

			ss[niv] = 0;
		}
		else
			genStates(niv + 1);
	}
}

int minpathcover(void)
{
	int vmin, a, c;

	// dynamic programming

	a = c = 0;

	for (s = 0; s < MAXSTATES; s++)
		minp[c][s] = INF;

	minp[c][fstate] = 1;

	//fprintf(stderr, "starting: N=%d\n", N);

	for (n = 2; n <= N; n++)
	{
		a = c;
		c = 1 - c;

		for (s = 0; s < nstates; s++)
			minp[c][s] = INF;

		for (s = 0; s < nstates; s++)
			if (minp[a][s] < INF)
			{
				//printf("%d %d\n", n - 1, s);

				//fprintf(stderr, "###### n=%d, s=%d, minp[a][s]=%d\n", n - 1, s, minp[a][s]);
				//fprintf(stderr, " * %d\n", minp[a][10439]);

				// option 1: extend a path

				for (vmax = i = 0; i < K; i++)
					if (state[s][i] > vmax)
						vmax = state[s][i];

				for (i = n - 1; i >= n - K && i > 0; i--)
					if (A[n][i] && state[s][n - i - 1] != STATE_INSIDE)
					{
						if (state[s][n - i - 1] == STATE_SINGLE)
						{
							//fprintf(stderr, "# n=%d -> extend path: %d[%d]\n", n, i, state[s][n - i - 1]);

							// copy the state
							for (k = 0; k < K; k++)
								ss[k + 1] = state[s][k];

							ss[0] = vmax + 1;
							ss[n - i] = vmax + 1;

							adjustState(ss);

							snou = getStateNumber(ss);

							if (minp[a][s] < minp[c][snou])
								minp[c][snou] = minp[a][s];

							//fprintf(stderr, "[snou=%d]: ", snou);
							//for (k = 0; k < K; k++)
							//	fprintf(stderr, " %d", ss[k]);
							//fprintf(stderr, "\n");
						}
						else
						{
							//fprintf(stderr, "# n=%d -> extend path: %d[%d]\n", n, i, state[s][n - i - 1]);

							// copy the state
							for (k = 0; k < K; k++)
								ss[k + 1] = state[s][k];

							ss[0] = state[s][n - i - 1];
							ss[n - i] = STATE_INSIDE;

							adjustState(ss);

							snou = getStateNumber(ss);

							if (minp[a][s] < minp[c][snou])
								minp[c][snou] = minp[a][s];

							//fprintf(stderr, "[snou=%d]: ", snou);
							//for (k = 0; k < K; k++)
							//	fprintf(stderr, " %d", ss[k]);
							//fprintf(stderr, "\n");
						}
					}

				// option 2: connect two existing paths

				ss[0] = STATE_INSIDE;
				for (i = n - 1; i >= n - K && i > 0; i--)
					if (A[n][i] && state[s][n - i - 1] != STATE_INSIDE)
						for (j = i - 1; j >= n - K && j > 0; j--)
							if (A[n][j] && state[s][n - j - 1] != STATE_INSIDE)
							{
								if (state[s][n - i - 1] > 0 && state[s][n - i - 1] == state[s][n - j - 1])
									continue;

								//fprintf(stderr, "# n=%d -> connect two paths: %d[%d] - %d[%d]\n", n, i, state[s][n - i - 1], j, state[s][n - j - 1]);

								// copy the state
								
								for (k = 0; k < K; k++)
									ss[k + 1] = state[s][k];
					
								//memcpy(ss + 1, state[s], DIFMAX * sizeof(int));

								if (state[s][n - i - 1] == STATE_SINGLE && state[s][n - j - 1] == STATE_SINGLE)
								{
									ss[n - i] = vmax + 1;
									ss[n - j] = vmax + 1;
								}
								else
								if (state[s][n - i - 1] == STATE_SINGLE && state[s][n - j - 1] > 0)
								{
									ss[n - i] = ss[n - j];
									ss[n - j] = STATE_INSIDE;
								}
								else
								if (state[s][n - i - 1] > 0 && state[s][n - j - 1] == STATE_SINGLE)
								{
									ss[n - j] = ss[n - i];
									ss[n - i] = STATE_INSIDE;
								}
								else // state[s][n - i -1] > 0 && state[s][n - j - 1] > 0
								{
									si = state[s][n - i - 1];
									sj = state[s][n - j - 1];
									ss[n - i] = STATE_INSIDE;
									ss[n - j] = STATE_INSIDE;

									for (k = n - 1; k >= n - K && k > 0; k--)
										if (ss[n - k] == sj)
										{
											ss[n - k] = si;
											break;
										}
								}

								adjustState(ss);

								snou = getStateNumber(ss);

								if (minp[a][s] - 1 < minp[c][snou])
									minp[c][snou] = minp[a][s] - 1;

								//fprintf(stderr, "[snou=%d]: ", snou);
								//for (k = 0; k < K; k++)
								//	fprintf(stderr, " %d", ss[k]);
								//fprintf(stderr, "\n");
							}

				// option 3: add a single node

				ss[0] = STATE_SINGLE;
				for (i = 0; i < K; i++)
					ss[i + 1] = state[s][i];

				snou = getStateNumber(ss);

				if (minp[a][s] + 1 < minp[c][snou])
					minp[c][snou] = minp[a][s] + 1;

				//fprintf(stderr, "# n=%d -> single node; [snou=%d] :", n, snou);
				//for (i = 0; i < K; i++)
				//	fprintf(stderr, " %d", ss[i]);
				//fprintf(stderr, "\n");
			}
	}

	vmin = INF;

	for (s = 0; s < nstates; s++)
		if (minp[c][s] < vmin)
			vmin = minp[c][s];

	if (vmin == INF)
		vmin = -1;

	return vmin;
}

int mincyclecover(void)
{
	int vmin, a, c, fstate, extrac;

	c = a = 0;

	// dynamic programming

	for (s = 0; s < MAXSTATES; s++)
		minc[c][s] = INF;

	memset(ss, 0, sizeof(ss));
	for (i = 1; i < K; i++)
		ss[i] = STATE_INSIDE;

	ss[0] = STATE_SINGLE;

	fstate = getStateNumber(ss);
	minc[c][fstate] = 0;

	//fprintf(stderr, "starting: N=%d\n", N);

	for (n = 2; n <= N; n++)
	{
		a = c;
		c = 1 - c;

		for (s = 0; s < nstates; s++)
			minc[c][s] = INF;

		for (s = 0; s < nstates; s++)
			if (minc[a][s] < INF)
			{
				// find the largest path id

				for (vmax = i = 0; i < K; i++)
					if (state[s][i] > vmax)
						vmax = state[s][i];

				// option 1: extend a path

				for (i = n - 1; i >= n - K && i > 0; i--)
					if (A[n][i] && state[s][n - i - 1] != STATE_INSIDE)
					{
						if (state[s][n - i - 1] == STATE_SINGLE)
						{
							//fprintf(stderr, "# n=%d -> extend path: %d[%d]\n", n, i, state[s][n - i - 1]);

							// copy the state
							for (k = 0; k < K; k++)
								ss[k + 1] = state[s][k];

							ss[0] = vmax + 1;
							ss[n - i] = vmax + 1;

							adjustState(ss);

							snou = getStateNumber(ss);

							if (minc[a][s] < minc[c][snou] && ss[K] == STATE_INSIDE)
								minc[c][snou] = minc[a][s];

							//fprintf(stderr, "[snou=%d]: ", snou);
							//for (k = 0; k < K; k++)
							//	fprintf(stderr, " %d", ss[k]);
							//fprintf(stderr, "\n");
						}
						else
						{
							//fprintf(stderr, "# n=%d -> extend path: %d[%d]\n", n, i, state[s][n - i - 1]);

							// copy the state
							for (k = 0; k < K; k++)
								ss[k + 1] = state[s][k];

							ss[0] = state[s][n - i - 1];
							ss[n - i] = STATE_INSIDE;

							adjustState(ss);

							snou = getStateNumber(ss);

							if (minc[a][s] < minc[c][snou] && ss[K] == STATE_INSIDE)
								minc[c][snou] = minc[a][s];

							//fprintf(stderr, "[snou=%d]: ", snou);
							//for (k = 0; k < K; k++)
							//	fprintf(stderr, " %d", ss[k]);
							//fprintf(stderr, "\n");
						}
					}

				// option 2: connect two existing paths

				ss[0] = STATE_INSIDE;
				for (i = n - 1; i >= n - K && i > 0; i--)
					if (A[n][i] && state[s][n - i - 1] != STATE_INSIDE)
						for (j = i - 1; j >= n - K && j > 0; j--)
							if (A[n][j] && state[s][n - j - 1] != STATE_INSIDE)
							{
								extrac = 0;
								//fprintf(stderr, "# n=%d -> connect two paths: %d[%d] - %d[%d]\n", n, i, state[s][n - i - 1], j, state[s][n - j - 1]);

								// copy the state
								
								for (k = 0; k < K; k++)
									ss[k + 1] = state[s][k];
					
								//memcpy(ss + 1, state[s], DIFMAX * sizeof(int));

								if (state[s][n - i - 1] == STATE_SINGLE && state[s][n - j - 1] == STATE_SINGLE)
								{
									ss[n - i] = vmax + 1;
									ss[n - j] = vmax + 1;
								}
								else
								if (state[s][n - i - 1] == STATE_SINGLE && state[s][n - j - 1] > 0)
								{
									ss[n - i] = ss[n - j];
									ss[n - j] = STATE_INSIDE;
								}
								else
								if (state[s][n - i - 1] > 0 && state[s][n - j - 1] == STATE_SINGLE)
								{
									ss[n - j] = ss[n - i];
									ss[n - i] = STATE_INSIDE;
								}
								else
								if (state[s][n - i - 1] == state[s][n - j - 1]) // they are the ends of the same path
								{
									extrac = 1;
									ss[n - i] = STATE_INSIDE;
									ss[n - j] = STATE_INSIDE;
								}
								else // state[s][n - i -1] > 0 && state[s][n - j - 1] > 0, but they are from diferent paths
								{
									si = state[s][n - i - 1];
									sj = state[s][n - j - 1];
									ss[n - i] = STATE_INSIDE;
									ss[n - j] = STATE_INSIDE;

									for (k = n - 1; k >= n - K && k > 0; k--)
										if (ss[n - k] == sj)
										{
											ss[n - k] = si;
											break;
										}
								}

								adjustState(ss);

								snou = getStateNumber(ss);

								if (minc[a][s] + extrac < minc[c][snou] && ss[K] == STATE_INSIDE)
									minc[c][snou] = minc[a][s] + extrac;

								//fprintf(stderr, "[snou=%d]: ", snou);
								//for (k = 0; k < K; k++)
								//	fprintf(stderr, " %d", ss[k]);
								//fprintf(stderr, "\n");
							}

				// option 3: add a single node

				ss[0] = STATE_SINGLE;
				for (i = 0; i < K; i++)
					ss[i + 1] = state[s][i];

				snou = getStateNumber(ss);

				if (minc[a][s] < minc[c][snou] && ss[K] == STATE_INSIDE)
					minc[c][snou] = minc[a][s];

				//fprintf(stderr, "# n=%d -> single node; [snou=%d] :", n, snou);
				//for (i = 0; i < K; i++)
				//	fprintf(stderr, " %d", ss[i]);
				//fprintf(stderr, "\n");
			}
	}

	vmin = minc[c][lstate];

	if (vmin == INF)
		vmin = -1;

	return vmin;
}

int main()
{
	freopen("kcity.in", "r", stdin);

	scanf("%d %d %d %d", &N, &K, &X, &M);

	memset(ss, 0, sizeof(ss));
	nstates = fstate = lstate = 0;

	genStates(0);
	//fprintf(stderr, "nstates=%d\n", nstates);
	ins_hash();

	memset(A, 0, sizeof(A));

	for (k = 0; k < M; k++)
	{
		scanf("%d %d", &i, &j);
		A[i][j] = A[j][i] = 1;
	}

	freopen("kcity.out", "w", stdout);

	if (X == 1)
		printf("%d\n", minpathcover());
	else
		printf("%d\n", mincyclecover());

	return 0;
}
