// O(N * log^2(N))

#include <stdio.h>
#include <string.h>

#include <vector>
#include <algorithm>
using namespace std;

#define NMAX 131072  //262144
#define NIVMAX 17
#define INF 666666666

#define x_pt(idx, i) (pts[idx][i].first)
#define y_pt(idx , i) (pts[idx][i].second.first)
#define w_pt(idx, i) (pts[idx][i].second.second)

#define x_seg(i) (segs[i].first)
#define yjos_seg(i) (segs[i].second.first)
#define ysus_seg(i) (segs[i].second.second)

struct ORSTnode
{
	int xmin, xmax, size;
	int *y, *w, *maxwleft, *maxwright;
};

vector<pair<int, pair<int, int> > > segs;
vector<pair<int, pair<int, int> > > pts[4];
struct ORSTnode orst[4][NMAX];
int mem[4][4][NIVMAX][NMAX/2];
int i, j, k, N, xx, yyj, yys, w1, w2, w, dmax;

void buildORST(int idx, int node, int li, int ls, int niv)
{
	int i, j, k, m, lson, rson, sz;

	//fprintf(stderr, "starting idx=%d, node=%d, li=%d, ls=%d\n", idx, node, li, ls);

	if (li == ls)
	{
		orst[idx][node].size = 1;

		orst[idx][node].xmin = orst[idx][node].xmax = x_pt(idx, li);
		orst[idx][node].y = &mem[idx][0][niv][li]/*(int*) malloc(1 * sizeof(int))*/;
		orst[idx][node].w = &mem[idx][1][niv][li]/*(int*) malloc(1 * sizeof(int))*/;
		orst[idx][node].maxwleft = &mem[idx][2][niv][li]/*(int*) malloc(1 * sizeof(int))*/;
		orst[idx][node].maxwright = &mem[idx][3][niv][li]/*(int*) malloc(1 * sizeof(int))*/;

		orst[idx][node].y[0] = y_pt(idx, li);
		orst[idx][node].w[0] = orst[idx][node].maxwleft[0] = orst[idx][node].maxwright[0] = w_pt(idx, li);
	}
	else
	{
		m = (li + ls) >> 1;
		lson = node << 1;
		rson = lson + 1;

		buildORST(idx, lson, li, m, niv + 1);
		buildORST(idx, rson, m + 1, ls, niv + 1);

		// merge the results of the 2 sons into the results of the father

		orst[idx][node].size = ls - li + 1;

		orst[idx][node].y = &mem[idx][0][niv][li]/*(int*) malloc(orst[idx][node].size * sizeof(int))*/;
		orst[idx][node].w = &mem[idx][1][niv][li]/*(int*) malloc(orst[idx][node].size * sizeof(int))*/;
		orst[idx][node].maxwleft = &mem[idx][2][niv][li]/*(int*) malloc(orst[idx][node].size * sizeof(int))*/;
		orst[idx][node].maxwright = &mem[idx][3][niv][li]/*(int*) malloc(orst[idx][node].size * sizeof(int))*/;

		i = 0;
		j = 0;
		k = -1;
		sz = orst[idx][node].size >> 1;

		while (i < sz && j < sz)
		{
			if (orst[idx][lson].y[i] <= orst[idx][rson].y[j])
			{
				k++;
				orst[idx][node].y[k] = orst[idx][lson].y[i];
				orst[idx][node].w[k] = orst[idx][lson].w[i];
				i++;
			}
			else
			{
				k++;
				orst[idx][node].y[k] = orst[idx][rson].y[j];
				orst[idx][node].w[k] = orst[idx][rson].w[j];
				j++;
			}
		}

		if (i < sz)
		{
			for (j = i; j < sz; j++)
			{
				k++;
				orst[idx][node].y[k] = orst[idx][lson].y[j];
				orst[idx][node].w[k] = orst[idx][lson].w[j];
			}
		}
		else
		{
			for (i = j; i < sz; i++)
			{
				k++;
				orst[idx][node].y[k] = orst[idx][rson].y[i];
				orst[idx][node].w[k] = orst[idx][rson].w[i];
			}
		}

		// compute xmin and xmax

		orst[idx][node].xmin = orst[idx][lson].xmin;
		orst[idx][node].xmax = orst[idx][rson].xmax;
		
		// compute maxwleft and maxwright

		sz = orst[idx][node].size;

		orst[idx][node].maxwleft[0] = orst[idx][node].w[0];

		for (i = 1; i < sz; i++)
			if (orst[idx][node].w[i] > orst[idx][node].maxwleft[i - 1])
				orst[idx][node].maxwleft[i] = orst[idx][node].w[i];
			else
				orst[idx][node].maxwleft[i] = orst[idx][node].maxwleft[i - 1];

		orst[idx][node].maxwright[sz - 1] = orst[idx][node].w[sz - 1];

		for (i = sz - 2; i >= 0; i--)
			if (orst[idx][node].w[i] > orst[idx][node].maxwright[i + 1])
				orst[idx][node].maxwright[i] = orst[idx][node].w[i];
			else
				orst[idx][node].maxwright[i] = orst[idx][node].maxwright[i + 1];
	}

	//fprintf(stderr, "done idx=%d, node=%d, li=%d, ls=%d\n", idx, node, li, ls);
}

int query(int idx, int node, int xmin, int xmax, int ymin, int ymax)
{
	int lson, rson, wl, wr, li, ls, mid, pok;

	//fprintf(stderr, "%d,%d\n", idx, node);

	if (xmin <= orst[idx][node].xmin && orst[idx][node].xmax <= xmax)
	{
		if (ymin <= orst[idx][node].y[0])
		{
			li = 0; ls = orst[idx][node].size - 1; pok = -1;

			while (li <= ls)
			{
				mid = (li + ls) >> 1;

				if (orst[idx][node].y[mid] <= ymax)
					pok = mid,
					li = mid + 1;
				else
					ls = mid - 1;
			}

			if (pok >= 0)
				return orst[idx][node].maxwleft[pok];
			else
				return - 3 * INF;
		}
		else // ymax >= orst[idx][node].y[orst[idx][node].size - 1]
		{
			li = 0; ls = orst[idx][node].size - 1; pok = orst[idx][node].size;

			while (li <= ls)
			{
				mid = (li + ls) >> 1;

				if (orst[idx][node].y[mid] >= ymin)
					pok = mid,
					ls = mid - 1;
				else
					li = mid + 1;
			}

			if (pok < orst[idx][node].size)
				return orst[idx][node].maxwright[pok];
			else
				return - 3 * INF;
		}
	}
	else
	{
		lson = node << 1;
		rson = lson + 1;

		if (orst[idx][lson].xmax < xmin || orst[idx][lson].xmin > xmax)
			wl = - 3 * INF;
		else
			wl = query(idx, lson, xmin, xmax, ymin, ymax);

		if (orst[idx][rson].xmax < xmin || orst[idx][rson].xmin > xmax)
			wr = - 3 * INF;
		else
			wr = query(idx, rson, xmin, xmax, ymin, ymax);

		if (wl > wr)
			return wl;
		else
			return wr;
	}
}

int main()
{
	freopen("h.in", "r", stdin);
	scanf("%d", &N);

	segs.clear();

	for (i = 1; i <= N; i++)
	{
		scanf("%d %d %d", &xx, &yyj, &yys);

		segs.push_back(make_pair(xx, make_pair(yyj, yys)));

		w = -xx + 2 * yys;
		pts[0].push_back(make_pair(yys, make_pair(yyj, w))); // pts[0] is "special" (yyj and yys are switched)

		w = -xx;
		pts[1].push_back(make_pair(yyj, make_pair(yys, w)));

		w = -xx + 2 * (yys - yyj);
		pts[2].push_back(make_pair(yyj, make_pair(yys, w)));

		w = -xx - 2 * yyj;
		pts[3].push_back(make_pair(yyj, make_pair(yys, w)));
	}

	for (k = 0; k < 4; k++)
	{
		while (pts[k].size() < NMAX/2)
			pts[k].push_back(make_pair(0, make_pair(0, -INF)));

		//fprintf(stderr, "k=%d -> size=%d\n", k, pts[k].size());

		sort(pts[k].begin(), pts[k].end());
		
		//fprintf(stderr, "starting %d\n", k);
		buildORST(k, 1, 0, pts[k].size() - 1, 0);
		//fprintf(stderr, "done %d\n", k);

		//fprintf(stderr, "%d: %d - %d\n", k, orst[k][1].xmin, orst[k][1].xmax);
	}

	sort(segs.begin(), segs.end());

	dmax = -1;

	for (i = 0; i < N; i++)
	{
		xx = x_seg(i);
		yyj = yjos_seg(i);
		yys = ysus_seg(i);

		//fprintf(stderr, "seg %d: x=%d, yjos=%d, ysus=%d\n", i, xx, yyj, yys);

		// choice #0 : yjos(seg2) <= yyj and ysus(seg2) <= yys

		//w = query(0, 1, yyj, yys, -INF, yyj);
		w1 = query(0, 1, yys, yys, -INF, yyj - 1);
		w2 = query(0, 1, yyj, yys - 1, -INF, yyj);

		if (w1 > w2)
			w = w1;
		else
			w = w2;

		//fprintf(stderr, "(%d,%d): w=%d\n", i, 0, w);
		w = w + xx - 2 * yyj;
		//fprintf(stderr, "(%d,%d): wupd=%d\n", i, 0, w);

		if (w > dmax)
			dmax = w;

		// choice #1 : yjos(seg2) <= yyj and ysus(seg2) >= yys

		//w = query(1, 1, -INF, yyj, yys, INF);
		w1 = query(1, 1, -INF, yyj - 1, yys, INF);
		w2 = query(1, 1, yyj, yyj, yys + 1, INF);

		if (w1 > w2)
			w = w1;
		else
			w = w2;

		//fprintf(stderr, "(%d,%d): w=%d\n", i, 1, w);
		w = w + xx + 2 * (yys - yyj);
		//fprintf(stderr, "(%d,%d): wupd=%d\n", i, 1, w);

		if (w > dmax)
			dmax = w;

		// choice #2 : yjos(seg2) >= yyj and ysus(seg2) <= yys

		//w = query(2, 1, yyj, INF, -INF, yys);
		w1 = query(2, 1, yyj, yyj, -INF, yys - 1);
		w2 = query(2, 1, yyj + 1, INF, -INF, yys);
	
		if (w1 > w2)
			w = w1;
		else
			w = w2;

		//fprintf(stderr, "(%d,%d): w=%d\n", i, 2, w);
		w = w + xx;
		//fprintf(stderr, "(%d,%d): wupd=%d\n", i, 2, w);

		if (w > dmax)
			dmax = w;

		// choice #3 : yjos(seg2) >= yyj and ysus(seg2) >= yys

		//w = query(3, 1, yyj, yys, yys, INF);
		w1 = query(3, 1, yyj, yyj, yys + 1, INF);
		w2 = query(3, 1, yyj + 1, yys, yys, INF);

		if (w1 > w2)
			w = w1;
		else
			w = w2;

		//fprintf(stderr, "(%d,%d): w=%d\n", i, 3, w);
		w = w + xx + 2 * yys;
		//fprintf(stderr, "(%d,%d): wupd=%d\n", i, 3, w);

		if (w > dmax)
			dmax = w;

		//fprintf(stderr, "%d/%d -> %d\n", i + 1, N, dmax);
	}

	freopen("h.out", "w", stdout);
	printf("%d\n", dmax);

	return 0;
}
