// O(N * log(N))

#include <stdio.h>
#include <string.h>

#include <vector>
#include <algorithm>
using namespace std;

#define NMAX 131072 //262144
#define INF 666666666

#define x_pt(idx, i) (pts[idx][i].first)
#define y_pt(idx , i) (pts[idx][i].second.first)
#define w_pt(idx, i) (pts[idx][i].second.second)

#define x_seg(i) (segs[i].first)
#define yjos_seg(i) (segs[i].second.first)
#define ysus_seg(i) (segs[i].second.second)

struct ORSTnode
{
	int xmin, xmax, size;
	int *y, *w, *maxwleft, *maxwright, *polsonge, *polsonle, *porsonge, *porsonle;
};

vector<pair<int, pair<int, int> > > segs;
vector<pair<int, pair<int, int> > > pts[4];
int tip[NMAX], poz[NMAX], lastpoz[2];
struct ORSTnode orst[4][NMAX];
int i, j, k, N, xx, yyj, yys, w1, w2, w, dmax;

void buildORST(int idx, int node, int li, int ls)
{
	int i, j, k, m, lson, rson, sz;

	//fprintf(stderr, "starting idx=%d, node=%d, li=%d, ls=%d\n", idx, node, li, ls);

	if (li == ls)
	{
		orst[idx][node].size = 1;

		orst[idx][node].xmin = orst[idx][node].xmax = x_pt(idx, li);
		orst[idx][node].y = (int*) malloc(1 * sizeof(int));
		orst[idx][node].w = (int*) malloc(1 * sizeof(int));
		orst[idx][node].porsonge = (int*) malloc(1 * sizeof(int));
		orst[idx][node].polsonge = (int*) malloc(1 * sizeof(int));
		orst[idx][node].porsonle = (int*) malloc(1 * sizeof(int));
		orst[idx][node].polsonle = (int*) malloc(1 * sizeof(int));
		orst[idx][node].maxwleft = (int*) malloc(1 * sizeof(int));
		orst[idx][node].maxwright = (int*) malloc(1 * sizeof(int));

		orst[idx][node].y[0] = y_pt(idx, li);
		orst[idx][node].w[0] = orst[idx][node].maxwleft[0] = orst[idx][node].maxwright[0] = w_pt(idx, li);
		orst[idx][node].polsonle[0] = orst[idx][node].polsonge[0] = orst[idx][node].porsonle[0] = orst[idx][node].porsonge[0] = -1;
	}
	else
	{
		m = (li + ls) >> 1;
		lson = node << 1;
		rson = lson + 1;

		buildORST(idx, lson, li, m);
		buildORST(idx, rson, m + 1, ls);

		// merge the results of the 2 sons into the results of the father

		orst[idx][node].size = ls - li + 1;

		orst[idx][node].y = (int*) malloc(orst[idx][node].size * sizeof(int));
		orst[idx][node].w = (int*) malloc(orst[idx][node].size * sizeof(int));
		orst[idx][node].maxwleft = (int*) malloc(orst[idx][node].size * sizeof(int));
		orst[idx][node].maxwright = (int*) malloc(orst[idx][node].size * sizeof(int));
		orst[idx][node].polsonle = (int*) malloc(orst[idx][node].size * sizeof(int));
		orst[idx][node].polsonge = (int*) malloc(orst[idx][node].size * sizeof(int));
		orst[idx][node].porsonle = (int*) malloc(orst[idx][node].size * sizeof(int));
		orst[idx][node].porsonge = (int*) malloc(orst[idx][node].size * sizeof(int));

		i = 0;
		j = 0;
		k = -1;
		sz = orst[idx][node].size >> 1;

		while (i < sz && j < sz)
		{
			if (orst[idx][lson].y[i] <= orst[idx][rson].y[j])
			{
				k++;
				orst[idx][node].y[k] = orst[idx][lson].y[i];
				orst[idx][node].w[k] = orst[idx][lson].w[i];
				tip[k] = 0;
				poz[k] = i;
				i++;
			}
			else
			{
				k++;
				orst[idx][node].y[k] = orst[idx][rson].y[j];
				orst[idx][node].w[k] = orst[idx][rson].w[j];
				tip[k] = 1;
				poz[k] = j;
				j++;
			}
		}

		if (i < sz)
		{
			for (j = i; j < sz; j++)
			{
				k++;
				orst[idx][node].y[k] = orst[idx][lson].y[j];
				orst[idx][node].w[k] = orst[idx][lson].w[j];
				tip[k] = 0;
				poz[k] = j;
			}
		}
		else
		{
			for (i = j; i < sz; i++)
			{
				k++;
				orst[idx][node].y[k] = orst[idx][rson].y[i];
				orst[idx][node].w[k] = orst[idx][rson].w[i];
				tip[k] = 1;
				poz[k] = i;
			}
		}

		// compute xmin and xmax

		orst[idx][node].xmin = orst[idx][lson].xmin;
		orst[idx][node].xmax = orst[idx][rson].xmax;
		
		// compute maxwleft and maxwright

		sz = orst[idx][node].size;

		orst[idx][node].maxwleft[0] = orst[idx][node].w[0];

		for (i = 1; i < sz; i++)
			if (orst[idx][node].w[i] > orst[idx][node].maxwleft[i - 1])
				orst[idx][node].maxwleft[i] = orst[idx][node].w[i];
			else
				orst[idx][node].maxwleft[i] = orst[idx][node].maxwleft[i - 1];

		orst[idx][node].maxwright[sz - 1] = orst[idx][node].w[sz - 1];

		for (i = sz - 2; i >= 0; i--)
			if (orst[idx][node].w[i] > orst[idx][node].maxwright[i + 1])
				orst[idx][node].maxwright[i] = orst[idx][node].w[i];
			else
				orst[idx][node].maxwright[i] = orst[idx][node].maxwright[i + 1];

		// compute pointers to lson and rson (greater than or equal / less than or equal)

		lastpoz[0] = lastpoz[1] = -1;

		for (i = 0; i < sz; i++)
		{
			lastpoz[tip[i]] = poz[i];
			orst[idx][node].polsonle[i] = lastpoz[0];
			orst[idx][node].porsonle[i] = lastpoz[1];
		}

		lastpoz[0] = lastpoz[1] = NMAX;

		for (i = sz - 1; i >= 0; i--)
		{
			lastpoz[tip[i]] = poz[i];
			orst[idx][node].polsonge[i] = lastpoz[0];
			orst[idx][node].porsonge[i] = lastpoz[1];
		}

	}

	//fprintf(stderr, "done idx=%d, node=%d, li=%d, ls=%d\n", idx, node, li, ls);
}

int query2(int idx, int node, int xmin, int xmax, int pymin, int pymax)
{
	int lson, rson, wl, wr;

	if ((pymax < 0) || (pymin >= orst[idx][node].size) || (pymin > pymax))
		return -3 * INF;

	if (xmin <= orst[idx][node].xmin && orst[idx][node].xmax <= xmax)
	{
		if (pymin == 0)
			return orst[idx][node].maxwleft[pymax];
		else
		//if (pymax == orst[idx][node].size - 1)
			return orst[idx][node].maxwright[pymin];

		//fprintf(stderr, "?\n");
	}
	else
	{
		lson = node << 1;
		rson = lson + 1;

		if (orst[idx][lson].xmax < xmin || orst[idx][lson].xmin > xmax)
			wl = - 3 * INF;
		else
			wl = query2(idx, lson, xmin, xmax, orst[idx][node].polsonge[pymin], orst[idx][node].polsonle[pymax]);

		if (orst[idx][rson].xmax < xmin || orst[idx][rson].xmin > xmax)
			wr = - 3 * INF;
		else
			wr = query2(idx, rson, xmin, xmax, orst[idx][node].porsonge[pymin], orst[idx][node].porsonle[pymax]);

		if (wl > wr)
			return wl;
		else
			return wr;
	}
}

inline int query(int idx, int node, int xmin, int xmax, int ymin, int ymax)
{
	int li, ls, mid, pymin, pymax;

	if (ymax < orst[idx][node].y[0])
		return -3 * INF;

	if (ymin > orst[idx][node].y[orst[idx][node].size - 1])
		return -3 * INF;

	// find the index for ymin (the first position whose y cordinate is >= ymin)

	li = 0; ls = orst[idx][node].size - 1; pymin = NMAX;

	while (li <= ls)
	{
		mid = (li + ls) >> 1;

		if (orst[idx][node].y[mid] >= ymin)
			pymin = mid,
			ls = mid - 1;
		else
			li = mid + 1;
	}

	// find the index for ymax (the last position whose y cordinate is <= ymax)

	li = 0; ls = orst[idx][node].size - 1; pymax = -1;

	while (li <= ls)
	{
		mid = (li + ls) >> 1;

		if (orst[idx][node].y[mid] <= ymax)
			pymax = mid,
			li = mid + 1;
		else
			ls = mid - 1;
	}

	return query2(idx, node, xmin, xmax, pymin, pymax);
}

int main()
{
	freopen("h.in", "r", stdin);
	scanf("%d", &N);

	segs.clear();

	for (i = 1; i <= N; i++)
	{
		scanf("%d %d %d", &xx, &yyj, &yys);

		segs.push_back(make_pair(xx, make_pair(yyj, yys)));

		w = -xx + 2 * yys;
		pts[0].push_back(make_pair(yys, make_pair(yyj, w))); // pts[0] is "special" (yyj and yys are switched)

		w = -xx;
		pts[1].push_back(make_pair(yyj, make_pair(yys, w)));

		w = -xx + 2 * (yys - yyj);
		pts[2].push_back(make_pair(yyj, make_pair(yys, w)));

		w = -xx - 2 * yyj;
		pts[3].push_back(make_pair(yyj, make_pair(yys, w)));
	}

	for (k = 0; k < 4; k++)
	{
		while (pts[k].size() < NMAX/2)
			pts[k].push_back(make_pair(0, make_pair(0, -3 * INF)));

		//fprintf(stderr, "k=%d -> size=%d\n", k, pts[k].size());

		sort(pts[k].begin(), pts[k].end());
		
		//fprintf(stderr, "starting %d\n", k);
		buildORST(k, 1, 0, pts[k].size() - 1);
		//fprintf(stderr, "done %d\n", k);

		//fprintf(stderr, "%d: %d - %d\n", k, orst[k][1].xmin, orst[k][1].xmax);
	}

	sort(segs.begin(), segs.end());

	dmax = -1;

	for (i = 0; i < N; i++)
	{
		xx = x_seg(i);
		yyj = yjos_seg(i);
		yys = ysus_seg(i);

		//fprintf(stderr, "seg %d: x=%d, yjos=%d, ysus=%d\n", i, xx, yyj, yys);

		// choice #0 : yjos(seg2) <= yyj and ysus(seg2) <= yys

		//w = query(0, 1, yyj, yys, -INF, yyj);
		w1 = query(0, 1, yys, yys, -INF, yyj - 1);
		w2 = query(0, 1, yyj, yys - 1, -INF, yyj);

		if (w1 > w2)
			w = w1;
		else
			w = w2;

		//fprintf(stderr, "(%d,%d): w=%d\n", i, 0, w);
		w = w + xx - 2 * yyj;
		//fprintf(stderr, "(%d,%d): wupd=%d\n", i, 0, w);

		if (w > dmax)
			dmax = w;

		// choice #1 : yjos(seg2) <= yyj and ysus(seg2) >= yys

		//w = query(1, 1, -INF, yyj, yys, INF);
		w1 = query(1, 1, -INF, yyj - 1, yys, INF);
		w2 = query(1, 1, yyj, yyj, yys + 1, INF);

		if (w1 > w2)
			w = w1;
		else
			w = w2;

		//fprintf(stderr, "(%d,%d): w=%d\n", i, 1, w);
		w = w + xx + 2 * (yys - yyj);
		//fprintf(stderr, "(%d,%d): wupd=%d\n", i, 1, w);

		if (w > dmax)
			dmax = w;

		// choice #2 : yjos(seg2) >= yyj and ysus(seg2) <= yys

		//w = query(2, 1, yyj, INF, -INF, yys);
		w1 = query(2, 1, yyj, yyj, -INF, yys - 1);
		w2 = query(2, 1, yyj + 1, INF, -INF, yys);
	
		if (w1 > w2)
			w = w1;
		else
			w = w2;

		//fprintf(stderr, "(%d,%d): w=%d\n", i, 2, w);
		w = w + xx;
		//fprintf(stderr, "(%d,%d): wupd=%d\n", i, 2, w);

		if (w > dmax)
			dmax = w;

		// choice #3 : yjos(seg2) >= yyj and ysus(seg2) >= yys

		//w = query(3, 1, yyj, yys, yys, INF);
		w1 = query(3, 1, yyj, yyj, yys + 1, INF);
		w2 = query(3, 1, yyj + 1, yys, yys, INF);

		if (w1 > w2)
			w = w1;
		else
			w = w2;

		//fprintf(stderr, "(%d,%d): w=%d\n", i, 3, w);
		w = w + xx + 2 * yys;
		//fprintf(stderr, "(%d,%d): wupd=%d\n", i, 3, w);

		if (w > dmax)
			dmax = w;

		//fprintf(stderr, "%d/%d -> %d\n", i + 1, N, dmax);
	}

	freopen("h.out", "w", stdout);
	printf("%d\n", dmax);

	return 0;
}
