// O(N * log(N))

#include <stdio.h>
#include <string.h>

#include <vector>
#include <algorithm>
using namespace std;

#define NMAX 131072 //262144
#define INF 666666666
#define IDX_START 0

#define x_pt(idx, i) (pts[i].first)
#define y_pt(idx , i) (pts[i].second.first)
#define w_pt(idx, i) (pts[i].second.second)

#define x_seg(i) (segs[i].first)
#define yjos_seg(i) (segs[i].second.first)
#define ysus_seg(i) (segs[i].second.second)

struct ORSTnode
{
	int xmin, xmax, size;
	int *y, *w, *maxwleft, *maxwright, *polsonge, *polsonle, *porsonge, *porsonle;
};

vector<pair<int, pair<int, int> > > segs;
vector<pair<int, pair<int, int> > > pts;
int tip[NMAX], poz[NMAX], lastpoz[2];
struct ORSTnode orst[NMAX];
int i, j, k, N, xx, yyj, yys, w1, w2, w, dmax;

void buildORST(int idx, int node, int li, int ls)
{
	int i, j, k, m, lson, rson, sz;

	//fprintf(stderr, "starting idx=%d, node=%d, li=%d, ls=%d\n", idx, node, li, ls);

	if (li == ls)
	{
		orst[node].size = 1;

		orst[node].xmin = orst[node].xmax = x_pt(idx, li);

		if (idx == IDX_START)
		{
			orst[node].y = (int*) malloc(1 * sizeof(int));
			orst[node].w = (int*) malloc(1 * sizeof(int));
			orst[node].porsonge = (int*) malloc(1 * sizeof(int));
			orst[node].polsonge = (int*) malloc(1 * sizeof(int));
			orst[node].porsonle = (int*) malloc(1 * sizeof(int));
			orst[node].polsonle = (int*) malloc(1 * sizeof(int));
			orst[node].maxwleft = (int*) malloc(1 * sizeof(int));
			orst[node].maxwright = (int*) malloc(1 * sizeof(int));
		}

		orst[node].y[0] = y_pt(idx, li);
		orst[node].w[0] = orst[node].maxwleft[0] = orst[node].maxwright[0] = w_pt(idx, li);
		orst[node].polsonle[0] = orst[node].polsonge[0] = orst[node].porsonle[0] = orst[node].porsonge[0] = -1;
	}
	else
	{
		m = (li + ls) >> 1;
		lson = node << 1;
		rson = lson + 1;

		buildORST(idx, lson, li, m);
		buildORST(idx, rson, m + 1, ls);

		// merge the results of the 2 sons into the results of the father

		orst[node].size = ls - li + 1;

		if (idx == IDX_START)
		{
			orst[node].y = (int*) malloc(orst[node].size * sizeof(int));
			orst[node].w = (int*) malloc(orst[node].size * sizeof(int));
			orst[node].maxwleft = (int*) malloc(orst[node].size * sizeof(int));
			orst[node].maxwright = (int*) malloc(orst[node].size * sizeof(int));
			orst[node].polsonle = (int*) malloc(orst[node].size * sizeof(int));
			orst[node].polsonge = (int*) malloc(orst[node].size * sizeof(int));
			orst[node].porsonle = (int*) malloc(orst[node].size * sizeof(int));
			orst[node].porsonge = (int*) malloc(orst[node].size * sizeof(int));
		}

		i = 0;
		j = 0;
		k = -1;
		sz = orst[node].size >> 1;

		while (i < sz && j < sz)
		{
			if (orst[lson].y[i] <= orst[rson].y[j])
			{
				k++;
				orst[node].y[k] = orst[lson].y[i];
				orst[node].w[k] = orst[lson].w[i];
				tip[k] = 0;
				poz[k] = i;
				i++;
			}
			else
			{
				k++;
				orst[node].y[k] = orst[rson].y[j];
				orst[node].w[k] = orst[rson].w[j];
				tip[k] = 1;
				poz[k] = j;
				j++;
			}
		}

		if (i < sz)
		{
			for (j = i; j < sz; j++)
			{
				k++;
				orst[node].y[k] = orst[lson].y[j];
				orst[node].w[k] = orst[lson].w[j];
				tip[k] = 0;
				poz[k] = j;
			}
		}
		else
		{
			for (i = j; i < sz; i++)
			{
				k++;
				orst[node].y[k] = orst[rson].y[i];
				orst[node].w[k] = orst[rson].w[i];
				tip[k] = 1;
				poz[k] = i;
			}
		}

		// compute xmin and xmax

		orst[node].xmin = orst[lson].xmin;
		orst[node].xmax = orst[rson].xmax;
		
		// compute maxwleft and maxwright

		sz = orst[node].size;

		orst[node].maxwleft[0] = orst[node].w[0];

		for (i = 1; i < sz; i++)
			if (orst[node].w[i] > orst[node].maxwleft[i - 1])
				orst[node].maxwleft[i] = orst[node].w[i];
			else
				orst[node].maxwleft[i] = orst[node].maxwleft[i - 1];

		orst[node].maxwright[sz - 1] = orst[node].w[sz - 1];

		for (i = sz - 2; i >= 0; i--)
			if (orst[node].w[i] > orst[node].maxwright[i + 1])
				orst[node].maxwright[i] = orst[node].w[i];
			else
				orst[node].maxwright[i] = orst[node].maxwright[i + 1];

		// compute pointers to lson and rson (greater than or equal / less than or equal)

		lastpoz[0] = lastpoz[1] = -1;

		for (i = 0; i < sz; i++)
		{
			lastpoz[tip[i]] = poz[i];
			orst[node].polsonle[i] = lastpoz[0];
			orst[node].porsonle[i] = lastpoz[1];
		}

		lastpoz[0] = lastpoz[1] = NMAX;

		for (i = sz - 1; i >= 0; i--)
		{
			lastpoz[tip[i]] = poz[i];
			orst[node].polsonge[i] = lastpoz[0];
			orst[node].porsonge[i] = lastpoz[1];
		}

	}

	//fprintf(stderr, "done idx=%d, node=%d, li=%d, ls=%d\n", idx, node, li, ls);
}

int query2(int idx, int node, int xmin, int xmax, int pymin, int pymax)
{
	int lson, rson, wl, wr;

	if ((pymax < 0) || (pymin >= orst[node].size) || (pymin > pymax))
		return -3 * INF;

	if (xmin <= orst[node].xmin && orst[node].xmax <= xmax)
	{
		if (pymin == 0)
			return orst[node].maxwleft[pymax];
		else
		//if (pymax == orst[node].size - 1)
			return orst[node].maxwright[pymin];

		//fprintf(stderr, "?\n");
	}
	else
	{
		lson = node << 1;
		rson = lson + 1;

		if (orst[lson].xmax < xmin || orst[lson].xmin > xmax)
			wl = - 3 * INF;
		else
			wl = query2(idx, lson, xmin, xmax, orst[node].polsonge[pymin], orst[node].polsonle[pymax]);

		if (orst[rson].xmax < xmin || orst[rson].xmin > xmax)
			wr = - 3 * INF;
		else
			wr = query2(idx, rson, xmin, xmax, orst[node].porsonge[pymin], orst[node].porsonle[pymax]);

		if (wl > wr)
			return wl;
		else
			return wr;
	}
}

inline int query(int idx, int node, int xmin, int xmax, int ymin, int ymax)
{
	int li, ls, mid, pymin, pymax;

	if (ymax < orst[node].y[0])
		return -3 * INF;

	if (ymin > orst[node].y[orst[node].size - 1])
		return -3 * INF;

	// find the index for ymin (the first position whose y cordinate is >= ymin)

	li = 0; ls = orst[node].size - 1; pymin = NMAX;

	while (li <= ls)
	{
		mid = (li + ls) >> 1;

		if (orst[node].y[mid] >= ymin)
			pymin = mid,
			ls = mid - 1;
		else
			li = mid + 1;
	}

	// find the index for ymax (the last position whose y cordinate is <= ymax)

	li = 0; ls = orst[node].size - 1; pymax = -1;

	while (li <= ls)
	{
		mid = (li + ls) >> 1;

		if (orst[node].y[mid] <= ymax)
			pymax = mid,
			li = mid + 1;
		else
			ls = mid - 1;
	}

	return query2(idx, node, xmin, xmax, pymin, pymax);
}

int main()
{
	freopen("h.in", "r", stdin);
	scanf("%d", &N);

	segs.clear();

	for (i = 1; i <= N; i++)
	{
		scanf("%d %d %d", &xx, &yyj, &yys);

		segs.push_back(make_pair(xx, make_pair(yyj, yys)));
	}

	sort(segs.begin(), segs.end());

	dmax = -1;

	for (k = IDX_START; k < 4; k++)
	{
		pts.clear();

		for (i = 0; i < N; i++)
		{
			xx = x_seg(i);
			yyj = yjos_seg(i);
			yys = ysus_seg(i);

			if (k == 0)
			{
				w = -xx + 2 * yys;
				pts.push_back(make_pair(yys, make_pair(yyj, w))); // pts[0] is "special" (yyj and yys are switched)
			}
			else
			if (k == 1)
			{
				w = -xx;
				pts.push_back(make_pair(yyj, make_pair(yys, w)));
			}
			else
			if (k == 2)
			{
				w = -xx + 2 * (yys - yyj);
				pts.push_back(make_pair(yyj, make_pair(yys, w)));
			}
			else
			if (k == 3)
			{
				w = -xx - 2 * yyj;
				pts.push_back(make_pair(yyj, make_pair(yys, w)));
			}
		}

		while (pts.size() < NMAX/2)
			pts.push_back(make_pair(0, make_pair(0, -3 * INF)));


		//fprintf(stderr, "k=%d -> size=%d\n", k, pts.size());

		sort(pts.begin(), pts.end());
		
		//fprintf(stderr, "starting %d\n", k);
		buildORST(k, 1, 0, pts.size() - 1);
		//fprintf(stderr, "done %d\n", k);

		//fprintf(stderr, "%d: %d - %d\n", k, orst[1].xmin, orst[1].xmax);

		// query phase
		for (i = 0; i < N; i++)
		{
			xx = x_seg(i);
			yyj = yjos_seg(i);
			yys = ysus_seg(i);

			//fprintf(stderr, "seg %d: x=%d, yjos=%d, ysus=%d\n", i, xx, yyj, yys);

			if (k == 0)
			{
				// choice #0 : yjos(seg2) <= yyj and ysus(seg2) <= yys

				//w = query(0, 1, yyj, yys, -INF, yyj);
				w1 = query(0, 1, yys, yys, -INF, yyj - 1);
				w2 = query(0, 1, yyj, yys - 1, -INF, yyj);

				if (w1 > w2)
					w = w1;
				else
					w = w2;

				//fprintf(stderr, "(%d,%d): w=%d\n", i, 0, w);
				w = w + xx - 2 * yyj;
				//fprintf(stderr, "(%d,%d): wupd=%d\n", i, 0, w);

				if (w > dmax)
					dmax = w;
			}
			else
			if (k == 1)
			{
				// choice #1 : yjos(seg2) <= yyj and ysus(seg2) >= yys

				//w = query(1, 1, -INF, yyj, yys, INF);
				w1 = query(1, 1, -INF, yyj - 1, yys, INF);
				w2 = query(1, 1, yyj, yyj, yys + 1, INF);

				if (w1 > w2)
					w = w1;
				else
					w = w2;

				//fprintf(stderr, "(%d,%d): w=%d\n", i, 1, w);
				w = w + xx + 2 * (yys - yyj);
				//fprintf(stderr, "(%d,%d): wupd=%d\n", i, 1, w);

				if (w > dmax)
					dmax = w;
			}
			else
			if (k == 2)
			{
				// choice #2 : yjos(seg2) >= yyj and ysus(seg2) <= yys

				//w = query(2, 1, yyj, INF, -INF, yys);
				w1 = query(2, 1, yyj, yyj, -INF, yys - 1);
				w2 = query(2, 1, yyj + 1, INF, -INF, yys);
	
				if (w1 > w2)
					w = w1;
				else
					w = w2;

				//fprintf(stderr, "(%d,%d): w=%d\n", i, 2, w);
				w = w + xx;
				//fprintf(stderr, "(%d,%d): wupd=%d\n", i, 2, w);

				if (w > dmax)
					dmax = w;
			}
			else
			if (k == 3)
			{
				// choice #3 : yjos(seg2) >= yyj and ysus(seg2) >= yys

				//w = query(3, 1, yyj, yys, yys, INF);
				w1 = query(3, 1, yyj, yyj, yys + 1, INF);
				w2 = query(3, 1, yyj + 1, yys, yys, INF);

				if (w1 > w2)
					w = w1;
				else
					w = w2;

				//fprintf(stderr, "(%d,%d): w=%d\n", i, 3, w);
				w = w + xx + 2 * yys;
				//fprintf(stderr, "(%d,%d): wupd=%d\n", i, 3, w);

				if (w > dmax)
					dmax = w;

				//fprintf(stderr, "%d/%d -> %d\n", i + 1, N, dmax);
			}
		}
	}

	freopen("h.out", "w", stdout);
	printf("%d\n", dmax);

	return 0;
}
