// O(N^2 * logN) - Dijkstra cu heap-uri in graful celor O(N^2) puncte de intersectie
// fiecare punct de intersectie a 2 drepte are maxim 4 vecini in graful acesta

#include <stdio.h>
#include <math.h>
#include <stdlib.h>
#include <time.h>

#include <vector>
#include <algorithm>
#include <set>
using namespace std;

#define NMAX 1011
#define eps 1e-6
#define epsinf 1e-2
#define INF 1e8
#define USE_DIJKSTRA 0

double xa[NMAX], ya[NMAX], xb[NMAX], yb[NMAX];
vector<pair<double, pair<double, int> > > pid[NMAX];
set<pair<int, pair<int, int> > > idset;
set<pair<int, pair<int, int> > >::iterator it;
set<pair<double, int> > heap;
set<pair<double, int> >::iterator heapit;
pair<double, int> helem;
int v[NMAX*NMAX/2][4], nv[NMAX*NMAX/2], t[NMAX*NMAX/2];
double xp[NMAX*NMAX/2], yp[NMAX*NMAX/2], l[NMAX*NMAX/2][4], dmin[NMAX*NMAX/2];
int i, j, k, N, id, current, before, after, ls1, ls2, lf1, lf2, ids, idf, cntmisses, ntries, cntedges;

int semn(double a, double b, double c, double x, double y)
{
	double r = a * x + b * y + c;

	if (fabs(r) < eps)
		return 0;
	else
	if (r > 0)
		return 1;
	else
		return -1;
}

int parallel(double a1, double b1, double a2, double b2)
{
	return (fabs(a2 * b1 - a1 * b2) < eps);
}

int inbetween(double a, double b, double c)
{
	if (fabs(a - c) < eps || fabs(b - c) < eps || (a <= c && c <= b) || (b <= c && c <= a))
		return 1;
	else
		return 0;
}

int onsegment(double xa, double ya, double xb, double yb, double x, double y)
{
	double a, b, c;

	a = ya - yb;
	b = xb - xa;
	c = xa * yb - xb * ya;

	return (inbetween(xa, xb, x) && inbetween(ya, yb, y) && semn(a, b, c, x, y)==0);
}

int intersect(double x1a, double y1a, double x1b, double y1b,
			  double x2a, double y2a, double x2b, double y2b,
			  double *xi, double *yi)
{
	double a1, b1, c1, a2, b2, c2;

	a1 = y1a - y1b;
	b1 = x1b - x1a;
	c1 = x1a * y1b - x1b * y1a;

	a2 = y2a - y2b;
	b2 = x2b - x2a;
	c2 = x2a * y2b - x2b * y2a;

	if (parallel(a1,b1,a2,b2))
		return 0;
	else
	{
		*xi = (b2 * c1 - b1 * c2) / (a2 * b1 - a1 * b2);
		*yi = (c2 * a1 - c1 * a2) / (a2 * b1 - a1 * b2);

		/*
		if (onsegment(x1a, y1a, x1b, y1b, *xi, *yi) &&
			onsegment(x2a, y2a, x2b, y2b, *xi, *yi))
			return 1;
		else
			return 0;
		*/

		return 1;
	}
}

void DijkstraWithHeaps()
{
	// Dijkstra cu heap-uri

	memset(t, 0, sizeof(t));

	for (i = 1; i <= id; i++)
		dmin[i] = INF;

	dmin[ids] = 0.0;
	heap.clear();
	heap.insert(make_pair(dmin[ids], ids));

	cntmisses = 0;

	while (heap.size() > 0)
	{
		helem = *(heap.begin());
		i = helem.second;
		heap.erase(helem);

		for (j = 0; j < nv[i]; j++)
		{
			k = v[i][j];

			if (dmin[i] + l[i][j] < dmin[k])
			{
				if (dmin[k] < INF - epsinf) // k in heap => must be removed
				{
					heapit = heap.lower_bound(make_pair(dmin[k] - eps, k));

					ntries = 0;

					while (heapit != heap.end())
					{
						ntries++;

						if ((*heapit).second == k)
						{
							heap.erase(heapit);
							break;
						}
						else
							heapit++;
					}

					cntmisses += (ntries - 1);
				}

				dmin[k] = dmin[i] + l[i][j];
				heap.insert(make_pair(dmin[k], k));
				t[k] = i;
			}
		}
	}

	fprintf(stderr, "### Dijkstra with heaps ###\n");
	fprintf(stderr, "cntmisses=%d\n", cntmisses);

	freopen("tramvai.out", "w", stdout);

	if (fabs(dmin[idf] - INF) > epsinf)
	{
		printf("%.3lf\n", dmin[idf]);
		fprintf(stderr, "minimum distance = %.3lf\n", dmin[idf]);

		i = idf;

		cntedges = 0;

		while (i != ids)
		{
			if (fabs(xp[i] - xp[t[i]]) > eps || fabs(yp[i] - yp[t[i]]) > eps)
				cntedges++;
	
			i = t[i];
		}

		fprintf(stderr, "number of edges = %d\n", cntedges);
	}
	else
	{
		printf("-1\n");
		fprintf(stderr, "no path\n");
	}
}

void GreedyPathFinding()
{
	double dcur, dmin, dnew, dextra, dtotal = 0.0;
	int nextNode, cntedges = 0;

	dcur = (xp[ids] - xp[idf]) * (xp[ids] - xp[idf]) + (yp[ids] - yp[idf]) * (yp[ids] - yp[idf]);
	nextNode = i = ids;

	srand(time(NULL));

	while (fabs(dcur) > eps && nextNode)
	{
		nextNode = 0;
		dmin = dcur;

		for (j = 0; j < nv[i]; j++)
		{
			k = v[i][j];
			dnew = (xp[k] - xp[idf]) * (xp[k] - xp[idf]) + (yp[k] - yp[idf]) * (yp[k] - yp[idf]);
		
			if (dnew < dmin)
			{
				dmin = dnew;
				dextra = l[i][j];
				nextNode = k;
				
				if (rand() % 1000 < 500)
					break;
			}
		}

		if (nextNode)
		{
			dtotal += dextra;
			i = nextNode;
			dcur = dmin;
			cntedges++;
		}
	}

	fprintf(stderr, "### greedy ###\n");
	fprintf(stderr, "dcur=%.3lf\n", dcur);
	fprintf(stderr, "dtotal=%.3lf\n", dtotal);
	fprintf(stderr, "cntedges=%d\n", cntedges);

	freopen("tramvai.out", "w", stdout);
	printf("%.3lf\n", dtotal);
}

void readData()
{
	freopen("tramvai.in", "r", stdin);

	scanf("%d", &N);

	for (i = 1; i <= N; i++)
		scanf("%lf %lf %lf %lf", &xa[i], &ya[i], &xb[i], &yb[i]);

	scanf("%d %d %d %d", &ls1, &ls2, &lf1, &lf2);
}

void buildGraph()
{
	double xx, yy;

	for (i = 1; i <= N; i++)
		pid[i].clear();

	idset.clear();

	for (id = 0, i = 1; i < N; i++)
		for (j = i + 1; j <= N; j++)
			if (intersect(xa[i], ya[i], xb[i], yb[i], xa[j], ya[j], xb[j], yb[j], &xx, &yy))
			{
				id++;
				pid[i].push_back(make_pair(xx, make_pair(yy, id)));
				pid[j].push_back(make_pair(xx, make_pair(yy, id)));
				idset.insert(make_pair(i, make_pair(j, id)));

				xp[id] = xx;
				yp[id] = yy;
			}

	memset(nv, 0, sizeof(nv));

	for (i = 1; i <= N; i++)
	{
		sort(pid[i].begin(), pid[i].end());

		for (j = 0; j < pid[i].size(); j++)
		{
			current = pid[i][j].second.second;

			if (j > 0)
				before = pid[i][j - 1].second.second;
			else
				before = 0;

			if (j < pid[i].size() - 1)
				after = pid[i][j + 1].second.second;
			else
				after = 0;

			if (before > 0)
			{
				v[current][nv[current]] = before;
				l[current][nv[current]] = sqrt((xp[current] - xp[before]) * (xp[current] - xp[before]) +
											   (yp[current] - yp[before]) * (yp[current] - yp[before]));
				nv[current]++;
			}

			if (after > 0)
			{
				v[current][nv[current]] = after;
				l[current][nv[current]] = sqrt((xp[current] - xp[after]) * (xp[current] - xp[after]) +
											   (yp[current] - yp[after]) * (yp[current] - yp[after]));
				nv[current]++;
			}
		}
	}

	it = idset.lower_bound(make_pair(ls1, make_pair(ls2, -1)));
	ids = (*it).second.second;
	it = idset.lower_bound(make_pair(lf1, make_pair(lf2, -1)));
	idf = (*it).second.second;

	fprintf(stderr, "%d/%d\n", id, N*(N-1)/2);
	fprintf(stderr, "direct distance from (%.3lf,%.3lf) [%d] to (%.3lf,%.3lf) [%d] is %.3lf\n",
		xp[ids], yp[ids], ids, xp[idf], yp[idf], idf,
		sqrt((xp[ids] - xp[idf]) * (xp[ids] - xp[idf]) + (yp[ids] - yp[idf]) * (yp[ids] - yp[idf])));
}

int main()
{

	readData();
	buildGraph();

	if (USE_DIJKSTRA)
		DijkstraWithHeaps();
	else
		GreedyPathFinding();

	return 0;
}
