import java.io.*;
import java.math.BigInteger;
import java.util.*;

public class kitchen_md_assert implements Runnable {
	private static final int MAXROOM = 300;
	private static final int MAXN = 100;
	private static final int MAXSHELF = 300;
	
	private Scanner in;
	private PrintWriter out;

	public void run() {
		try {
			solve();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}

	private void error(String msg) {
		out.print("ERROR: " + msg);
		in.close();
		out.close();
		System.exit(1);
	}

	private void bounds(int val, int low, int high, String name) {
		if (val < low || val > high)
			error(name + " = " + val);
	}

	private void solve() throws IOException {
		Locale.setDefault(Locale.US);
		in = new Scanner(new FileReader("kitchen.in"));
		out = new PrintWriter("kitchen.out");
		int wid = in.nextInt();
		bounds(wid, 1, MAXROOM, "size of room");
		int hei = in.nextInt();
		bounds(hei, 1, MAXROOM, "size of room");
		int n = in.nextInt();
		bounds(n, 1, MAXN, "n");
		int[] w = new int[n];
		for (int i = 0; i < n; i++) {
			w[i] = in.nextInt();
			bounds(w[i], 1, MAXSHELF, "shelf number " + (i + 1));
		}
		if (in.hasNext())
			error("extra data");
		BigInteger[][][] a = new BigInteger[n + 1][n + 1][wid + 1];
		for (int i = 0; i <= n; i++)
			for (int j = 0; j <= n; j++)
				Arrays.fill(a[i][j], BigInteger.ZERO);
		a[0][0][0] = BigInteger.ONE;
		int sum = 0;
		for (int i = 0; i < n; i++) {
			sum += w[i];
			for (int j = 0; j <= i; j++) {
				for (int k = 0; k <= wid; k++) {
					if (a[i][j][k].signum() == 0)
						continue;
					if (k + w[i] <= wid)
						a[i + 1][j + 1][k + w[i]] = a[i + 1][j + 1][k + w[i]].add(a[i][j][k]);
					if (sum - k <= hei)
						a[i + 1][j][k] = a[i + 1][j][k].add(a[i][j][k]);
				}
			}
		}
		BigInteger[] fact = new BigInteger[n + 1];
		fact[0] = BigInteger.ONE;
		for (int i = 1; i <= n; i++) {
			fact[i] = fact[i - 1].multiply(BigInteger.valueOf(i));
		}
		BigInteger ans = BigInteger.ZERO;
		for (int j = 0; j <= n; j++) {
			BigInteger ways = BigInteger.ZERO;
			for (int k = 0; k <= wid; k++) {
				ways = ways.add(a[n][j][k]);
			}
			ways = ways.multiply(fact[j]).multiply(fact[n - j]);
			ans = ans.add(ways);
		}
		out.println(ans);
		in.close();
		out.close();
	}

	public static void main(String[] args) {
		new Thread(new kitchen_md_assert()).start();
	}
}
