import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.PrintWriter;
import java.util.LinkedList;
import java.util.StringTokenizer;

public class mahjong_dy {
	
	enum Directions {UP, DOWN, LEFT, RIGHT}
	
	class Item {
		public int color, x1, y1, x2, y2;
		
		public Item() {}
		
		public Item(int color, int x1, int y1, int x2, int y2) {
			this.color = color;
			this.x1 = x1;
			this.x2 = x2;
			this.y1 = y1;
			this.y2 = y2;
		}
	}
	
	class Point {
		int x, y;
		Directions dir;
		
		public Point() {}
		
		public Point(int x, int y, Directions dir) {
			this.x = x;
			this.y = y;
			this.dir = dir;
		}
	}
	
	class Cell {
		int color;
		boolean[] isBorder;
		
		public Cell() {}
		
		public Cell(int color) {
			isBorder = new boolean[4];
			this.color = color;
		}
	}
	
	BufferedReader in;
	PrintWriter out;
	StringTokenizer strtok;
	
	int n, m;
	Cell[][] a;
	LinkedList<Item> queue;
	LinkedList<Integer> answer;
	boolean[] processed;	
	Point[][] outer;
	
	int nextInt() throws Exception {
		while (strtok == null || !strtok.hasMoreTokens())
			strtok = new StringTokenizer(in.readLine());
		return Integer.parseInt(strtok.nextToken());
	}
	
	void readData() throws Exception {		
		n = nextInt();
		m = nextInt();
		a = new Cell[n][m];
		for (int i = 0; i < n; ++i) {
			for (int j = 0; j < m; ++j) {
				a[i][j] = new Cell(nextInt());
			}
		}
	}
	
	void find(int x, int y, int xx, int yy, int dx, int dy, Directions dir) {
		for (int i = x, j = y; i <= xx && j <= yy; i += dx, j += dy) {
			for (int p = x, q = y; p <= xx && q <= yy; p += dx, q += dy) {
				a[i][j].isBorder[dir.ordinal()] = a[p][q].isBorder[dir.ordinal()] = true;
				if (!(i == p && j == q) && a[i][j].color == a[p][q].color && !processed[a[p][q].color]) {									
					processed[a[p][q].color] = true;
					queue.add(new Item(a[i][j].color, i, j, p, q));					
				}
			}
		}
	}
	
	void initQueue() {
		queue = new LinkedList<Item>();
		processed = new boolean[m*n/2+1];
		find(0, 0, 0, m-1, 0, 1, Directions.UP);
		find(0, 0, n-1, 0, 1, 0, Directions.LEFT);
		find(n-1, 0, n-1, m-1, 0, 1, Directions.DOWN);
		find(0, m-1, n-1, m-1, 1, 0, Directions.RIGHT);
	}
	
	void initOuter() {
		outer = new Point[4][n*m/2+1];
		for (int i = 0; i < m; ++i) {
			if (!processed[a[0][i].color]) {
				outer[Directions.UP.ordinal()][a[0][i].color] = new Point(0, i, Directions.UP);
				a[0][i].isBorder[Directions.UP.ordinal()] = true;
			}
			if (!processed[a[n-1][i].color]) {
				outer[Directions.DOWN.ordinal()][a[n-1][i].color] = new Point(n-1, i, Directions.DOWN);
				a[n-1][i].isBorder[Directions.DOWN.ordinal()] = true;
			}
		}
		for (int i = 0; i < n; ++i) {
			if (!processed[a[i][0].color]) {
				outer[Directions.LEFT.ordinal()][a[i][0].color] = new Point(i, 0, Directions.LEFT);
				a[i][0].isBorder[Directions.LEFT.ordinal()] = true;
			}
			if (!processed[a[i][m - 1].color]) {
				outer[Directions.RIGHT.ordinal()][a[i][m - 1].color] = new Point(i, m - 1, Directions.RIGHT);
				a[i][m - 1].isBorder[Directions.RIGHT.ordinal()] = true;
			}
		}
	}
	
	void addBorderPoint(int x, int y, Directions dir) {		
		a[x][y].isBorder[dir.ordinal()] = true;
		if (outer[dir.ordinal()][a[x][y].color] == null) {
			outer[dir.ordinal()][a[x][y].color] = new Point(x, y, dir);
		} else if (!(outer[dir.ordinal()][a[x][y].color].x == x && outer[dir.ordinal()][a[x][y].color].y == y)){
			if (processed[a[x][y].color])
				return;				
			queue.add(new Item(a[x][y].color, x, y, outer[dir.ordinal()][a[x][y].color].x, outer[dir.ordinal()][a[x][y].color].y));
			processed[a[x][y].color] = true;
			outer[dir.ordinal()][a[x][y].color] = null;
		}
	}
	
	void processPoint(int x, int y, Directions dir) {
		int dx = 0, dy = 0;
		if (dir == Directions.UP) {
			dx = 1;
		} else if (dir == Directions.DOWN) {
			dx = -1;
		} else if (dir == Directions.LEFT) {
			dy = 1;
		} else if (dir == Directions.RIGHT) {
			dy = -1;
		}
		while (x >= 0 && x < n && y >= 0 && y < m && a[x][y].color == 0) {
			x += dx;
			y += dy;
		}
		
		if (x < 0 || x >= n || y < 0 || y >= m)
			return;
		if (a[x][y].color != 0)
			addBorderPoint(x, y, dir);
	}
	
	void solve() {
		answer = new LinkedList<Integer>();		
		while (queue.size() > 0) {
			Item cur = queue.removeFirst();
			answer.addLast(cur.color);
						
			a[cur.x1][cur.y1].color = a[cur.x2][cur.y2].color = 0;
			
			for (Directions dir : Directions.values()) {
				if (a[cur.x1][cur.y1].isBorder[dir.ordinal()])
					processPoint(cur.x1, cur.y1, dir);
				if (a[cur.x2][cur.y2].isBorder[dir.ordinal()])
					processPoint(cur.x2, cur.y2, dir);
			}	
			
											
		}
	}
	
	void output() {
		out.println(answer.size());
		for (Integer it : answer) {
			out.print(it);
			out.print(" ");
		}
	}
	
	public mahjong_dy() {
		try {
			in = new BufferedReader(new FileReader("mahjong.in"));
			out = new PrintWriter(new File("mahjong.out"));
			
			readData();
			initQueue();
			initOuter();
			solve();
			output();
			
			out.close();
		} catch (Exception er) {
			er.printStackTrace();
			System.exit(1);
		}
	}
	
	public static void main(String[] args) {
		new mahjong_dy();
	}
}