import java.io.*;
import java.util.*;

public class mahjong_md_assert implements Runnable {
	private static final int MAX = 300;
	
	private BufferedReader in;
	private PrintWriter out;
	
	public void run() {
		try {
			solve();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}
	
	private void error(String msg) throws IOException {
		out.print("ERROR: " + msg);
		in.close();
		out.close();
		System.exit(1);
	}
	
	private void bounds(int val, int low, int high, String name) throws IOException {
		if (val < low || val > high)
			error(name + " = " + val);
	}
	
	private void solve() throws IOException {
		Locale.setDefault(Locale.US);
		in = new BufferedReader(new FileReader("mahjong.in"));
		out = new PrintWriter("mahjong.out");
		StringTokenizer st = new StringTokenizer(in.readLine());
		int n = Integer.parseInt(st.nextToken());
		bounds(n, 1, MAX, "height");
		int m = Integer.parseInt(st.nextToken());
		bounds(m, 1, MAX, "width");
		if (st.hasMoreTokens())
			error("extra data in first line");
		int f = n * m / 2;
		
		int[][] a = new int[n][m];
		int[] north = new int[f];
		int[] south = new int[f];
		int[] east = new int[f];
		int[] west = new int[f];
		
		int[] np = new int[m];
		Arrays.fill(np, 0);
		int[] sp = new int[m];
		Arrays.fill(sp, n - 1);
		int[] wp = new int[n];
		Arrays.fill(wp, 0);
		int[] ep = new int[n];
		Arrays.fill(ep, m - 1);
		
		int[] x1 = new int[f];
		int[] y1 = new int[f];
		int[] x2 = new int[f];
		int[] y2 = new int[f];
		Arrays.fill(x1, -1);
		Arrays.fill(x2, -1);
		
		ArrayList<Integer> queue = new ArrayList<Integer>();
		boolean[] mark = new boolean[f];
		int low = 0;
		for (int i = 0; i < n; i++) {
			st = new StringTokenizer(in.readLine());
			for (int j = 0; j < m; j++) {
				int v = a[i][j] = Integer.parseInt(st.nextToken()) - 1;
				bounds(v + 1, 1, f, "number in line " + (i + 1) + " position " + (j + 1));
				if (x1[v] < 0) {
					x1[v] = i;
					y1[v] = j;
				} else if (x2[v] < 0) {
					x2[v] = i;
					y2[v] = j;
				} else
					error("number " + (v + 1) + " is used at least three times");
				if (i == 0) {
					north[v]++;
					if (north[v] == 2 && !mark[v]) {
						queue.add(v);
						mark[v] = true;
					}
				}
				if (i == n - 1) {
					south[v]++;
					if (south[v] == 2 && !mark[v]) {
						queue.add(v);
						mark[v] = true;
					}
				}
				if (j == 0) {
					west[v]++;
					if (west[v] == 2 && !mark[v]) {
						queue.add(v);
						mark[v] = true;
					}
				}
				if (j == m - 1) {
					east[v]++;
					if (east[v] == 2 && !mark[v]) {
						queue.add(v);
						mark[v] = true;
					}
				}
			}
			if (st.hasMoreTokens())
				error("line " + (i + 1) + "has extra data");
		}
		if (in.readLine() != null)
			error("extra data after mahjong table");
		while (low < queue.size()) {
			int v = queue.get(low++);
			int x, y;
			for (int t = 0; t < 2; t++) {
				if (t == 0) {
					x = x1[v];
					y = y1[v];
				} else {
					x = x2[v];
					y = y2[v];
				}
				a[x][y] = -1;
				if (x == np[y]) {
					do np[y]++; while (np[y] < n && a[np[y]][y] < 0);
					if (np[y] < n) {
						int u = a[np[y]][y];
						north[u]++;
						if (north[u] == 2 && !mark[u]) {
							queue.add(u);
							mark[u] = true;
						}
					}
				}
				if (x == sp[y]) {
					do sp[y]--; while (sp[y] >= 0 && a[sp[y]][y] < 0);
					if (sp[y] >= 0) {
						int u = a[sp[y]][y];
						south[u]++;
						if (south[u] == 2 && !mark[u]) {
							queue.add(u);
							mark[u] = true;
						}
					}
				}
				if (y == wp[x]) {
					do wp[x]++; while (wp[x] < m && a[x][wp[x]] < 0);
					if (wp[x] < m) {
						int u = a[x][wp[x]];
						west[u]++;
						if (west[u] == 2 && !mark[u]) {
							queue.add(u);
							mark[u] = true;
						}
					}
				}
				if (y == ep[x]) {
					do ep[x]--; while (ep[x] >= 0 && a[x][ep[x]] < 0);
					if (ep[x] >= 0) {
						int u = a[x][ep[x]];
						east[u]++;
						if (east[u] == 2 && !mark[u]) {
							queue.add(u);
							mark[u] = true;
						}
					}
				}
			}
		}
		out.println(queue.size());
		for (int v : queue)
			out.print((v + 1) + " ");
		out.println();
		in.close();
		out.close();
	}
	
	public static void main(String[] args) {
		new Thread(new mahjong_md_assert()).start();
	}
}
