import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.Locale;
import java.util.StringTokenizer;

public class trench_dy {
	
	final double EPS = 1e-6;
	
	BufferedReader in;
	PrintWriter out;
	StringTokenizer strtok = null;
	
	int n, start = -1, end = -1;
	double[][] g;
	double[] d;
	Point a, b;	
	Box[] boxes;
	boolean[] inTree;
	
	int nextInt() throws Exception {
		while (strtok == null || !strtok.hasMoreTokens())
			strtok = new StringTokenizer(in.readLine());
		return Integer.parseInt(strtok.nextToken());
	}
	
	class Point {
		public int x, y;
		
		public Point() {}
		
		public Point(int x, int y) {
			this.x = x;
			this.y = y;
		}
		
		public Point(Point p1, Point p2) {
			this.x = p2.x - p1.x;
			this.y = p2.y - p1.y;
		}
		
		public Point subtract(Point subtractWhat) {
			return new Point(x - subtractWhat.x, y - subtractWhat.y);
		}
	}
	
	class Segment {
		public Point p1, p2;
		double len;
		
		public Segment() {}
		
		public Segment(Point p1, Point p2) {
			this.p1 = p1;
			this.p2 = p2;
			len = dist(p1, p2);
		}
		
		public boolean pointOnSeg(Point p) {
			double d1 = dist(p, p1);
			double d2 = dist(p, p2);
			return Math.abs(len - d1 - d2) < EPS;
		}
		
		public double dist2ToPoint(Point p) {
			Point p1, p2;
			p1 = p.subtract(this.p1);
			p2 = this.p2.subtract(this.p1);
			int a1 = p1.x * p2.x + p1.y * p2.y;
			p1 = p.subtract(this.p2);
			p2 = this.p1.subtract(this.p2);
			int a2 = p1.x * p2.x + p1.y * p2.y;
			if (a1 >= 0 && a2 >= 0) {
				double a = this.p2.y - this.p1.y;
				double b = this.p1.x - this.p2.x;
				double c = -a * this.p1.x - b * this.p1.y;
				double d = Math.sqrt(a*a + b*b);
				return (a * p.x + b * p.y + c) * (a * p.x + b * p.y + c) / d / d;
			} else {
				return min(dist2(p, this.p1), dist2(p, this.p2));
			}
		}
		
		public double dist2ToSeg(Segment s) {
			if (segmentCross(this, s))
				return 0.0;
			double d1 = min(s.dist2ToPoint(this.p1), s.dist2ToPoint(this.p2));
			double d2 = min(dist2ToPoint(s.p1), dist2ToPoint(s.p2));
			return min(d1, d2);
		}
	}
	
	int orient(Point v1, Point v2) {
		return Integer.valueOf(v1.x * v2.y - v1.y * v2.x).compareTo(Integer.valueOf(0));
	}	
	
	int max(int a, int b) {
		return a > b? a : b;
	}
	
	int min(int a, int b) {
		return a < b? a : b;
	}
	
	double min(double a, double b) {
		return a < b? a : b;
	}
	
	boolean segmentCross(Segment s1, Segment s2) {		
		if (max(s1.p1.x, s1.p2.x) < min(s2.p1.x, s2.p2.x) || 
			min(s1.p1.x, s1.p2.x) > max(s2.p1.x, s2.p2.x) ||
			max(s1.p1.y, s1.p2.y) < min(s2.p1.y, s2.p2.y) || 
			min(s1.p1.y, s1.p2.y) > max(s2.p1.y, s2.p2.y)) 
				return false; 
		return orient(new Point(s1.p1, s2.p1), new Point(s1.p1, s1.p2)) * orient(new Point(s1.p1, s1.p2), new Point(s1.p1, s2.p2)) >= 0 &&
			   orient(new Point(s2.p1, s1.p1), new Point(s2.p1, s2.p2)) * orient(new Point(s2.p1, s2.p2), new Point()) >= 0;
	}

	
	class Box {
		Segment[] s;
		
		public Box() {}
		
		public Box(Point p1, Point p2) {
			s = new Segment[4];
			s[0] = new Segment(new Point(p1.x, p1.y), new Point(p1.x, p2.y));
			s[1] = new Segment(new Point(p1.x, p1.y), new Point(p2.x, p1.y));
			s[2] = new Segment(new Point(p2.x, p2.y), new Point(p1.x, p2.y));
			s[3] = new Segment(new Point(p2.x, p2.y), new Point(p2.x, p1.y));
		}
				
		
		public double distToBox(Box b) {
			double dist2 = false && boxIntersect(b, this)? 0 : Double.POSITIVE_INFINITY;
			for (int i = 0; i < 4; ++i) {
				for (int j = 0; j < 4; ++j) {
					dist2 = min(dist2, s[i].dist2ToSeg(b.s[j]));
				}
			}
			if (dist2 < 1e-10 != boxIntersect(b, this)) {				
				throw new AssertionError("Bug in solution");
			}
			return Math.sqrt(dist2);
		}
	}

	boolean boxIntersect(Box b1, Box b2) {		
		int maxx1, maxx2, maxy1, maxy2, minx1, miny1, minx2, miny2;
		maxx1 = maxx2 = maxy1 = maxy2 = Integer.MIN_VALUE;
		minx1 = minx2 = miny1 = miny2 = Integer.MAX_VALUE;
		for (int i = 0; i < 4; ++i) {
			maxx1 = max(b1.s[i].p1.x, max(b1.s[i].p2.x, maxx1));
			maxx2 = max(b2.s[i].p1.x, max(b2.s[i].p2.x, maxx2));
			maxy1 = max(b1.s[i].p1.y, max(b1.s[i].p2.y, maxy1));
			maxy2 = max(b2.s[i].p1.y, max(b2.s[i].p2.y, maxy2));
			minx1 = min(b1.s[i].p1.x, min(b1.s[i].p2.x, minx1));
			minx2 = min(b2.s[i].p1.x, min(b2.s[i].p2.x, minx2));
			miny1 = min(b1.s[i].p1.y, min(b1.s[i].p2.y, miny1));
			miny2 = min(b2.s[i].p1.y, min(b2.s[i].p2.y, miny2));
		}
		if (minx1 > maxx2 || maxx1 < minx2 || miny1 > maxy2 || maxy1 < miny2 || 
				(maxx1 > maxx2 && minx1 < minx2 && maxy1 > maxy2 && miny1 < miny2) || 
				(maxx2 > maxx1 && minx2 < minx1 && maxy2 > maxy1 && miny2 < miny1))
			return false;
		return true;
	}
	
	double dist(Point p1, Point p2) {
		return Math.sqrt((p2.x - p1.x) * (p2.x - p1.x) + (p2.y - p1.y) * (p2.y - p1.y));
	}
	
	double dist2(Point p1, Point p2) {
		return ((p2.x - p1.x) * (p2.x - p1.x) + (p2.y - p1.y) * (p2.y - p1.y));
	}
	
	void readData() throws Exception {
		n = nextInt();
		if (n > 1000)
			throw new Exception("   1000");
		boxes = new Box[n];		
		for (int i = 0; i < n; ++i) {
			boxes[i] = new Box(new Point(nextInt(), nextInt()), new Point(nextInt(), nextInt()));
		}
		a = new Point(nextInt(), nextInt());
		b = new Point(nextInt(), nextInt());		
	}
	
	void buildGraph() throws Exception {
		g = new double[n][n];		
		for (int i = 0; i < n; ++i)
			for (int j = 0; j < n; ++j)
				g[i][j] = Double.POSITIVE_INFINITY;		
		for (int i = 0; i < n; ++i) {
			for (int j = 0; j < 4; ++j) {
				if (boxes[i].s[j].pointOnSeg(a))
					start = i;
				if (boxes[i].s[j].pointOnSeg(b))
					end = i;
			}
		}
		for (int i = 0; i < n; ++i) {
			for (int j = i + 1; j < n; ++j) {
				g[i][j] = g[j][i] = boxes[i].distToBox(boxes[j]);
			}
		}
		if (start == -1)
			throw new Exception("    ");
		if (end == -1)
			throw new Exception(" B   ");
	}
	
	void dijkstra(int start) {
		d = new double[n];
		inTree = new boolean[n];
		Arrays.fill(d, Double.POSITIVE_INFINITY);
		d[start] = 0;
		int v = start;	
		double mindist = 0;
		while (!inTree[v]) {
			inTree[v] = true;
			for (int i = 0; i < n; ++i) {
				if (d[v] + g[v][i] < d[i])
					d[i] = d[v] + g[v][i]; 
			}
			mindist = Double.POSITIVE_INFINITY;			
			for (int i = 0; i < n; ++i) {
				if (mindist > d[i] && !inTree[i]) {
					mindist = d[i];
					v = i;
				}
			}
		}
	}
	
	public trench_dy() {
		try {
			Locale.setDefault(Locale.US);
			in = new BufferedReader(new FileReader("trench.in"));
			out = new PrintWriter(new File("trench.out"));
						
			readData();
			buildGraph();
			dijkstra(start);
			if (d[end] == Double.POSITIVE_INFINITY)
				throw new Exception("-    ");
			out.printf("%.7f", d[end]);
			
			out.close();
		} catch (Exception er) {
			er.printStackTrace();
			System.exit(1);
		}
	}
	
	public static void main(String[] args) {
		new trench_dy();
	}
}