#include <cstdio>
#include <cmath>
#include <vector>
#include <iostream>
#include <fstream>
using namespace std;

const int MAXN = 100000;
const long double eps = 1e-12;

class Point
{
public:
	long double x, y;
};

int n;
long double l;
Point a, b;
vector<Point> pnt;

void Load()
{
	double t;
	scanf("%d%lf", &n, &t);
	l = t;
	double aax, aay, bbx, bby;
	scanf("%lf%lf%lf%lf", &aax, &aay, &bbx, &bby);
	a.x = aax;
	a.y = aay;
	b.x = bbx;
	b.y = bby;
	int i;
	for (i = 0; i < n; i++)
	{
		Point c;
		double cx, cy;
		scanf("%lf%lf", &cx, &cy);
		c.x = cx;
		c.y = cy;
		pnt.push_back(c);
	}
}

inline long double sqr(long double a)
{
	return a * a;
}

long double Dist(Point &a, Point &b)
{
	return sqrt(sqr(a.x - b.x) + sqr(a.y - b.y));
}

long double dista[MAXN + 10], distb[MAXN + 10];
long double ymin[MAXN + 10], ymax[MAXN + 10];
      
long double GetX(Point &p1, Point &p2, long double y)
{
	if (fabs(p2.y - p1.y) < eps) 
	{
		if (fabs(y - p1.y) > eps) return 1e-100;
		else return p1.x;
	}
	return (y - p1.y) / (p2.y - p1.y) * (p2.x - p1.x) + p1.x;
}

long double CheckBridge(int p1, int p2, Point &pp1, Point &pp2)
{
	if (fabs(pp1.x - 1497.067) < eps)
		cerr << "Checked bridge " << pp1.x << " " << pp1.y << " " << pp2.x << " " << pp2.y << "\n";
	int i;
	for (i = p1 + 1; i <= p2; i++)
	{
		if (pnt[i].y - pp1.y > eps) return 1e100;
	}
	if ((fabs(pp1.x - 1.5) < eps) && (fabs(pp1.y - 4) < eps))
	{
		pp1.x = 1.5;
	}
	return min(dista[p1] + Dist(pnt[p1], pp1), dista[p1 + 1] + Dist(pnt[p1 + 1], pp1)) +
			+ Dist(pp1, pp2) +
		   min(distb[p2] + Dist(pnt[p2], pp2), distb[p2 + 1] + Dist(pnt[p2 + 1], pp2)); 
}

int Inter(long double l1, long double l2, long double r1, long double r2)
{
	l1 = max(l1, r1);
	l2 = min(l2, r2);
	if (l1 - l2 < eps) return 1;
	else return 0;
}

long double GetBridge(int p1, int p2, Point &beg, Point &en)
{
	long double ybeg, yen;
	ybeg = ymin[p1];
	yen = ymax[p1];
	ybeg = max(ybeg, ymin[p2]);
	yen = min(yen, ymax[p2]);
	if (ybeg - yen > eps) return 1e100;
	int i;
	for (i = p1 + 1; i < p2; i++)
	{
		if (Inter(ymin[i], ymax[i], ybeg, yen) && (ymax[i] - ybeg > -eps) && (ymax[i] - yen < eps))
		{
			ybeg = ymax[i];
		}
		else if (Inter(ymin[i], ymax[i], ybeg, yen) && (ymin[i] - ybeg > -eps) && (ymin[i] - yen < eps))
		{
			yen = ymin[i];
		}
	}
	if (yen - ybeg < -eps) return 1e100;
	long double a, b;
	a = b = 0;
	if (fabs(pnt[p1 + 1].y - pnt[p1].y) < eps)
	{
		b -= pnt[p1 + 1].x;
	}
	else
	{
		a -= (pnt[p1 + 1].x - pnt[p1].x) / (pnt[p1 + 1].y - pnt[p1].y);
		b -= - pnt[p1].y * (pnt[p1 + 1].x - pnt[p1].x) / (pnt[p1 + 1].y - pnt[p1].y) + pnt[p1].x;
	}
	if (fabs(pnt[p2 + 1].y - pnt[p2].y) < eps)
	{
		b += pnt[p2 + 1].x;
	}
	else
	{
		a += (pnt[p2 + 1].x - pnt[p2].x) / (pnt[p2 + 1].y - pnt[p2].y);
		b += - pnt[p2].y * (pnt[p2 + 1].x - pnt[p2].x) / (pnt[p2 + 1].y - pnt[p2].y) + pnt[p2].x;
	}
	if (fabs(a) > eps)
	{
		long double ty = (l - b) / a;
		if ((ty - ybeg > -eps) && (ty - yen < eps))
		{
			if (a * ybeg + b - l > eps) ybeg = ty;
			else yen = ty;
		}
	}
	if (a * ybeg + b - l > eps) return 1e100;
    Point pp1, pp2, pp3, pp4;
    pp1.x = GetX(pnt[p1], pnt[p1 + 1], ybeg);
    pp1.y = ybeg;
    pp2.x = GetX(pnt[p2], pnt[p2 + 1], ybeg);
    pp2.y = ybeg;
    pp3.x = GetX(pnt[p1], pnt[p1 + 1], yen);
    pp3.y = yen;
    pp4.x = GetX(pnt[p2], pnt[p2 + 1], yen);
    pp4.y = yen;
	long double r1, r2;
	r1 = CheckBridge(p1, p2, pp1, pp2);
	r2 = CheckBridge(p1, p2, pp3, pp4);
	if (r1 < r2)
	{
		beg = pp1;
		en = pp2;
		return r1;
	}
	else
	{
		beg = pp3;
		en = pp4;
		return r2;
	} 
	return 1e100;
}

int FindInVector(Point &p)
{
	int i;
	for (i = 0; i < pnt.size() - 1; i++)
	{
		if (! ((p.x - pnt[i].x > -eps) && (p.x - pnt[i + 1].x < eps))) continue;
		if (fabs((p.x - pnt[i].x) * (pnt[i + 1].y - pnt[i].y) - (pnt[i + 1].x - pnt[i].x) * (p.y - pnt[i].y)) < eps) return i;
	}
	return -1;
}

void Solve()
{
	int i, j;
	int apos = FindInVector(a);
	if ((fabs(pnt[apos].x - a.x) > eps)  && ((apos == pnt.size() - 1) || (fabs(pnt[apos + 1].x - a.x) > eps)))
	{
		pnt.push_back(pnt[pnt.size() - 1]);
		for (i = pnt.size() - 1; i > apos + 1; i--) 
		{	
			pnt[i] = pnt[i - 1];
		}
		pnt[apos + 1] = a;
		apos++;
	}
	if ((apos != pnt.size() - 1) && (fabs(pnt[apos + 1].x - a.x) < eps))
	{
		apos++;
	}
	int bpos = FindInVector(b);
	if ((fabs(pnt[bpos].x - b.x) > eps)  && ((bpos == pnt.size() - 1) || (fabs(pnt[bpos + 1].x - b.x) > eps)))
	{
		pnt.push_back(pnt[pnt.size() - 1]);
		for (i = pnt.size() - 1; i > bpos + 1; i--) 
		{	
			pnt[i] = pnt[i - 1];
		}
		pnt[bpos + 1] = b;
		if (bpos < apos) apos++;
		bpos++;
	}
	if ((bpos != pnt.size() - 1) && (fabs(pnt[bpos + 1].x - b.x) < eps))
	{
		bpos++;
	}
	if (apos > bpos)
	{
		Point tt;
		tt = a;
		a = b;
		b = tt;
		int t = apos;
		apos = bpos;
		bpos = t;
	}
	for (i = 0; i < pnt.size() - 1; i++)
	{
		ymin[i] = min(pnt[i].y, pnt[i + 1].y);
		ymax[i] = max(pnt[i].y, pnt[i + 1].y);
	}

	dista[apos] = 0;
	for (i = apos + 1; i < pnt.size(); i++) dista[i] = dista[i - 1] + Dist(pnt[i], pnt[i - 1]);
	for (i = apos - 1; i >= 0; i--) dista[i] = dista[i + 1] + Dist(pnt[i], pnt[i + 1]);
	distb[bpos] = 0;
	for (i = bpos + 1; i < pnt.size(); i++) distb[i] = distb[i - 1] + Dist(pnt[i], pnt[i - 1]);
	for (i = bpos - 1; i >= 0; i--) distb[i] = distb[i + 1] + Dist(pnt[i], pnt[i + 1]);

	long double mn = dista[bpos];
	Point bbeg, ben;
	bbeg.x = 1e100;
	for (i = 0; i < pnt.size() - 1; i++)
	{
		for (j = i + 1; j < pnt.size() - 1; j++)
		{
			if ((i == 15) && (j == 44))
			{
				j = 44;
			}
			Point cb, ce;
			long double cur;
			cur = GetBridge(i, j, cb, ce);
			if (cur < mn)
			{
				mn = cur;
				bbeg = cb;
				ben = ce;
			}
		}
	}
	if (bbeg.x > 1e99) 
	{
		cout << "Some BoTVA appeared!!!";
	}
	else
	{
		cout.setf(ios::fixed | ios::showpoint);
		cout << bbeg.x << " " << bbeg.y << "\n" << ben.x << " " << ben.y << "\n";
	}
}

int main()
{
	freopen("bridge.in", "rt", stdin);
	freopen("bridge.out", "wt", stdout);
	Load();
	Solve();
	return 0;
}