import java.io.*;
import java.util.*;

public class bridge_md_assert implements Runnable {
	public static final double eps = 1e-9;
	public static final double infty = 1e10;

	private class Valley implements Comparable<Valley> {
		double ylo, yhi;
		int i, j;
		boolean wide;

		public Valley(double ylo, int i, int j) {
			this.ylo = ylo;
			this.i = i;
			this.j = j;
			yhi = Math.min(y[i], y[j + 1]);
			if ((i > 0) && (j < n - 2))
				check();
		}
		
		public void check() {
			check(ylo);
			check(yhi);
			double xx = x(j, ylo) - x(i, ylo);
			double slope = (x[j + 1] - x[j]) / (y[j + 1] - y[j]) - (x[i + 1] - x[i]) / (y[i + 1] - y[i]);
			double yy = ylo + (l - xx) / slope;
			check(yy);
			check(ay); // optimizable
			check(by);
		}
		
		public void check(double y) {
			if (y < ylo - eps || y > yhi + eps)
				return;
			double x1 = x(i, y);
			double x2 = x(j, y);
			if (x2 < x1 + l + eps) {
				tryBridge(x1, x2);
			} else
				wide = true;
		}

		public int compareTo(Valley that) {
			if (yhi == that.yhi)
				return i - that.i;
			return Double.compare(yhi, that.yhi);
		}
		
		@Override
		public String toString() {
			return i + " " + j + " " + ylo;
		}
	}
	
	private class Landscape {
		TreeSet<Valley> ts = new TreeSet<Valley>();
		
		public void add(Valley v) {
			ts.add(v);
//			System.out.println(y[v.i] + " " + y[v.i + 1] + "       " + y[v.j] + " " + y[v.j + 1]);
		}

		public boolean process() {
			if (ts.isEmpty() || ts.first().yhi == infty)
				return false;
			Valley v = ts.first();
//			System.out.println(y[v.i] + " " + y[v.i + 1] + "       " + y[v.j] + " " + y[v.j + 1]);
//			System.out.println(v.i + " " + v.j);
			Valley u;
			ts.remove(v);
			if (Math.abs(v.yhi - y[v.i]) < eps) {
				while (v.i > 0 && y[v.i] == y[v.i - 1])
					v.i--;
				if (y[v.i - 1] > y[v.i]) {
					u = new Valley(v.yhi, v.i - 1, v.j);
					ts.add(u);
					return true;
				}
				throw new Error("what's going on on the left???");
			}
			int j = v.j;
			while (y[j + 1] == y[j + 2])
				j++;
			j++;
			if (y[j] < y[j + 1]) {
				u = new Valley(v.yhi, v.i, j);
				ts.add(u);
				return true;
			}
			if (j != ts.first().i)
				throw new Error("strange neibour");
			ArrayList<Valley> al = new ArrayList<Valley>();
			al.add(v);
			while (!ts.isEmpty() && isrm[al.get(al.size() - 1).j]) {
				if (ts.first().yhi != v.yhi)
					throw new Error("what's going on on the right???");
				al.add(ts.first());
				ts.remove(ts.first());
				if (y[al.get(al.size() - 1).j + 1] != v.yhi)
					break;
			}
			
			int s1 = al.size() - 1;
			while (s1 > 0 && x[al.get(s1).j + 1] > bx + eps)
				s1--;
			j = 0;
			for (int i = 0; i < al.size(); i++) {
				while (j + 1 < al.size() && (x[al.get(j + 1).j + 1] - x[al.get(i).i] < l + eps))
					j++;
				new Valley(v.yhi, al.get(i).i, al.get(j).j);
				new Valley(v.yhi, al.get(i).i, al.get(s1).j);
				if (s1 < al.size() - 1)
					new Valley(v.yhi, al.get(i).i, al.get(s1 + 1).j);
			}
			
			u = new Valley(v.yhi, al.get(0).i, al.get(al.size() - 1).j);
			ts.add(u);
			return true;
		}
	}
	
	private BufferedReader in;
	private PrintWriter out;

	public void run() {
		try {
			solve();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}
	
	int n, l;
	double[] x;
	double[] y;
	double[] cum;
	boolean[] isrm;
	double ax, ay, bx, by;
	double ans = 1e100;
	double ansx1, ansx2, ansy;
	Landscape land = new Landscape();
	
	private int edge(double x1) {
		int i = Arrays.binarySearch(x, x1);
		i = (i < 0) ? (-2 - i) : i;
		return (i == n - 1) ? i - 1 : i;
	}
	
	private double y(double x1) {
		int i = edge(x1);
		return y[i] + (y[i + 1] - y[i]) * (x1 - x[i]) / (x[i + 1] - x[i]);
	}
	
	private double x(int i, double y1) {
		return x[i] + (y1 - y[i]) / (y[i + 1] - y[i]) * (x[i + 1] - x[i]);
	}
	
	private double walk(double x1) {
		int i = edge(x1);
		return cum[i] + (x1 - x[i]) / (x[i + 1] - x[i]) * Math.hypot(x[i + 1] - x[i], y[i + 1] - y[i]);
	}

	private double dist(double x1, double x2) {
		if (x1 > x2) {
			double t = x1; x1 = x2; x2 = t;
		}
		return walk(x2) - walk(x1);
	}
	
	private void tryBridge(double xl, double xr) {
		double len = dist(ax, xl) + xr - xl + dist(xr, bx);
//		System.out.println(xl + " " + xr + " " + y(xl) + " " + len);
		if (len < ans) {
			ans = len;
			ansx1 = xl;
			ansx2 = xr;
			ansy = y(xl);
		}
	}
	
	private void myAssert(boolean cond, String msg) throws IOException {
		if (!cond) {
			out.println("ERROR: " + msg);
			in.close();
			out.close();
			System.exit(1);
		}
	}
	
	private void solve() throws IOException {
		Locale.setDefault(Locale.US);
		in = new BufferedReader(new FileReader("bridge.in"));
		out = new PrintWriter("bridge.out");
		String s = in.readLine();
		StringTokenizer st = new StringTokenizer(s);
		n = Integer.parseInt(st.nextToken());
		l = Integer.parseInt(st.nextToken());
		myAssert(s.equals(n + " " + l), "Bad spaces in line 1");
		myAssert(n > 0 && n <= 100000, "Bad n = " + n);
		myAssert(l > 0 && l <= 1000000, "Bad l = " + l);
		x = new double[n + 2];
		y = new double[n + 2];
		
		s = in.readLine();
		st = new StringTokenizer(s);
		ax = Integer.parseInt(st.nextToken());
		ay = Integer.parseInt(st.nextToken());
		myAssert(s.equals((int)ax + " " + (int)ay), "Bad spaces in line 2");
		s = in.readLine();
		st = new StringTokenizer(s);
		bx = Integer.parseInt(st.nextToken());
		by = Integer.parseInt(st.nextToken());
		myAssert(s.equals((int)bx + " " + (int)by), "Bad spaces in line 3");
		if (ax > bx) {
			double t = ax; ax = bx; bx = t;
			t = ay; ay = by; by = t;
		}
		
		for (int i = 1; i <= n; i++) {
			s = in.readLine();
			st = new StringTokenizer(s);
			x[i] = Integer.parseInt(st.nextToken());
			y[i] = Integer.parseInt(st.nextToken());
			myAssert(s.equals((int)x[i] + " " + (int)y[i]), "Bad spaces in line " + (i + 3));
			myAssert(Math.abs(x[i]) <= 1000000, "Bad x coordinate in line " + (i + 3));
			myAssert(Math.abs(y[i]) <= 1000000, "Bad y coordinate in line " + (i + 3));
		}
		myAssert(in.readLine() == null, "Extra information in test");
		for (int i = 1; i < n; i++) {
			myAssert(x[i] < x[i + 1], "Non-increasing x's in lines " + (3 + i) + "-" + (4 + i));
		}
		myAssert(y[1] == 0, "y[1] != 0");
		myAssert(y[n] == 0, "y[n] != 0");
		
		x[0] = x[1] - 1;
		y[0] = infty;
		x[n + 1] = x[n] + 1;
		y[n + 1] = infty;
		n += 2;
		cum = new double[n];
		for (int i = 1; i < n - 1; i++) {
			cum[i + 1] = cum[i] + Math.hypot(x[i + 1] - x[i], y[i + 1] - y[i]);
		}
		
		myAssert(ax >= x[1] && ax <= x[n - 2], "Bad ax = " + ax);
		myAssert(bx >= x[1] && bx <= x[n - 2], "Bad bx = " + bx);
		double az = y(ax);
		myAssert(Math.abs(ay - az) < eps, "Bad ay = " + ay + " instead of " + az);
		double bz = y(bx);
		myAssert(Math.abs(by - bz) < eps, "Bad by = " + by + " instead of " + bz);
		
		tryBridge(ax, ax);
		double simple = ans;
		
		for (int i = 0; i < n - 1; i++) {
			if (y[i] > y[i + 1]) {
				int j = i + 1;
				while (y[j] == y[j + 1])
					j++;
				if (y[j] > y[j + 1])
					continue;
				land.add(new Valley(y[j], i, j));
			}
		}
		
		isrm = new boolean[n];
		for (int i = 0; i < n - 2; i++) {
			if (y[i] < y[i + 1]) {
				int j = i + 1;
				while (y[j] == y[j + 1])
					j++;
				if (y[j] > y[j + 1])
					isrm[i] = true;
			}
		}
		
		while (land.process());
		
		myAssert(ans < simple - eps, "No bridge needed at all");
		out.println(ansx1 + " " + ansy);
		out.println(ansx2 + " " + ansy);
		in.close();
		out.close();
	}

	public static void main(String[] args) {
		new Thread(new bridge_md_assert()).start();
	}
}
