import java.io.*;
import java.util.*;

public class bridge_md_square_on_ridges implements Runnable {
	public static final double eps = 1e-9;
	public static final double infty = 1e10;

	private class Valley implements Comparable<Valley> {
		double ylo, yhi;
		int i, j;
		boolean wide;

		public Valley(double ylo, int i, int j) {
			this.ylo = ylo;
			this.i = i;
			this.j = j;
			yhi = Math.min(y[i], y[j + 1]);
			if ((i > 0) && (j < n - 2))
				check();
		}
		
		public void check() {
			check(ylo);
			check(yhi);
			double xx = x(j, ylo) - x(i, ylo);
			double slope = (x[j + 1] - x[j]) / (y[j + 1] - y[j]) - (x[i + 1] - x[i]) / (y[i + 1] - y[i]);
			double yy = ylo + (l - xx) / slope;
			check(yy);
			check(ay); // optimizable
			check(by);
		}
		
		public void check(double y) {
			if (y < ylo - eps || y > yhi + eps)
				return;
			double x1 = x(i, y);
			double x2 = x(j, y);
			if (x2 < x1 + l + eps) {
				tryBridge(x1, x2);
			} else
				wide = true;
		}

		public int compareTo(Valley that) {
			if (yhi == that.yhi)
				return i - that.i;
			return Double.compare(yhi, that.yhi);
		}
		
		@Override
		public String toString() {
			return i + " " + j + " " + ylo;
		}
	}
	
	private class Landscape {
		TreeSet<Valley> ts = new TreeSet<Valley>();
		
		public void add(Valley v) {
			ts.add(v);
//			System.out.println(y[v.i] + " " + y[v.i + 1] + "       " + y[v.j] + " " + y[v.j + 1]);
		}

		public boolean process() {
			if (ts.isEmpty() || ts.first().yhi == infty)
				return false;
			Valley v = ts.first();
//			System.out.println(y[v.i] + " " + y[v.i + 1] + "       " + y[v.j] + " " + y[v.j + 1]);
//			System.out.println(v.i + " " + v.j);
			Valley u;
			ts.remove(v);
			if (Math.abs(v.yhi - y[v.i]) < eps) {
				while (v.i > 0 && y[v.i] == y[v.i - 1])
					v.i--;
				if (y[v.i - 1] > y[v.i]) {
					u = new Valley(v.yhi, v.i - 1, v.j);
					ts.add(u);
					return true;
				}
				throw new Error("what's going on on the left???");
			}
			int j = v.j;
			while (y[j + 1] == y[j + 2])
				j++;
			j++;
			if (y[j] < y[j + 1]) {
				u = new Valley(v.yhi, v.i, j);
				ts.add(u);
				return true;
			}
			if (j != ts.first().i)
				throw new Error("strange neibour");
			ArrayList<Valley> al = new ArrayList<Valley>();
			al.add(v);
			while (!ts.isEmpty() && ts.first().yhi == v.yhi) {
				al.add(ts.first());
				ts.remove(ts.first());
				if (y[al.get(al.size() - 1).j + 1] != v.yhi)
					break;
			}
			
			for (Valley x : al)
				for (Valley y : al)
					if (x.i < y.j)
						new Valley(v.yhi, x.i, y.j);
			
			u = new Valley(v.yhi, v.i, al.get(al.size() - 1).j);
			ts.add(u);
			return true;
		}
	}
	
	private BufferedReader in;
	private PrintWriter out;

	public void run() {
		try {
			solve();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}
	
	int n, l;
	double[] x;
	double[] y;
	double[] cum;
	double ax, ay, bx, by;
	double ans = 1e100;
	double ansx1, ansx2, ansy;
	Landscape land = new Landscape();
	
	private int edge(double x1) {
		int i = Arrays.binarySearch(x, x1);
		i = (i < 0) ? (-2 - i) : i;
		return (i == n - 1) ? i - 1 : i;
	}
	
	private double y(double x1) {
		int i = edge(x1);
		return y[i] + (y[i + 1] - y[i]) * (x1 - x[i]) / (x[i + 1] - x[i]);
	}
	
	private double x(int i, double y1) {
		return x[i] + (y1 - y[i]) / (y[i + 1] - y[i]) * (x[i + 1] - x[i]);
	}
	
	private double walk(double x1) {
		int i = edge(x1);
		return cum[i] + (x1 - x[i]) / (x[i + 1] - x[i]) * Math.hypot(x[i + 1] - x[i], y[i + 1] - y[i]);
	}

	private double dist(double x1, double x2) {
		if (x1 > x2) {
			double t = x1; x1 = x2; x2 = t;
		}
		return walk(x2) - walk(x1);
	}
	
	private void tryBridge(double xl, double xr) {
		double len = dist(ax, xl) + xr - xl + dist(xr, bx);
//		System.out.println(xl + " " + xr + " " + y(xl) + " " + len);
		if (len < ans) {
			ans = len;
			ansx1 = xl;
			ansx2 = xr;
			ansy = y(xl);
		}
	}
	
	private void solve() throws IOException {
		Locale.setDefault(Locale.US);
		in = new BufferedReader(new FileReader("bridge.in"));
		out = new PrintWriter("bridge.out");
		StringTokenizer st = new StringTokenizer(in.readLine());
		n = Integer.parseInt(st.nextToken());
		l = Integer.parseInt(st.nextToken());
		x = new double[n + 2];
		y = new double[n + 2];
		
		st = new StringTokenizer(in.readLine());
		ax = Integer.parseInt(st.nextToken());
		ay = Integer.parseInt(st.nextToken());
		st = new StringTokenizer(in.readLine());
		bx = Integer.parseInt(st.nextToken());
		by = Integer.parseInt(st.nextToken());
		if (ax > bx) {
			double t = ax; ax = bx; bx = t;
			t = ay; ay = by; by = t;
		}
		
		for (int i = 1; i <= n; i++) {
			st = new StringTokenizer(in.readLine());
			x[i] = Integer.parseInt(st.nextToken());
			y[i] = Integer.parseInt(st.nextToken());
		}
		x[0] = x[1] - 1;
		y[0] = infty;
		x[n + 1] = x[n] + 1;
		y[n + 1] = infty;
		n += 2;
		cum = new double[n];
		for (int i = 1; i < n - 1; i++) {
			cum[i + 1] = cum[i] + Math.hypot(x[i + 1] - x[i], y[i + 1] - y[i]);
		}
		
		tryBridge(ax, ax);
		
		for (int i = 0; i < n - 1; i++) {
			if (y[i] > y[i + 1]) {
				int j = i + 1;
				while (y[j] == y[j + 1])
					j++;
				if (y[j] > y[j + 1])
					continue;
				land.add(new Valley(y[j], i, j));
			}
		}
		
		while (land.process());
		
		out.println(ansx1 + " " + ansy);
		out.println(ansx2 + " " + ansy);
		in.close();
		out.close();
	}

	public static void main(String[] args) {
		new Thread(new bridge_md_square_on_ridges()).start();
	}
}
