#include <cstdio>
#include <cstring>
#include <cstdlib>
#include <cmath>
#include <algorithm>
#include <vector>

using namespace std;

#define eps 1e-6
#define inf 1e20
#define maxn 100010

typedef double dbl;
struct pnt
{
  dbl x, y;
  pnt() { }
  pnt( dbl _x, dbl _y ) { x = _x, y = _y; }
};
pnt Read() { pnt p; scanf("%lf%lf", &p.x, &p.y); return p; }
pnt operator +( pnt a, pnt b ) { return pnt(a.x + b.x, a.y + b.y); }
pnt operator -( pnt a, pnt b ) { return pnt(a.x - b.x, a.y - b.y); }
pnt operator *( pnt a, dbl k ) { return pnt(a.x * k, a.y * k); }
dbl operator !( pnt a ) { return sqrt(a.x * a.x + a.y * a.y); }
bool operator ==( pnt a, pnt b ) { return fabs(a.x - b.x) < eps && fabs(a.y - b.y) < eps; }

int N, A, B;
dbl L, MinD, D[maxn];
pnt Rp1, Rp2;
vector <pnt> p;

int IsIn( pnt a, pnt b, pnt p )
{
  return
    fabs((p.y - a.y) * (b.x - a.x) - (p.x - a.x) * (b.y - a.y)) < eps &&
    min(a.x, b.x) - eps < p.x && p.x < max(a.x, b.x) + eps &&
    min(a.y, b.y) - eps < p.y && p.y < max(a.y, b.y) + eps;
}

int AddPoint( pnt a )
{
  int i;
  for (i = 0; i < p.size(); i++)
    if (p[i] == a)
      return i;
  for (i = 1; i < p.size(); i++)
  {
    if (IsIn(p[i - 1], p[i], a))
    {
      p.insert(p.begin() + i, a);
      N++;
      return i;
    }
  }
  return -1;
}

dbl Dist( int i, int j )
{
  return fabs(D[j] - D[i]);
}

pnt Get( pnt a, pnt b, dbl y )
{
  return a + (b - a) * ((y - a.y) / (b.y - a.y));
}

void Try( pnt a, pnt b, int ai, int bi, int f )
{
  if (ai < A)
    ai++;
  if (bi > B)
    bi--;
  if (fabs(a.x - b.x) < L + eps)
  {
    dbl d = Dist(A, ai) + !(a - p[ai]) + fabs(a.x - b.x) + !(b - p[bi]) + Dist(bi, B);
    if (d < MinD)
    {
      if (f)
        a.x = -a.x, b.x = -b.x;
      MinD = d, Rp1 = a, Rp2 = b;
    }
  }
}

void Solve1( int f )
{
  for (int ri = 0; ri < N; ri++)
  {
    dbl x, maxx = inf;
    int i = 1, mi = 0;
    for (i = ri + 1; i < N; i++)
      if (p[i - 1].y - eps < p[ri].y && p[ri].y < p[i].y - eps)
        if ((x = Get(p[i - 1], p[i], p[ri].y).x) < maxx)
          maxx = x, mi = i;
    pnt end(maxx, p[ri].y);
    Try(p[ri], end, ri, mi, f);
    for (i = 0; i < N; i++)
      if (IsIn(p[ri], end, p[i]))
        Try(p[ri], p[i], ri, i, f);
  }
}

void Do( int i, int ri, pnt a, pnt b, pnt c, pnt d )
{
  if (c.x - b.x > L + eps)
    return;
  Try(b, c, i, ri, 0);
  if (d.x - a.x < L - eps)
    Try(a, d, i, ri, 0);
  else
  {
    dbl k = (L - (c.x - b.x)) / ((d.x - a.x) - (c.x - b.x));
    Try(b + (a - b) * k, c + (d - c) * k, i, ri, 0);
  }
}

void Solve2( void )
{
  for (int ri = 1; ri < N; ri++)
    if (p[ri].y < p[ri - 1].y - eps)
    {
      dbl maxy = p[ri].y;
      for (int i = ri; i + 1 < N; i++)
        if (p[i + 1].y > p[i].y + eps && p[i + 1].y > maxy + eps)
        {
          dbl new_maxy = min(p[i + 1].y, p[ri - 1].y);
          Do(ri - 1, i + 1, Get(p[ri - 1], p[ri], new_maxy), Get(p[ri - 1], p[ri], maxy), Get(p[i], p[i + 1], maxy), Get(p[i], p[i + 1], new_maxy));
          maxy = new_maxy;
          if (maxy + eps > p[ri - 1].y)
            break;
        }
    }
}

int main( void )
{
  freopen("bridge.in", "rt", stdin);
  freopen("bridge.out", "wt", stdout);

  int i, j;
  scanf("%d%lf", &N, &L);
  pnt a = Read(), b = Read();
  for (i = 0; i < N; i++)
    p.push_back(Read());
  A = AddPoint(a);
  int n0 = N;
  B = AddPoint(b);
  if (B <= A && n0 < N)
    A++;
  if (A > B)
    swap(A, B);

  MinD = inf;
  D[0] = 0;
  for (i = 0; i < N; i++)
    D[i + 1] = D[i] + !(p[i + 1] - p[i]);
  for (j = 0; j < 2; j++)
  {
    Solve1(j);
    for (i = 0; i < N; i++)
      p[i].x = -p[i].x;
    for (i = 0; i < N - i - 1; i++)
      swap(p[i], p[N - i - 1]), swap(D[i], D[N - i - 1]);
    A = N - A - 1, B = N - B - 1;
    swap(A, B);
  }
  Solve2();

  printf("%.9lf %.9lf\n%.9lf %.9lf\n", Rp1.x, Rp1.y, Rp2.x, Rp2.y);
  return 0;
}
