#pragma warning (disable:4018)
#include <stdio.h>
#include <vector>

using namespace std;

struct Edge
{
	int x;
	int y;

	Edge(int x, int y)
	{
		this->x = x;
		this->y = y;
	}
};

struct Vertex
{
	bool visit; 
	int zone;

	Vertex()
	{
		visit = false;
		zone = 0;
	}
};


struct Route
{
	bool visit;
	vector<int> v;

	Route()
	{
		visit = false;
	}
};

vector<Vertex> vertices;
vector<Edge> edges;
vector<Route> routes;

int ReadInt()
{
	int res = 0;
	if (scanf("%d", &res) < 1)
		throw "IO error";
	return res;
}

void ReadData()
{
	int n = ReadInt();
	int m = ReadInt();

	for (int i = 0; i < n; i++)
		vertices.push_back(Vertex());

	for (int i = 0; i < m; i++)
	{
		int x = ReadInt()-1;
		int y = ReadInt()-1;

		edges.push_back(Edge(x, y));
	}

	routes.resize(ReadInt());

	for (int i = 0; i < routes.size(); i++)
	{
		Route &r = routes[i];

		while (true)
		{
			int x = ReadInt();
			if (x == 0)
				break;

			r.v.push_back(x-1);
		}
	}
}

void CheckRoute(Route &r, bool &le, bool &ge, bool &eq)
{
	le = false;
	ge = false;
	eq = false;

	for (int i = 0; i < r.v.size()-1; i++)
	{
		Vertex v1 = vertices[r.v[i]];
		Vertex v2 = vertices[r.v[i+1]];

		if (!v1.visit || !v2.visit)
			continue;

		le |= (v1.zone < v2.zone);
		ge |= (v1.zone > v2.zone);
		eq |= (v1.zone == v2.zone);
	}
}

int GetRouteIndex(Route &r)
{
	for (int i = 0; i < r.v.size(); i++)
		if (vertices[r.v[i]].visit)
			return i;
	return -1;
}

bool AddRoute(Route &r)
{
	r.visit = true;

	bool le = false;
	bool ge = false;
	bool eq = false;

	for (int i = 0; i < r.v.size()-2; i++)
	{
		if (r.v[i] == r.v[i+2])
			return false;
	}

	CheckRoute(r, le, ge, eq);

	if (eq || le && ge)
		return false;

	int dir = (ge ? -1: 1);

	Vertex v;
	int index = GetRouteIndex(r);
	if (index >= 0)
	{
		v = vertices[r.v[index]];
		v.zone -= index*dir;
	}

	for (int i = 0; i < r.v.size(); i++)
	{
		vertices[r.v[i]].visit = true;
		vertices[r.v[i]].zone = v.zone+i*dir;
	}

	return true;
}

void Normalize()
{
	int minZone = 0;

	for (int i = 0; i < vertices.size(); i++)
	{
		int zone = vertices[i].zone;
		if (i == 0)
			minZone = zone;
		minZone = min(minZone, zone);
	}

	for (int i = 0; i < vertices.size(); i++)
	{
		vertices[i].zone += 1-minZone;
	}
}

bool Solve1()
{
	bool ok = true;
	for (int i = 0; i < routes.size(); i++)
		ok &= AddRoute(routes[i]);

	return ok;
}

int GetNextRoute()
{
	int index1 = -1;
	int index2 = -1;
	int index3 = -1;

	for (int i = 0; i < routes.size(); i++)
	{
		Route &r = routes[i];
		if (r.visit)
			continue;

		index1 = i;
		
		if (GetRouteIndex(r) >= 0)
			index2 = i;

		bool le, ge, eq;

		CheckRoute(r, le, ge, eq);
		if (le || ge || eq)
			index3 = i;
	}

	if (index3 >= 0)
		return index3;
	if (index2 >= 0)
		return index2;
	if (index1 >= 0)
		return index1;

	return -1;
}

bool Solve2()
{
	bool ok = true;
	while (true)
	{
		int index = GetNextRoute();
		if (index < 0)
			break;

		ok &= AddRoute(routes[index]);
	}

	return ok;
}

void Solve()
{
	bool ok = Solve2();

	Normalize();

	if (!ok)
	{
		printf("NO\n");
		return;
	}

	printf("YES\n");
	for (int i = 0; i < vertices.size(); i++)
		printf("%d ", vertices[i].zone);
	printf("\n");
}

void main()
{
	freopen("rail.in", "r", stdin);
	freopen("rail.out", "w", stdout);
	ReadData();
	Solve();
}