import java.io.*;
import java.util.*;

public class internet_md implements Runnable {
	private class StreetManager {
		HashMap<Long, Row> rows = new HashMap<Long, Row>();
		HashMap<Long, Row> columns = new HashMap<Long, Row>();
		
		public void addRow(long y, long x1, long x2) {
			Row r;
			if (!rows.containsKey(y)) {
				r = new Row(y);
				rows.put(y, r);
			} else
				r = rows.get(y);
			r.fill(x1, x2);
		}

		public void addColumn(long x, long y1, long y2) {
			Row r;
			if (!columns.containsKey(x)) {
				r = new Row(x);
				columns.put(x, r);
			} else
				r = columns.get(x);
			r.fill(y1, y2);
		}

		public long countBlocks() {
			long res = 0;
			for (long y : rows.keySet()) {
				Row r = rows.get(y);
				res += r.process();
			}
			for (long x : columns.keySet()) {
				Row r = columns.get(x);
				res += r.process();
			}
			for (long y : rows.keySet()) {
				for (long x : columns.keySet()) {
					res -= rows.get(y).intersect(columns.get(x));
				}
			}
			return res;
		}
		
	}
	
	private class Row {
		private class Event implements Comparable<Event> {
			long x;
			int  open;
			
			public Event(long x, int open) {
				this.x = x;
				this.open = open;
			}

			public int compareTo(Event that) {
				if (x == that.x)
					return that.open - open;
				if (x < that.x)
					return -1;
				return 1;
			}
		}
		
		long y;
		int mod;
		ArrayList<Event> events = new ArrayList<Event>();
		
		public Row(long y) {
			this.y = y;
			mod = (int) y & 1;
		}

		public void fill(long x1, long x2) {
			x2--;
			if ((x1 & 1) != mod)
				x1++;
			if ((x2 & 1) != mod)
				x2--;
			if (x1 > x2)
				return;
			x1 >>= 1;
			x2 >>= 1;
			events.add(new Event(x1, 1));
			events.add(new Event(x2 + 1, -1));
		}

		public long process() {
			Collections.sort(events);
			int open = 0;
			ArrayList<Event> ev = new ArrayList<Event>();
			for (Event e : events) {
				if (e.open > 0) {
					if (open == 0) {
						ev.add(e);
					}
				} else {
					if (open == 1) {
						ev.add(e);
					}
				}
				open += e.open;
			}
			events = ev;
			long res = 0;
			for (Event e : events) {
				res += e.x * e.open;
				if (e.open < 0)
					e.x--;
			}
			return -res;
		}

		public long intersect(Row row) {
			if ((y & 1) != (row.y & 1))
				return 0;
			return (contains(row.y) && row.contains(y)) ? 1 : 0;
		}

		private boolean contains(long x) {
			x >>= 1;
			Event e = new Event(x, 0);
			int i = Collections.binarySearch(events, e);
			return (i & 1) == 0;
		}
	}
	
	private class Path {
		long x, y, dx, dy, len;
		char dir;
		
		public Path(Scanner in) {
			x = in.nextLong();
			y = in.nextLong();
			dir = in.next().charAt(0);
			dx = (dir == 'E') ? 1 : (dir == 'W') ? -1 : 0;
			dy = (dir == 'N') ? 1 : (dir == 'S') ? -1 : 0;
			len = in.nextLong();
		}

		public long getLength() {
			return len;
		}

		public void setLength(long length) {
			len = length;
		}

		public void printLastBlock() {
			if (dy == 0) {
				x += dx * (len - 1);
				x = Math.min(x, x + dx);
				if ((x & 1) != (y & 1))
					y--;
			} else {
				y += dy * (len - 1);
				y = Math.min(y, y + dy);
				if ((x & 1) != (y & 1))
					x--;
			}
			out.println(x + " " + y);
		}
	}
	
	private Scanner in;
	private PrintWriter out;
	private int n;
	private long k;
	private Path[] path;

	public void run() {
		try {
			solve();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}

	private void solve() throws IOException {
		Locale.setDefault(Locale.US);
		in = new Scanner(new FileReader("internet.in"));
		out = new PrintWriter("internet.out");
		n = in.nextInt();
		k = in.nextLong();
		path = new Path[n];
		for (int i = 0; i < n; i++) {
			path[i] = new Path(in);
		}
		if (countBlocks() < k) {
			out.println("PLEASE WAIT");
			in.close();
			out.close();
			return;
		}
		int left = 0;
		int right = n;
		while (left + 1 < right) {
			n = (left + right) / 2;
			if (countBlocks() >= k)
				right = n;
			else
				left = n;
		}
		n = right;
		long le = 0;
		long ri = path[n - 1].getLength();
		while (le + 1 < ri) {
			long mi = (le + ri) / 2;
			path[n - 1].setLength(mi);
			if (countBlocks() >= k)
				ri = mi;
			else
				le = mi;
		}
		path[n - 1].setLength(ri);
		path[n - 1].printLastBlock();
		in.close();
		out.close();
	}

	private long countBlocks() {
		StreetManager sm = new StreetManager();
		for (int i = 0; i < n; i++) {
			Path p = path[i];
			if (p.dy == 0) {
				long x1 = Math.min(p.x, p.x + p.dx * p.len);
				long x2 = Math.max(p.x, p.x + p.dx * p.len);
				sm.addRow(p.y, x1, x2);
				sm.addRow(p.y - 1, x1, x2);
			} else {
				long y1 = Math.min(p.y, p.y + p.dy * p.len);
				long y2 = Math.max(p.y, p.y + p.dy * p.len);
				sm.addColumn(p.x, y1, y2);
				sm.addColumn(p.x - 1, y1, y2);
			}
		}
		return sm.countBlocks();
	}

	public static void main(String[] args) {
		new Thread(new internet_md()).start();
	}
}
