import java.util.Scanner;
import java.util.Set;
import java.util.HashSet;
import java.util.Arrays;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;

public class internet_pm_wrong1 implements Runnable {
    public void run() {
        try {
            readInput();
            solve();
            writeOutput();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(1);
        }
    }

    static class Action {
        long x0;
        long y0;
        long x1;
        long y1;
    }

    final String TASK_ID = "internet";
    final String IN_FILE = TASK_ID + ".in";
    final String OUT_FILE = TASK_ID + ".out";

    long k;
    Action[] actions;
    boolean isSol;
    long resX;
    long resY;
    boolean[][] used;
    long[] interestingXs;
    long[] interestingYs;


    private void readInput() throws Exception {
        Scanner scanner = new Scanner(new File(IN_FILE));

        int n = scanner.nextInt();
        k = scanner.nextLong();

        actions = new Action[n];

        for (int i = 0; i < n; ++i) {
            Action action = new Action();
            action.x0 = scanner.nextLong();
            action.y0 = scanner.nextLong();
            char dir = scanner.next().charAt(0);
            long len = scanner.nextLong();
            action.x1 = action.x0;
            action.y1 = action.y0;
            switch (dir) {
                case 'N':
                    action.y1 += len;
                    break;

                case 'S':
                    action.y1 -= len;
                    break;

                case 'E':
                    action.x1 += len;
                    break;

                case 'W':
                    action.x1 -= len;
                    break;

                default:
                    throw new Exception();
            }
            actions[i] = action;
        }
    }

    private void writeOutput() throws FileNotFoundException {
        PrintWriter writer = new PrintWriter(OUT_FILE);

        if (isSol)
            writer.println(resX + " " + resY);
        else
            writer.println("PLEASE WAIT");

        writer.close();
    }

    private void solve() {
        Set<Long> interestingXSet = new HashSet<Long>();
        Set<Long> interestingYSet = new HashSet<Long>();
        for (Action action : actions) {
            if (action.x0 == action.x1) {
                interestingXSet.add(action.x0 - 1);
                interestingXSet.add(action.x0);
            } else {
                interestingYSet.add(action.y0 - 1);
                interestingYSet.add(action.y0);
            }
        }
        interestingXSet.add(Long.MIN_VALUE + 1);
        interestingXSet.add(Long.MAX_VALUE - 1);
        interestingYSet.add(Long.MIN_VALUE + 1);
        interestingYSet.add(Long.MAX_VALUE - 1);

        interestingXs = UnwrapArray(interestingXSet.toArray(new Long[0]));
        interestingYs = UnwrapArray(interestingYSet.toArray(new Long[0]));
        Arrays.sort(interestingXs);
        Arrays.sort(interestingYs);

        used = new boolean[interestingXs.length][interestingYs.length];

        isSol = true;

        for (Action action : actions) {
            if (action.x0 == action.x1) {
                long xLeft = action.x0 - 1;
                long xRight = action.x0;
                int xLeftId = Arrays.binarySearch(interestingXs, xLeft);
                int xRightId = Arrays.binarySearch(interestingXs, xRight);
                if (action.y0 < action.y1) {
                    for (int i = 0; i < interestingYs.length - 1; ++i) {
                        long left = Math.max(interestingYs[i], action.y0);
                        long right = Math.min(interestingYs[i + 1], action.y1);

                        if (left >= right)
                            continue;
                        if (left == interestingYs[i]) {
                            if (markCell(xLeftId, i) || markCell(xRightId, i)) return;
                            ++left;
                        }

                        if (right - left >= k) {
                            resY = left + k - 1;
                            if (goodCell(xLeft, resY))
                                resX = xLeft;
                            else
                                resX = xRight;
                            return;
                        } else k -= (right - left);
                    }
                } else {
                    for (int i = interestingYs.length - 1; i >= 1; --i) {
                        long left = Math.max(interestingYs[i - 1] + 1, action.y1);
                        long right = Math.min(interestingYs[i] + 1, action.y0);

                        if (left >= right)
                            continue;
                        if (right == interestingYs[i] + 1) {
                            if (markCell(xLeftId, i) || markCell(xRightId, i)) return;
                            --right;
                        }

                        if (right - left >= k) {
                            resY = right - k;
                            if (goodCell(xLeft, resY))
                                resX = xLeft;
                            else
                                resX = xRight;
                            return;
                        } else k -= (right - left);
                    }
                }
            } else {
                long yLeft = action.y0 - 1;
                long yRight = action.y0;
                int yLeftId = Arrays.binarySearch(interestingYs, yLeft);
                int yRightId = Arrays.binarySearch(interestingYs, yRight);
                if (action.x0 < action.x1) {
                    for (int i = 0; i < interestingXs.length - 1; ++i) {
                        long left = Math.max(interestingXs[i], action.x0);
                        long right = Math.min(interestingXs[i + 1], action.x1);

                        if (left >= right)
                            continue;
                        if (left == interestingXs[i]) {
                            if (markCell(i, yLeftId) || markCell(i, yRightId)) return;
                            ++left;
                        }

                        if (right - left >= k) {
                            resX = left + k - 1;
                            if (goodCell(resX, yLeft))
                                resY = yLeft;
                            else
                                resY = yRight;
                            return;
                        } else k -= (right - left);
                    }
                } else {
                    for (int i = interestingXs.length - 1; i >= 1; --i) {
                        long left = Math.max(interestingXs[i - 1] + 1, action.x1);
                        long right = Math.min(interestingXs[i] + 1, action.x0);

                        if (left >= right)
                            continue;
                        if (right == interestingXs[i] + 1) {
                            if (markCell(i, yLeftId) || markCell(i, yRightId)) return;
                            --right;
                        }

                        if (right - left >= k) {
                            resX = right - k;
                            if (goodCell(resX, yLeft))
                                resY = yLeft;
                            else
                                resY = yRight;
                            return;
                        } else k -= (right - left);
                    }
                }
            }
        }

        isSol = false;

        resX = -1;
        resY = -1;
    }

    private boolean markCell(int xId, int yId) {
        if (!goodCell(interestingXs[xId], interestingYs[yId]))
            return false;
        if (used[xId][yId])
            return false;

        used[xId][yId] = true;
        --k;
        if (k == 0) {
            resX = interestingXs[xId];
            resY = interestingYs[yId];
            return true;
        }
        return false;
    }

    private boolean goodCell(long x, long y) {
        return !((x & 1) != 0 ^ (y & 1) != 0);
    }

    private long[] UnwrapArray(Long[] wrapped) {
        long[] unwrapped = new long[wrapped.length];
        for (int i = 0; i < unwrapped.length; ++i)
            unwrapped[i] = wrapped[i];
        return unwrapped;
    }


    public static void main(String[] args) {
        new Thread(new internet_pm_wrong1()).start();
    }
}
