//  " ..."
// XIV     -  
//  :  , tsarev@rain.ifmo.ru

import java.io.*;
import java.util.*;

public class love_ft implements Runnable {

	private Scanner in;
	private PrintWriter out;

	private final static int MAXCOORD = 10000;
	private final static double EPS = 1e-9;

	private void myAssert(boolean e) {
		if (!e) {
			throw new Error("Assertion failure!!!");
		}
	}

	class Ray {
		double x0;
		double y0;
		double vx;
		double vy;

		public Ray(double x0, double y0, double vx, double vy) {
			this.x0 = x0;
			this.y0 = y0;
			this.vx = vx;
			this.vy = vy;
		}
		
		boolean lineContains(double x, double y) {
			return Math.abs((x - x0) * vy - (y - y0) * vx) < EPS;
		}
		
		double getT(double x, double y) {
			if (Math.abs(vx) > 0) {
				return (x - x0) / vx;
			} else {
				return (y - y0) / vy;
			}
		}

	}

	class Segment {
		double x1, y1, x2, y2;

		public Segment(double x1, double y1, double x2, double y2) {
			this.x1 = x1;
			this.x2 = x2;
			this.y1 = y1;
			this.y2 = y2;
		}

		public Ray toRay() {
			return new Ray(x1, y1, x2 - x1, y2 - y1);
		}

		boolean contains(double x, double y) {
			return Math.abs(Math.hypot(x1 - x2, y1 - y2) - Math.hypot(x - x1, y - y1) - Math.hypot(x - x2, y - y2)) <= EPS;
		}
        
	}

	double raySegmentIntersect(Ray r, Segment s) {
		Ray rs = s.toRay();
		double a1 = r.vx;
		double b1 = -rs.vx;
		double c1 = rs.x0 - r.x0;

		double a2 = r.vy;
		double b2 = -rs.vy;
		double c2 = rs.y0 - r.y0;

		double d = a1 * b2 - a2 * b1;
		
		if (Math.abs(d) < EPS) {
			if (r.lineContains(s.x1, s.y1) && r.lineContains(s.x2, s.y2)) {
				double ll = Math.min(r.getT(s.x1, s.y1), r.getT(s.x2, s.y2));
				double rr = Math.max(r.getT(s.x1, s.y1), r.getT(s.x2, s.y2));
//				System.out.println(ll + " " + rr);
				if (ll >= 0 - EPS) {
					return ll;
				} else if (rr >= 0 - EPS) {
					return 0;
				} else {
					return Double.POSITIVE_INFINITY;
				}
			} else {
				return Double.POSITIVE_INFINITY;
			}
		}

		double t1 = (c1 * b2 - c2 * b1) / d;
		double t2 = (a1 * c2 - a2 * c1) / d;

		if (t1 >= 0 - EPS && 0 - EPS <= t2 && t2 <= 1 + EPS) {
			return t1;
		} else {
			return Double.POSITIVE_INFINITY;
		}
	}

	boolean intersect(Segment s1, Segment s2) {
		double a1 = s1.y1 - s1.y2;
		double b1 = s1.x2 - s1.x1;
		double c1 = - a1 * s1.x1 - b1 * s1.y1;

		double a2 = s2.y1 - s2.y2;
		double b2 = s2.x2 - s2.x1;
		double c2 = - a2 * s2.x1 - b2 * s2.y1;

		double d = a1 * b2 - a2 * b1;

		if (Math.abs(d) <= EPS) {
			return s1.contains(s2.x1, s2.y1) || s1.contains(s2.x2, s2.y2) ||
				   s2.contains(s1.x1, s1.y1) || s2.contains(s1.x2, s1.y2);
		} 
		
		double x = (-c1 * b2 + c2 * b1) / d;
		double y = (-a1 * c2 + a2 * c1) / d;
		return s1.contains(x, y) && s2.contains(x, y);

	}
	
	double solve(Segment fixed, Segment moving, double vx, double vy) {
		return Math.min(
				raySegmentIntersect(new Ray(moving.x1, moving.y1, vx, vy), fixed),
				raySegmentIntersect(new Ray(moving.x2, moving.y2, vx, vy), fixed)
			   );
	}

	private void solve() throws IOException {
		int x1 = in.nextInt();
		myAssert(Math.abs(x1) <= MAXCOORD);
		int y1 = in.nextInt();
		myAssert(Math.abs(y1) <= MAXCOORD);

		int x2 = in.nextInt();
		myAssert(Math.abs(x2) <= MAXCOORD);
		int y2 = in.nextInt();
		myAssert(Math.abs(y2) <= MAXCOORD);

		int x3 = in.nextInt();
		myAssert(Math.abs(x3) <= MAXCOORD);
		int y3 = in.nextInt();
		myAssert(Math.abs(y3) <= MAXCOORD);

		int x4 = in.nextInt();
		myAssert(Math.abs(x4) <= MAXCOORD);
		int y4 = in.nextInt();
		myAssert(Math.abs(y4) <= MAXCOORD);

		int v1x = in.nextInt();
		myAssert(Math.abs(v1x) <= MAXCOORD);
		int v1y = in.nextInt();
		myAssert(Math.abs(v1y) <= MAXCOORD);

		int v2x = in.nextInt();
		myAssert(Math.abs(v2x) <= MAXCOORD);
		int v2y = in.nextInt();
		myAssert(Math.abs(v2y) <= MAXCOORD);

		int v1 = v1x * v1x + v1y * v1y;
		int v2 = v2x * v2x + v2y * v2y;
		if (v1 == 0 && v2 == 0) {
			out.println(-1);
			return;
		}

		myAssert((x1 - x2) * (x1 - x2) + (y1 - y2) * (y1 - y2) > 0);
		myAssert((x3 - x4) * (x3 - x4) + (y3 - y4) * (y3 - y4) > 0);

		Segment s1 = new Segment(x1, y1, x2, y2);
		Segment s2 = new Segment(x3, y3, x4, y4);
		myAssert(!intersect(s1, s2));

		double ans = Double.POSITIVE_INFINITY;

		ans = Math.min(ans, solve(s1, s2, v2x - v1x, v2y - v1y));
		ans = Math.min(ans, solve(s2, s1, v1x - v2x, v1y - v2y));

		if (!Double.isInfinite(ans)) {
			out.println(ans);
		} else {
			out.println(-1);
		}

	}

	public void run() {
		try {
			solve();
		} catch (Exception e) {
			e.printStackTrace();
			System.exit(1);
		} finally {
			out.close();
		}
	}
	
	private love_ft(String name) {
		try {
			in = new Scanner(new File(name + ".in"));
			out = new PrintWriter(new FileWriter(name + ".out"));	
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(239);
		}
	}

	public static void main(String[] args) {
		(new Thread(new love_ft("love"))).start();
	}
}
	