//  " ..."
// XIV     -  
//  :  , tsarev@rain.ifmo.ru

import java.io.*;
import java.util.*;

public class love_ft_vizi implements Runnable {

	private Scanner in;
	private PrintWriter out;

	private final static int MAXCOORD = 10000;
	private final static double EPS = 1e-9;

	String[] clArgs;

	private void myAssert(boolean e) {
		if (!e) {
			throw new Error("Assertion failure!!!");
		}
	}

	class Ray {
		double x0;
		double y0;
		double vx;
		double vy;

		public Ray(double x0, double y0, double vx, double vy) {
			this.x0 = x0;
			this.y0 = y0;
			this.vx = vx;
			this.vy = vy;
		}
		
		boolean lineContains(double x, double y) {
			return Math.abs((x - x0) * vy - (y - y0) * vx) < EPS;
		}
		
		double getT(double x, double y) {
			if (Math.abs(vx) > 0) {
				return (x - x0) / vx;
			} else {
				return (y - y0) / vy;
			}
		}

	}

	class Segment {
		double x1, y1, x2, y2;

		public Segment(double x1, double y1, double x2, double y2) {
			this.x1 = x1;
			this.x2 = x2;
			this.y1 = y1;
			this.y2 = y2;
		}

		public Ray toRay() {
			return new Ray(x1, y1, x2 - x1, y2 - y1);
		}

		boolean contains(double x, double y) {
			return Math.abs(Math.hypot(x1 - x2, y1 - y2) - Math.hypot(x - x1, y - y1) - Math.hypot(x - x2, y - y2)) <= EPS;
		}

		Segment move(double t, double vx, double vy) {
			return new Segment(x1 + vx * t, y1 + vy * t, x2 + vx * t, y2 + vy * t);
		}

		double minX() {
			return Math.min(x1, x2);
		}
		
		double maxX() {
			return Math.max(x1, x2);
		}

		double minY() {
			return Math.min(y1, y2);
		}
		
		double maxY() {
			return Math.max(y1, y2);
		}
        
	}

	double raySegmentIntersect(Ray r, Segment s) {
		Ray rs = s.toRay();
		double a1 = r.vx;
		double b1 = -rs.vx;
		double c1 = rs.x0 - r.x0;

		double a2 = r.vy;
		double b2 = -rs.vy;
		double c2 = rs.y0 - r.y0;

		double d = a1 * b2 - a2 * b1;
		
		if (Math.abs(d) < EPS) {
			if (r.lineContains(s.x1, s.y1) && r.lineContains(s.x2, s.y2)) {
				double ll = Math.min(r.getT(s.x1, s.y1), r.getT(s.x2, s.y2));
				double rr = Math.max(r.getT(s.x1, s.y1), r.getT(s.x2, s.y2));
				if (ll >= 0 - EPS) {
					return ll;
				} else if (rr >= 0 - EPS) {
					return 0;
				} else {
					return Double.POSITIVE_INFINITY;
				}
			} else {
				return Double.POSITIVE_INFINITY;
			}
		}

		double t1 = (c1 * b2 - c2 * b1) / d;
		double t2 = (a1 * c2 - a2 * c1) / d;

		if (t1 >= 0 - EPS && 0 - EPS <= t2 && t2 <= 1 + EPS) {
			return t1;
		} else {
			return Double.POSITIVE_INFINITY;
		}
	}

	boolean intersect(Segment s1, Segment s2) {
		double a1 = s1.y1 - s1.y2;
		double b1 = s1.x2 - s1.x1;
		double c1 = - a1 * s1.x1 - b1 * s1.y1;

		double a2 = s2.y1 - s2.y2;
		double b2 = s2.x2 - s2.x1;
		double c2 = - a2 * s2.x1 - b2 * s2.y1;

		double d = a1 * b2 - a2 * b1;

		if (Math.abs(d) <= EPS) {
			return s1.contains(s2.x1, s2.y1) || s1.contains(s2.x2, s2.y2) ||
				   s2.contains(s1.x1, s1.y1) || s2.contains(s1.x2, s1.y2);
		} 
		
		double x = (-c1 * b2 + c2 * b1) / d;
		double y = (-a1 * c2 + a2 * c1) / d;
		return s1.contains(x, y) && s2.contains(x, y);

	}
	
	double solve(Segment fixed, Segment moving, double vx, double vy) {
		return Math.min(
				raySegmentIntersect(new Ray(moving.x1, moving.y1, vx, vy), fixed),
				raySegmentIntersect(new Ray(moving.x2, moving.y2, vx, vy), fixed)
			   );
	}

	void outputImpossible(double ans, Segment s1, Segment s2, double vx1, double vy1, double vx2, double vy2) {
	    Segment t1 = s1.move(ans, vx1, vy1);
	    Segment t2 = s2.move(ans, vx2, vy2);
		double minX = Math.min(s1.minX(), s2.minX());
		minX = Math.min(minX, Math.min(t1.minX(), t2.minX()));

		double minY = Math.min(s1.minY(), s2.minY());
		minY = Math.min(minY, Math.min(t1.minY(), t2.minY()));

		double maxX = Math.max(s1.maxX(), s2.maxX());
		maxX = Math.max(maxX, Math.max(t1.maxX(), t2.maxX()));

		double maxY = Math.max(s1.maxY(), s2.maxY());
		maxY = Math.max(maxY, Math.max(t1.maxY(), t2.maxY()));

		double un = 100.0 / Math.max(1, Math.max(maxX - minX, maxY - minY));

		out.println("un =" + un + "cm;");

		out.println("beginfig(1)");


	    out.println("pickup pencircle scaled pt;");


	    
	    out.println("fill " + pts(s2.x1, s2.y1, un) + "--" + pts(s2.x2, s2.y2, un) + "--" + 
	    					  pts(t2.x2, t2.y2, un) + "--" + pts(t2.x1, t2.y1, un) + "--cycle withcolor green;");
	    out.println("fill " + pts(s1.x1, s1.y1, un) + "--" + pts(s1.x2, s1.y2, un) + "--" + 
	    					  pts(t1.x2, t1.y2, un) + "--" + pts(t1.x1, t1.y1, un) + "--cycle withcolor green;");

	    out.println("pickup pencircle scaled pt;");
	    out.println("draw " + pts(s1.x1, s1.y1, un) + "--" + pts(s1.x2, s1.y2, un) + "--" + 
	    					  pts(t1.x2, t1.y2, un) + "--" + pts(t1.x1, t1.y1, un) + "--cycle;");

	    out.println("draw " + pts(s2.x1, s2.y1, un) + "--" + pts(s2.x2, s2.y2, un) + "--" + 
	    					  pts(t2.x2, t2.y2, un) + "--" + pts(t2.x1, t2.y1, un) + "--cycle;");

	    out.println("pickup pencircle scaled 4pt;");
	    

	    out.println("draw " + pts(s1.x1, s1.y1, un) + "--" + pts(s1.x2, s1.y2, un) + ";");
	    out.println("draw " + pts(s2.x1, s2.y1, un) + "--" + pts(s2.x2, s2.y2, un) + ";");

		out.println("endfig;");
	    out.println("end.");
	}

	String pts(double x, double y, double un) {
		return "(" + x * un + ", " + y * un + ")"; 
	}

	void outputPossible(double ans, Segment s1, Segment s2, double vx1, double vy1, double vx2, double vy2) {
	    Segment t1 = s1.move(ans, vx1, vy1);
	    Segment t2 = s2.move(ans, vx2, vy2);
		double minX = Math.min(s1.minX(), s2.minX());
		minX = Math.min(minX, Math.min(t1.minX(), t2.minX()));

		double minY = Math.min(s1.minY(), s2.minY());
		minY = Math.min(minY, Math.min(t1.minY(), t2.minY()));

		double maxX = Math.max(s1.maxX(), s2.maxX());
		maxX = Math.max(maxX, Math.max(t1.maxX(), t2.maxX()));

		double maxY = Math.max(s1.maxY(), s2.maxY());
		maxY = Math.max(maxY, Math.max(t1.maxY(), t2.maxY()));

		double un = 100.0 / Math.max(1, Math.max(maxX - minX, maxY - minY));

		out.println("un =" + un + "cm;");

		out.println("beginfig(1)");


	    out.println("pickup pencircle scaled pt;");


	    
	    out.println("fill " + pts(s2.x1, s2.y1, un) + "--" + pts(s2.x2, s2.y2, un) + "--" + 
	    					  pts(t2.x2, t2.y2, un) + "--" + pts(t2.x1, t2.y1, un) + "--cycle withcolor blue;");
	    out.println("fill " + pts(s1.x1, s1.y1, un) + "--" + pts(s1.x2, s1.y2, un) + "--" + 
	    					  pts(t1.x2, t1.y2, un) + "--" + pts(t1.x1, t1.y1, un) + "--cycle withcolor red;");

	    out.println("pickup pencircle scaled pt;");
	    out.println("draw " + pts(s1.x1, s1.y1, un) + "--" + pts(s1.x2, s1.y2, un) + "--" + 
	    					  pts(t1.x2, t1.y2, un) + "--" + pts(t1.x1, t1.y1, un) + "--cycle;");

	    out.println("draw " + pts(s2.x1, s2.y1, un) + "--" + pts(s2.x2, s2.y2, un) + "--" + 
	    					  pts(t2.x2, t2.y2, un) + "--" + pts(t2.x1, t2.y1, un) + "--cycle;");

	    out.println("pickup pencircle scaled 4pt;");
	    

	    out.println("draw " + pts(s1.x1, s1.y1, un) + "--" + pts(s1.x2, s1.y2, un) + ";");
	    out.println("draw " + pts(s2.x1, s2.y1, un) + "--" + pts(s2.x2, s2.y2, un) + ";");

		out.println("endfig;");
	    out.println("end.");
	}

	void printTex(int testNum, double ans) throws IOException {
		PrintWriter out = new PrintWriter(new FileWriter("vizi.tex"));
		out.println("\\documentclass[11pt,a4paper,oneside]{article}");
		out.println("\\usepackage[dvips]{graphicx}");

		out.println("\\begin{document}");
        out.println("\\begin{center}");
        out.println("\\includegraphics{vizi.1}");
		out.println("\\end{center}");
        out.println("\\begin{center}");
		out.println("Fig. 1. Test " + testNum + "\\\\");
		if (Double.isInfinite(ans)) {
			out.println("Answer is -1 (IMPOSSIBLE).");
		} else {
			out.println("Answer is " + ans);
		}
		out.println("\\end{center}");


		out.println("\\end{document}");
		out.close();	
	}

	private void solve() throws IOException {
		int x1 = in.nextInt();
		myAssert(Math.abs(x1) <= MAXCOORD);
		int y1 = in.nextInt();
		myAssert(Math.abs(y1) <= MAXCOORD);

		int x2 = in.nextInt();
		myAssert(Math.abs(x2) <= MAXCOORD);
		int y2 = in.nextInt();
		myAssert(Math.abs(y2) <= MAXCOORD);

		int x3 = in.nextInt();
		myAssert(Math.abs(x3) <= MAXCOORD);
		int y3 = in.nextInt();
		myAssert(Math.abs(y3) <= MAXCOORD);

		int x4 = in.nextInt();
		myAssert(Math.abs(x4) <= MAXCOORD);
		int y4 = in.nextInt();
		myAssert(Math.abs(y4) <= MAXCOORD);

		int v1x = in.nextInt();
		myAssert(Math.abs(v1x) <= MAXCOORD);
		int v1y = in.nextInt();
		myAssert(Math.abs(v1y) <= MAXCOORD);

		int v2x = in.nextInt();
		myAssert(Math.abs(v2x) <= MAXCOORD);
		int v2y = in.nextInt();
		myAssert(Math.abs(v2y) <= MAXCOORD);

		myAssert((x1 - x2) * (x1 - x2) + (y1 - y2) * (y1 - y2) > 0);
		myAssert((x3 - x4) * (x3 - x4) + (y3 - y4) * (y3 - y4) > 0);

		Segment s1 = new Segment(x1, y1, x2, y2);
		Segment s2 = new Segment(x3, y3, x4, y4);
		myAssert(!intersect(s1, s2));

		int v1 = v1x * v1x + v1y * v1y;
		int v2 = v2x * v2x + v2y * v2y;
		if (v1 == 0 && v2 == 0) {
			outputImpossible(1, s1, s2, v1x, v1y, v2x, v2y);
			return;
		}


		double ans = Double.POSITIVE_INFINITY;

		ans = Math.min(ans, solve(s1, s2, v2x - v1x, v2y - v1y));
		ans = Math.min(ans, solve(s2, s1, v1x - v2x, v1y - v2y));

		printTex(Integer.parseInt(clArgs[0]), ans);

		if (!Double.isInfinite(ans)) {
//			out.println(ans);
			outputPossible(ans, s1, s2, v1x, v1y, v2x, v2y);
		} else {
//			out.println(-1);
			outputImpossible(1, s1, s2, v1x, v1y, v2x, v2y);
		}

	}

	public void run() {
		try {
			solve();
		} catch (Exception e) {
			e.printStackTrace();
			System.exit(1);
		} finally {
			out.close();
		}
	}
	
	private love_ft_vizi(String name, String[] args) {
		clArgs = args;
		try {
			in = new Scanner(new File(name + ".in"));
			out = new PrintWriter(new FileWriter("vizi.mp"));	
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(239);
		}
	}

	public static void main(String[] args) {
		(new Thread(new love_ft_vizi("love", args))).start();
	}
}
	