#include <stdio.h>

#define PROBLEM_ID          "love"
#define MIN(a, b)           (((a) < (b)) ? (a) : (b));
#define INF                 1e100
#define eps                 1e-6

int bt(double x, double a, double b) {
    return ((a < x + eps) && (x < b + eps)) || ((b < x + eps) && (x < a + eps));
}

double calc(int x, int y, int vx, int vy, int x1, int y1, int x2, int y2) {
    int a = y2 - y1;
    int b = x1 - x2;
    int c = -a * x1 - b * y1;
    int u = a * vx + b * vy;
    int v = a * x + b * y + c;
    double time1, time2;
    double curX, curY;

    if (vx == 0 && vy == 0)
        return INF;

    if (a == 0 && b == 0) {
        if (vx * (y1 - y) != vy * (x1 - x))
            return INF;
    }

    if (u != 0) {
        time1 = ((double) -v) / u;
        if (time1 < eps)
            return INF;

        curX = x + time1 * vx;
        curY = y + time1 * vy;
        if (!bt(curX, x1, x2) || !bt(curY, y1, y2))
            return INF;

        return time1;
    }

    if (v != 0) {
        return INF;
    }

    if (vx != 0) {
        time1 = ((double) (x1 - x)) / vx;
    } else {
        time1 = ((double) (y1 - y)) / vy;
    }

    if (vx != 0) {
        time2 = ((double) (x2 - x)) / vx;
    } else {
        time2 = ((double) (y2 - y)) / vy;
    }

    if (time1 < 0) {
        time1 = INF;
    }
    if (time2 < 0) {
        time2 = INF;
    }

    return MIN(time1, time2);
}

int main() {
    double time, time1, time2, time3, time4;
    int x1, y1, x2, y2, x3, y3, x4, y4;
    int v1x, v1y, v2x, v2y;

    freopen(PROBLEM_ID".in", "r", stdin);
    freopen(PROBLEM_ID".out", "w", stdout);

    scanf("%d %d %d %d", &x1, &y1, &x2, &y2);
    scanf("%d %d %d %d", &x3, &y3, &x4, &y4);
    scanf("%d %d %d %d", &v1x, &v1y, &v2x, &v2y);

    time1 = calc(x1, y1, v1x - v2x, v1y - v2y, x3, y3, x4, y4);
    time2 = calc(x2, y2, v1x - v2x, v1y - v2y, x3, y3, x4, y4);
    time3 = calc(x3, y3, v2x - v1x, v2y - v1y, x1, y1, x2, y2);
    time4 = calc(x4, y4, v2x - v1x, v2y - v1y, x1, y1, x2, y2);

    time = MIN(time1, time2);
    time = MIN(time, time3);
    time = MIN(time, time4);

    if (time == INF) {
        printf("-1\n");
    } else {
        printf("%.10lf\n", time);
    }
    return 0;
}
