import java.io.*;
import java.util.*;

public class maze_ia implements Runnable {

	private static final int INF = 1000000000;
	private BufferedReader in;
	private PrintWriter out;
	
	final int[] di = {0, 0, 0, 0, 1};
	final int[] dj = {1, -1, 0, 0, 0};
	final int[] dk = {0, 0, 1, -1, 0};

	public void run() {
		try {
			solve();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}

	private void solve() throws IOException {
		Locale.setDefault(Locale.US);
		in = new BufferedReader(new FileReader("maze.in"));
		out = new PrintWriter("maze.out");
		String str = in.readLine();
		Scanner scan = new Scanner(str);
		int h = scan.nextInt();
		int m = scan.nextInt();
		int n = scan.nextInt();
		myAssert((h >= 2) && (h <= 50), "h is not in range [2...50]");		
		myAssert((m >= 2) && (m <= 50), "m is not in range [2...50]");		
		myAssert((n >= 2) && (n <= 50), "n is not in range [2...50]");
		myAssert((h + " " + m + " " + n).equals(str), "Extra spaces in first line");
		
		boolean[][][] a = new boolean[h][m][n];
		int si = -1;
		int sj = -1;
		int sk = -1;
		
		int ti = -1;
		int tj = -1;
		int tk = -1;
		
		for (int i = 0; i < h; i++) {
			for (int j = 0; j < m; j++) {
				String s = in.readLine();
				myAssert(s.length() == n, "");
				for (int k = 0; k < n; k++) {
					char c = s.charAt(k);
					if (c == '.') {
						a[i][j][k] = false;
					} else if (c == 'o') {
						a[i][j][k] = true;
					} else if (c == '1') {
						a[i][j][k] = false;
						myAssert((si == -1), "Two start points in test");
						myAssert(i == 0, "Start point is not on the top level");
						si = i;
						sj = j;
						sk = k;						
					} else if (c == '2') {
						a[i][j][k] = false;
						myAssert((ti == -1), "Two end points in test");
						myAssert(i == h - 1, "End point is not on the bottom level");
						ti = i;
						tj = j;
						tk = k;						
					} else {
						myAssert(false, "Bad character");
					}
				}				
			}
			String s = in.readLine();
			if (i == h - 1) {
				myAssert(s == null, "Extra lines");
			} else {
				myAssert(s.equals(""), "Extra characters");
			}
		}
		
		int[][][] d = new int[h][m][n];
		for (int i = 0; i < h; i++) {
			for (int j = 0; j < m; j++) {
				for (int k = 0; k < n; k++) {
					d[i][j][k] = INF;
				}
			}
		}
		
		int[] qi = new int[h * m * n];
		int[] qj = new int[h * m * n];
		int[] qk = new int[h * m * n];
		int b = 0;
		int e = 1;
		qi[0] = si;
		qj[0] = sj;
		qk[0] = sk;
		d[si][sj][sk] = 0;
		while (b < e) {
			int i = qi[b];
			int j = qj[b];
			int k = qk[b];
			b++;
			for (int z = 0; z < 5; z++) {
				int ii = i + di[z];
				int jj = j + dj[z];
				int kk = k + dk[z];
				if ((ii >= h) || (jj < 0) || (jj >= m) || (kk < 0) || (kk >= n) || a[ii][jj][kk]) {
					continue;
				}
				if (d[ii][jj][kk] > d[i][j][k] + 1) {
					d[ii][jj][kk] = d[i][j][k] + 1;
					qi[e] = ii;
					qj[e] = jj;
					qk[e] = kk;					
					e++;
				}				
			}			
		}
		myAssert(d[ti][tj][tk] < INF, "No way in input file");
		out.println(d[ti][tj][tk] * 5);
		in.close();
		out.close();
	}

	private void myAssert(boolean b, String message) {
		if (!b) {
			message = "Internal error or invalid input file: " + message;
			System.out.println(message);
			out.println(message);
			out.close();
			System.exit(239);
		}
	}

	public static void main(String[] args) {
		new Thread(new maze_ia()).start();
	}

}
