#include <cassert>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <sstream>
#include <string>
#include <vector>

#define TASKNAME "primesum"

using namespace std;

typedef long long int64;
typedef pair <string, int64> tuple;
const int MaxN = 9, MaxK = 63;

tuple c [MaxN];

void mulmod (int64 & a, int64 b, int64 n)
{
 int i;
 int64 cur, res;
 cur = a;
 res = 0;
 for (i = 0; i < MaxK; i++)
 {
  if ((b >> i) & 1)
  {
   res += cur;
   if (res >= n) res -= n;
  }
  cur <<= 1;
  if (cur >= n) cur -= n;
 }
 a = res;
}

void powmod (int64 & a, int64 d, int64 n)
{
 int i;
 int64 b;
 b = a;
 a = 1;
 for (i = 0; i < MaxK; i++)
 {
  if ((d >> i) & 1)
   mulmod (a, b, n);
  mulmod (b, b, n);
 }
}

bool test_mr (int64 a, int64 n)
{
 int r, s;
 int64 d;
 d = n - 1;
 for (s = 0; !(d & 1); s++) d >>= 1;
 powmod (a, d, n);
 if (a == 1) return true;
 for (r = 0; r < s; r++)
 {
  if (a == n - 1) return true;
  mulmod (a, a, n);
 }
 return false;
}

bool is_prime (int64 n)
{
 assert (n > 1);
 if (n == 2) return true;
 if (!(n & 1)) return false;
 if (n ==  2) return true; else if (!test_mr ( 2, n)) return false;
 if (n ==  3) return true; else if (!test_mr ( 3, n)) return false;
 if (n ==  5) return true; else if (!test_mr ( 5, n)) return false;
 if (n ==  7) return true; else if (!test_mr ( 7, n)) return false;
 if (n == 11) return true; else if (!test_mr (11, n)) return false;
 if (n == 13) return true; else if (!test_mr (13, n)) return false;
 if (n == 17) return true; else if (!test_mr (17, n)) return false;
 if (n == 19) return true; else if (!test_mr (19, n)) return false;
 return true;
}

string STL_to_str (int64 n)
{
 stringstream buf;
 buf << n;
 return buf.str ();
}

string to_string (int64 n)
{
 int i;
 string s = "";
 for (i = 0; i < MaxN; i++)
 {
  while (c[i].second == n || c[i].second < n - 1)
  {
   if (!s.empty ()) s += '+';
   s += c[i].first;
   n -= c[i].second;
  }
 }
 if (n > 0)
 {
  if (!s.empty ()) s += '+';
  s += STL_to_str (n);
 }
 return s;
}

void out (string s)
{
 printf ("%s\n", s.c_str ());
}

int main (void)
{
 int i;
 int64 n, p;
 freopen (TASKNAME ".in", "rt", stdin);
 freopen (TASKNAME ".out", "wt", stdout);
 n = 1;
 for (i = 0; i < MaxN; i++)
 {
  n++;
  for (p = n; !is_prime (p); p += 2) ;
  c[i].second = p;
  c[i].first = STL_to_str (c[i].second);
  n--;
  n *= 10;
 }
 sort (c, c + MaxN);
 while (scanf (" %I64d", &n) != EOF)
  out (to_string (n));
 return 0;
}
