import java.util.Scanner;
import java.util.List;
import java.util.ArrayList;
import java.util.Collections;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;

public class cross_pm implements Runnable {
    public static void main(String[] args) {
        new Thread(new cross_pm()).start();
    }

    public void run() {
        try {
            readInput();
            solve();
            writeOutput();
        } catch (Exception ex) {
            ex.printStackTrace();
            System.exit(1);
        }
    }

    static class Vertex {
        public List<Edge> incoming = new ArrayList<Edge>();
        public List<Edge> outgoing = new ArrayList<Edge>();
        Edge prevBy = null;
        int dist = -1;
        boolean visited = false;
        boolean inStack = false;
    }

    static class Edge {
        public Vertex start;
        public Vertex end;
        public int id;
        public boolean take = false;

        public Edge(Vertex start, Vertex end, int id) {
            this.start = start;
            this.end = end;
            this.id = id;
        }
    }

    List<Vertex> vertices = new ArrayList<Vertex>();
    List<Edge> edges = new ArrayList<Edge>();
    List<Vertex> order = new ArrayList<Vertex>();
    boolean haveSol;

    private void dfs(Vertex v) {
        if (v.inStack)
            throw new RuntimeException("Cycle detected.");

        if (v.visited)
            return;
        v.visited = true;
        v.inStack = true;

        for (Edge e : v.outgoing)
            dfs(e.end);

        v.inStack = false;
        order.add(v);
    }

    private boolean dfs2(Vertex v) {
        if (v.visited)
            throw new RuntimeException("Something went wrong.");

        v.visited = true;
        v.inStack = true;

        for (Edge e : v.incoming)
            if (!e.start.inStack)
                return false;

        for (Edge e : v.outgoing)
            if (e.take)
                if (!dfs2(e.end))
                    return false;

        v.inStack = false;
        return true;
    }

    private void solve() {
        haveSol = false;

        Vertex source = null;
        for (Vertex vertex : vertices)
            if (vertex.incoming.size() == 0) {
                if (source == null)
                    source = vertex;
                else
                    return;
            }
        if (source == null)
            return;

        dfs(source);
        if (order.size() != vertices.size())
            return;
        Collections.reverse(order);

        source.dist = 0;
        for (Vertex v : order) {
            if (v.prevBy != null)
                v.prevBy.take = true;
            for (Edge e : v.outgoing)
                if (e.end.prevBy == null || e.end.dist < v.dist + 1) {
                    e.end.dist = v.dist + 1;
                    e.end.prevBy = e;
                }
        }

        for (Vertex vertex : vertices)
            vertex.visited = false;

        haveSol = dfs2(source);
    }

    private void writeOutput() throws FileNotFoundException {
        PrintWriter writer = new PrintWriter("cross.out");
        if (haveSol) {
            writer.println(vertices.size() - 1);
            boolean first = true;
            for (Edge edge : edges)
                if (edge.take) {
                    if (first)
                        first = false;
                    else
                        writer.print(" ");
                    writer.print(edge.id);
                }
            writer.println();
        } else {
            writer.println(-1);
        }
        writer.close();
    }

    private void readInput() throws FileNotFoundException {
        Scanner scanner = new Scanner(new File("cross.in"));
        int n = scanner.nextInt();
        for (int i = 0; i < n; ++i)
            vertices.add(new Vertex());
        int m = scanner.nextInt();
        for (int i = 0; i < m; ++i) {
            Vertex a = vertices.get(scanner.nextInt() - 1);
            Vertex b = vertices.get(scanner.nextInt() - 1);
            Edge e = new Edge(a, b, i + 1);
            a.outgoing.add(e);
            b.incoming.add(e);
            edges.add(e);
        }
    }
}
