/* This program uses Allegro library version 4.1.x or higher.
   Visit http://allegro.cc to obtain information on the library. */
#include <cassert>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <allegro.h>
#include "chains.h"
#include "global.h"
#include "random.h"
#include "types.h"

const int MaxX = 800, MaxY = 600, MidX = MaxX >> 1, MidY = MaxY >> 1;
const int BorderX = 241, BorderY = 201, MinXW = BorderX, MinYW = BorderY,
 MaxXW = MaxX - BorderX, MaxYW = MaxY - BorderY;
const real Radius = 0.2, Under = 0.075;
const real MinScale = 10.0, MaxScale = 150.0, ScaleMult = 0.005;
const real MaxAngle = M_PI * 2.0, Delta = MaxAngle / 256.0;
enum Colours {COLOUR_BACK, COLOUR_GRID, COLOUR_LINE,
 COLOUR_CIRCLE0, COLOUR_CIRCLE1, COLOUR_CIRCLE0Z, COLOUR_CIRCLE1Z,
 COLOUR_BORDER, COLOUR_NUM};
int colour [COLOUR_NUM];

BITMAP * gbuf [2];
int gb_cur;
bool kb_poll;

const int MaxL2 = MaxL << 4;
int p [MaxL2], ap [MaxL2];
real xp [MaxL2], yp [MaxL2], zp [MaxL2];
real alpha, beta;
real Scale;

inline void poll_kb (void)
{
 if (kb_poll) poll_keyboard ();
}

void try_init (bool res, const char * str)
{
 if (res) printf ("%s init OK.\n", str);
 else
 {
  printf ("%s init failed!\n", str);
  exit (EXIT_FAILURE);
 }
}

void init_kb (void)
{
 try_init (install_keyboard () != -1, "Keyboard");
 kb_poll = keyboard_needs_poll ();
}

void init (void)
{
 try_init (allegro_init () == 0, "Allegro");
 init_kb ();
 set_color_depth (32);
 try_init (set_gfx_mode (GFX_AUTODETECT_WINDOWED, MaxX, MaxY, 0, 0) == 0,
  "Graphics");

 gb_cur = 0;
 gbuf[0] = create_video_bitmap (MaxX, MaxY);
 gbuf[1] = create_video_bitmap (MaxX, MaxY);

 colour[COLOUR_BACK]     = 0x00000000;
 colour[COLOUR_GRID]     = 0x00404040;
 colour[COLOUR_LINE]     = 0x00DFDFDF;
 colour[COLOUR_CIRCLE0]  = 0x0020F020;
 colour[COLOUR_CIRCLE1]  = 0x002020F0;
 colour[COLOUR_CIRCLE0Z] = 0x0050FF50;
 colour[COLOUR_CIRCLE1Z] = 0x005050FF;
 colour[COLOUR_BORDER]   = 0x00202020;

 init_random ();
}

void happy_end (void)
{
 destroy_bitmap (gbuf[0]);
 destroy_bitmap (gbuf[1]);
 allegro_exit ();
 printf ("Successful termination.\n");
 fflush (stdout);
 exit (EXIT_SUCCESS);
}

void draw ()
{
 gb_cur ^= 1;
 BITMAP * gcur = gbuf[gb_cur];
 int d, i, j, k, m, xc, yc, zc;
 int minx, miny, minz, maxx, maxy, maxz;
 real sina, cosa, sinb, cosb;
 sina = sin (alpha);
 cosa = cos (alpha);
 sinb = sin (beta);
 cosb = cos (beta);
 acquire_bitmap (gcur);
 clear_to_color (gcur, colour[COLOUR_BACK]);
 minx = miny = minz = MaxC;
 maxx = maxy = maxz = -MaxC;
 for (i = 0; i < n; i++)
 {
  if (minx > x[i]) minx = x[i];
  if (maxx < x[i]) maxx = x[i];
  if (miny > y[i]) miny = y[i];
  if (maxy < y[i]) maxy = y[i];
  if (minz > z[i]) minz = z[i];
  if (maxz < z[i]) maxz = z[i];
 }
 for (i = minx; i <= maxx; i++)
  for (j = miny; j <= maxy; j++)
  {
   k = minz;
   xp[0] = (i * cosa + j * sina);
   yp[0] = (-i * sina + j * cosa) * cosb + k * sinb;
   k = maxz;
   xp[1] = (i * cosa + j * sina);
   yp[1] = (-i * sina + j * cosa) * cosb + k * sinb;
   line (gcur,
    MidX + int (xp[0] * Scale),
    MidY - int (yp[0] * Scale),
    MidX + int (xp[1] * Scale),
    MidY - int (yp[1] * Scale),
    colour[COLOUR_GRID]);
  }
 for (i = minx; i <= maxx; i++)
  for (k = minz; k <= maxz; k++)
  {
   j = miny;
   xp[0] = (i * cosa + j * sina);
   yp[0] = (-i * sina + j * cosa) * cosb + k * sinb;
   j = maxy;
   xp[1] = (i * cosa + j * sina);
   yp[1] = (-i * sina + j * cosa) * cosb + k * sinb;
   line (gcur,
    MidX + int (xp[0] * Scale),
    MidY - int (yp[0] * Scale),
    MidX + int (xp[1] * Scale),
    MidY - int (yp[1] * Scale),
    colour[COLOUR_GRID]);
  }
 for (j = miny; j <= maxy; j++)
  for (k = minz; k <= maxz; k++)
  {
   i = minx;
   xp[0] = (i * cosa + j * sina);
   yp[0] = (-i * sina + j * cosa) * cosb + k * sinb;
   i = maxx;
   xp[1] = (i * cosa + j * sina);
   yp[1] = (-i * sina + j * cosa) * cosb + k * sinb;
   line (gcur,
    MidX + int (xp[0] * Scale),
    MidY - int (yp[0] * Scale),
    MidX + int (xp[1] * Scale),
    MidY - int (yp[1] * Scale),
    colour[COLOUR_GRID]);
  }
 for (i = 0; i < n; i++)
 {
  xp[i] = (x[i] * cosa + y[i] * sina);
  yp[i] = (-x[i] * sina + y[i] * cosa) * cosb + z[i] * sinb;
  zp[i] = -(-x[i] * sina + y[i] * cosa) * sinb + z[i] * cosb;
 }
 for (i = 0; i < n - 1; i++)
 {
  xp[i + n] = (xp[i] + xp[i + 1]) * 0.5;
  yp[i + n] = (yp[i] + yp[i + 1]) * 0.5;
  zp[i + n] = (zp[i] + zp[i + 1]) * 0.5;
 }
 for (i = 0; i < n; i++)
  ap[i] = a[i];
 m = (n * 2) - 1;
 for (i = 0; i < n; i++)
 {
  for (d = 0; d < MaxD; d++)
  {
   xc = x[i] + dx[d];
   yc = y[i] + dy[d];
   zc = z[i] + dz[d];
   for (j = 0; j < n; j++)
    if (xc == x[j] && yc == y[j] && zc == z[j])
     break;
   if (ap[i] == 0 && j < n && ap[j] == 0 || ap[i] == 1 && j == n)
   {
    xp[m] = (xc * cosa + yc * sina);
    yp[m] = (-xc * sina + yc * cosa) * cosb + zc * sinb;
    zp[m] = -(-xc * sina + yc * cosa) * sinb + zc * cosb;
    xp[m] = xp[m] * (Radius + Under) + xp[i] * (1.0 - Radius - Under);
    yp[m] = yp[m] * (Radius + Under) + yp[i] * (1.0 - Radius - Under);
    zp[m] = zp[m] * (Radius + Under) + zp[i] * (1.0 - Radius - Under);
    ap[m] = ap[i];
    m++;
    xp[m] = (xc * cosa + yc * sina);
    yp[m] = (-xc * sina + yc * cosa) * cosb + zc * sinb;
    zp[m] = -(-xc * sina + yc * cosa) * sinb + zc * cosb;
    xp[m] = xp[m] * ((Radius + Under / 6.0) * 2.0)
          + xp[i] * (1.0 - (Radius + Under / 6.0) * 2.0);
    yp[m] = yp[m] * ((Radius + Under / 6.0) * 2.0)
          + yp[i] * (1.0 - (Radius + Under / 6.0) * 2.0);
    zp[m] = zp[m] * ((Radius + Under / 6.0) * 2.0)
          + zp[i] * (1.0 - (Radius + Under / 6.0) * 2.0);
    ap[m] = ap[i];
    m++;
   }
  }
 }
 for (i = 0; i < m; i++) p[i] = i;
 for (i = 0; i < m - 1; i++)
  for (j = i + 1; j < m; j++)
   if (zp[p[i]] < zp[p[j]])
   {
    k = p[i]; p[i] = p[j]; p[j] = k;
   }
 for (i = 0; i < m; i++)
  if (p[i] >= n && p[i] < (n * 2) - 1)
  {
   line (gcur,
    MidX + int ((xp[p[i] - n] * Radius + xp[p[i] - n + 1] * (1.0 - Radius))
     * Scale),
    MidY - int ((yp[p[i] - n] * Radius + yp[p[i] - n + 1] * (1.0 - Radius))
     * Scale),
    MidX + int ((xp[p[i] - n] * (1.0 - Radius) + xp[p[i] - n + 1] * Radius)
     * Scale),
    MidY - int ((yp[p[i] - n] * (1.0 - Radius) + yp[p[i] - n + 1] * Radius)
     * Scale),
    colour[COLOUR_LINE]);
  }
  else if (p[i] < n)
  {
   circlefill (gcur,
    MidX + int (xp[p[i]] * Scale),
    MidY - int (yp[p[i]] * Scale),
    int (Radius * Scale),
    ap[p[i]] ? colour[COLOUR_CIRCLE1] : colour[COLOUR_CIRCLE0]);
   circle (gcur,
    MidX + int (xp[p[i]] * Scale),
    MidY - int (yp[p[i]] * Scale),
    int (Radius * Scale),
    colour[COLOUR_BORDER]);
  }
  else
  {
   circlefill (gcur,
    MidX + int (xp[p[i]] * Scale),
    MidY - int (yp[p[i]] * Scale),
    int (Under * Scale),
    ap[p[i]] ? colour[COLOUR_CIRCLE1Z] : colour[COLOUR_CIRCLE0Z]);
   circle (gcur,
    MidX + int (xp[p[i]] * Scale),
    MidY - int (yp[p[i]] * Scale),
    int (Under * Scale),
    colour[COLOUR_BORDER]);
  }
 release_bitmap (gcur);
 show_video_bitmap (gcur);
}

int main (void)
{
 init ();

 int test;
 int kb, kc;
 bool End1 = false;
 alpha = beta = 0.0;
 Scale = 50.0;

 test = 1;
 load_ans (test);
 centerize ();

 while (!End1)
 {
  draw ();
  rest (1);
  poll_kb ();
  if (key[KEY_INSERT])
  {
   if (Scale < MaxScale) Scale *= (1.0 + ScaleMult);
  }
  if (key[KEY_DEL])
  {
   if (Scale > MinScale) Scale *= (1.0 - ScaleMult);
  }
  if (key[KEY_PGUP])
  {
   test--;
   if (load_ans (test)) centerize ();
   else test++;
   rest (200);
  }
  if (key[KEY_PGDN])
  {
   test++;
   if (load_ans (test)) centerize ();
   else test--;
   rest (200);
  }
  if (key[KEY_LEFT])
  {
   alpha -= Delta;
   if (alpha < 0) alpha += MaxAngle;
  }
  if (key[KEY_RIGHT])
  {
   alpha += Delta;
   if (alpha > MaxAngle) alpha -= MaxAngle;
  }
  if (key[KEY_UP])
  {
   beta -= Delta;
   if (beta < 0) beta += MaxAngle;
  }
  if (key[KEY_DOWN])
  {
   beta += Delta;
   if (beta > MaxAngle) beta -= MaxAngle;
  }
  if (key[KEY_Q]) End1 = true;
  if (key[KEY_ESC]) End1 = true;
  while (keypressed ()) kb = ureadkey (&kc);
 }

 happy_end ();
 return 0;
}
END_OF_MAIN ()
