#include <fstream>
#include <vector>
#include <iostream>
#include <cmath>
using namespace std;

const long double eps = 1e-12;
const long double PI = 3.1415926535897932384626433832795;
const int MAXN = 110000;

class Point
{
public:
	long double x, y;
};

int n;
Point pnt[MAXN + 1];

void Load()
{
	scanf("%d", &n);
	int i;
	for (i = 1; i <= n; i++)
	{
	 	int x, y;
	 	scanf("%d%d", &x, &y);
	 	pnt[i].x = x;
	 	pnt[i].y = y;
	}
}

int prv[MAXN];
int nxt[MAXN];

class Segment
{
public:
	int id;
	long double bonus;
};

long double GetBonus(int pos)
{
	long double v1x, v1y, v2x, v2y, ang1, ang2;
	v1x = pnt[prv[pos]].x - pnt[pos].x;
	v1y = pnt[prv[pos]].y - pnt[pos].y;
	v2x = pnt[nxt[pos]].x - pnt[pos].x;
	v2y = pnt[nxt[pos]].y - pnt[pos].y;
	ang1 = atan2(v1x * v2y - v1y * v2x, v1x * v2x + v1y * v2y);
	if (ang1 < -eps) ang1 += 2 * PI;
	if (ang1 - PI > eps) ang1 = 2 * PI - ang1;
	ang1 = ang1 / PI * 180;
	v1x = pnt[nxt[nxt[pos]]].x - pnt[nxt[pos]].x;
	v1y = pnt[nxt[nxt[pos]]].y - pnt[nxt[pos]].y;
	v2x = -v2x;
	v2y = -v2y;
	ang2 = atan2(v1x * v2y - v1y * v2x, v1x * v2x + v1y * v2y);
	if (ang2 < -eps) ang2 += 2 * PI;
	if (ang2 - PI > eps) ang2 = 2 * PI - ang2;
	ang2 = ang2 / PI * 180;
	return ang1 * ang2;
}

bool operator<(const Segment &a, const Segment &b)
{
	if (a.bonus - b.bonus < -eps) return true;
	if (a.bonus - b.bonus > eps) return false;
	if (a.id < b.id) return true;
	if (a.id > b.id) return false;
	return false;
}

vector<Segment> seg;
int alive[MAXN];

void Solve()
{
	int i;
	for (i = 1; i <= n; i++)
	{
		if (i == 1) prv[i] = n;
		else prv[i] = i - 1;
		if (i == n) nxt[i] = 1;
		else nxt[i] = i + 1;
	}
	for (i = 1; i <= n; i++)
	{
		Segment a;
		a.id = i;
		a.bonus = GetBonus(i);
		seg.push_back(a);
	}
	sort(seg.begin(), seg.end());
	memset(alive, 0, sizeof(alive));
	long double res = 0;
	for (i = seg.size() - 1; i >= 0; i--)
	{
		if ((alive[nxt[seg[i].id]] == 1) || (alive[prv[seg[i].id]] == 1)) continue;
		alive[seg[i].id] = 1;
		res += seg[i].bonus;
	}
	cout.setf(ios::fixed | ios::showpoint);
	cout.precision(3);
	cout << res;
}

int main()
{
	freopen("road.in", "rt", stdin);
	freopen("road.out", "wt", stdout);
	Load();
	Solve();
	return 0;
}