#include <string>
#include <vector>
#include <cmath>
#include <map>
#include <algorithm>
#include <set>
#include <iostream>
#include <sstream>
#include <cstdio>
#include <cassert>
#include <utility>
#include <windows.h>
#include "gameunit.h"

using namespace std;

#define EPS 1E-8
#define INF ((int)1E+9)

#define forn(i, n) for (int i = 0; i < int(n); i++)
#define forv(i, a) for (int i = 0; i < int(a.size()); i++)
#define fors(i, a) for (int i = 0; i < int(a.length()); i++)
#define all(a) a.begin(), a.end()
#define pb push_back
#define mp make_pair
#define VI vector<int>
#define VS vector<string>

#define norm(a) sort(all(a)); a.erase(unique(all(a)), a.end());
#define num(a, v) (int)(lower_bound(all(a), v) - a.begin())


//#define printlog

const int n = 20;
const int m = 10;

typedef bool tfield[n][m];

tfield field, nfield;
int fig;

typedef bool figure[4][4];
figure fs[7];

int rotate(figure &f) { //return width
	figure r;
	forn(i, 4) forn(j, 4) {
		r[j][3 - i] = f[i][j];
	}
	memset(f, 0, sizeof f);
	int mx = 4, my = 4;
	forn(i, 4) forn(j, 4) if (r[i][j]) {
		mx = min(mx, i);
		my = min(my, j);
	}
	forn(i, 4) forn(j, 4) if (r[i][j]) {
		f[i - mx][j - my] = true;
	}
	my = 0;
	forn(i, 4) forn(j, 4) {
    	if (f[i][j]) my = max(my, j);		
	}
	return my + 1;
}

void initFigures() {
	memset(fs, 0, sizeof fs);
	int p = -1;
	/*0*/++p;
	forn(i, 4) fs[p][i][0] = true;
	/*1*/++p;
	forn(i, 3) fs[p][i][0] = true;
	fs[p][0][1] = true;
	/*2*/++p;
	forn(i, 3) fs[p][i][0] = true;
	fs[p][2][1] = true;
	/*3*/++p;
	forn(i, 2) {
		fs[p][i][1] = true;
		fs[p][i + 1][0] = true;
	}
	/*4*/++p;
	forn(i, 2) {
		fs[p][i + 1][1] = true;
		fs[p][i][0] = true;
	}
	/*5*/++p;
	forn(i, 3) fs[p][i][0] = true;
	fs[p][2][1] = true;
	/*6*/++p;
	forn(i, 2) {
		forn(j, 2) {
			fs[p][i][j] = true;
		}
	}
}


int kaddlines(int kdels) {
	if (kdels <= 1) return 1;
	return 1 << (kdels - 1);
}

int value(tfield field, int kdels) {
	int mx = 20;
	forn(i, n) {
		forn(j, m) {
			if (field[i][j]) {
				mx = i;
			}
		}
		if (mx != 20) break;
	}
	if (mx == 0) return -INF;
	int kp = 0;
	bool u[m];
	memset(u, 0, sizeof u);
	forn(i, n) forn(j, m) {
		if (field[i][j]) u[j] = true; else {
			if (u[j]) ++kp;
		}
	}
	int k[m];
	int sdiff = 0;
	memset(u, 0, sizeof u);
	memset(k, 0, sizeof k);
	forn(i, n) forn(j, m) {
		if (field[i][j]) u[j] = true; else {
			if (u[j]) continue;
			if ((j == 0 || u[j - 1]) &&
				(j == m - 1 || u[j + 1])) {
				++k[j];
			}
		}
	}
	forn(i, m) sdiff += (1 << (2 * min(k[i], 4)));
	return mx * 100 + kaddlines(kdels) * 80 - kp * 40 - sdiff;
}

int dropMine(tfield field, figure f, int ps) {
	int x = 0, y = ps;
	while (1) {
		bool ok = true;
		forn(i, 4) forn(j, 4) {
			bool fb = f[i][j];
			bool pb = true;
			if (x + i >= 0 && x + i < n 
				&& y + j >= 0 && y + j < m) {
				pb = field[x + i][y + j];
			}
			if (pb && fb) {
				ok = false;
			}
		}
		if (!ok) {
			if (x > 0) --x;
			forn(i, 4) forn(j, 4) if (f[i][j]) {
    			if (x + i >= 0 && x + i < n 
    				&& y + j >= 0 && y + j < m) {
    				field[x + i][y + j] = true;
    			}
			}
			break;
		} else {
			++x;
		}
	}
	forn(i, m) if (field[0][i]) return 0;
	int res = 0;
	forn(i, n) {
		bool ok = true;
		forn(j, m) if (!field[i][j]) ok = false;
		if (ok) {
			for(int t = i; t > 0; --t) {
				forn(j, m) field[t][j] = field[t - 1][j];
			}
			forn(j, m) field[0][j] = false;
			++res;
		}
	}
	return res;
}

void outFigure(figure cf) {
#ifdef printlog
    cerr << "figure: " << fig << endl;
    forn(i, 4) {
    	forn(j, 4) {
    		if (cf[i][j]) cerr << "#"; else cerr << " ";
	    }
	    cerr << endl;
	}
	cerr << endl;
#endif
}

void outField() {
#ifdef printlog
    cerr << "field:" << endl;
    forn(i, n) {
    	forn(j, m) {
    		if (field[i][j]) cerr << "#"; else cerr << ".";
	    }
	    cerr << endl;
	}
	cerr << endl;
	Sleep(1000);
#endif
}

void outdata() {
}

void solve() {
	bool fieldz[200];
	while (1) {
	    if (fig < 0 || fig > 6) fig = rand() % 7;
	    outField();
    	double bvalue = - INF * 2;
    	int brot = 0;
    	int bi = 0;
   		figure cf;
   		memmove(cf, fs[fig], sizeof cf);
    	forn(rot, 4) {
//	   		outFigure(cf);
    		int w = rotate(cf);
    		forn(i, 10 - w + 1) {
    			memmove(nfield, field, sizeof field);
    			double cvalue = value(nfield, dropMine(nfield, cf, i));
    			if (bvalue < cvalue) {
    				bvalue = cvalue;
    				brot = (rot + 1) % 4;
    				bi = i;
    			}
    		}
    	}
   		memmove(cf, fs[fig], sizeof cf);
   		forn(q, brot) rotate(cf);
	    outFigure(cf);
   		dropMine(field, cf, bi);
    	fig = Drop(brot, bi);
    	GetField(0, fieldz);
    	forn(i, n) forn(j, m) field[i][j] = fieldz[i * m + j];
	}
}

void readdata() {
	memset(field, 0, sizeof field);
    fig = Initialize();
    initFigures();	
}

int main() {
	readdata();
	solve();
	outdata();
	return 0;
}
