program segments_pm;
{$APPTYPE CONSOLE}
{$R+,Q+,S+,O-}
{$ASSERTIONS ON}

uses
  SysUtils;

Const
  MaxIP=3000;

Type
  TPoint=Record
    X,Y:Integer;
  End;
  TRational=Record
    P,Q:Int64;
  End;
  TRationalPoint=Record
    X,Y:TRational;
  End;
  TSegment=Record
    P1,P2:TPoint;
  End;
  TArr=Array[1..MaxIP]Of TRationalPoint;
  PTree=^TTree;
  TTree=Record
    Left,Right:PTree;
    Op:Char;
  End;
  TVarArr=Array['A'..'Z']Of Boolean;

Var
  S:Array['A'..'Z']Of TSegment;
  Have:Array['A'..'Z']Of Boolean;
  NIP:Integer;
  IP:TArr;
  IPOn:Array[1..MaxIP]Of TVarArr;
  NCur:Integer;
  Cur:TArr;
  St:String;
  Pos:Integer;

Procedure Load;
Var
  Ch:Char;
Begin
  FillChar(Have,SizeOf(Have),False);
  While True Do Begin
    SeekEOF;
    Read(Ch);
    If Ch='-' Then Break;
    Have[Ch]:=True;
    With S[Ch] Do Begin
      Read(P1.X,P1.Y,P2.X,P2.Y);
    End;
  End;
  ReadLn;
End;

Function GCD(A,B:Int64):Int64;
Var
  T:Int64;
Begin
  A:=Abs(A);
  B:=Abs(B);
  While B>0 Do Begin
    T:=A Mod B;
    A:=B;
    B:=T;
  End;
  Result:=A;
End;

Function LCM(A,B:Int64):Int64;
Begin
  Result:=(Abs(A) Div GCD(A,B))*Abs(B);
End;

Function Rational(P,Q:Int64):TRational;
Var
  G:Int64;
Begin
  G:=GCD(P,Q);
  If Q<0 Then G:=-G;
  Result.P:=P Div G;
  Result.Q:=Q Div G;
End;

Function RationalPoint(X,Y:TRational):TRationalPoint;
Begin
  Result.X:=X;
  Result.Y:=Y;
End;

Function Sign(Z:Int64):Integer;
Begin
  If Z<0 Then Sign:=-1 Else If Z>0 Then Sign:=1 Else Sign:=0;
End;

Function Compare(A,B:TRational):Integer;
Begin
  Result:=Sign(A.P*B.Q-A.Q*B.P);
End;

Function ComparePoint(A,B:TRationalPoint):Integer;
Begin
  Result:=Compare(A.X,B.X);
  If Result=0 Then Result:=Compare(A.Y,B.Y);
End;

Procedure Add(Z:TRationalPoint; Var N:Integer; Var C:TArr);
Var
  I,J:Integer;
  ZZ:Integer;
Begin
  I:=1;
  If N>0 Then For I:=1 To N Do Begin
    ZZ:=ComparePoint(Z,C[I]);
    If ZZ=0 Then Exit Else If ZZ<0 Then Break;
  End;
  For J:=N DownTo I Do C[J+1]:=C[J];
  Inc(N);
  C[I]:=Z;
End;

Procedure BuildImportantPoints;
Var
  SI,SJ:Char;
  DXI,DYI,DXJ,DYJ:Integer;
  Z,I,IA,IB,IC,JA,JB,JC,SI1,SI2,SJ1,SJ2:Integer;
  UP,UQ:Int64;
  TP1,TP2:TRationalPoint;
Begin
  NIP:=0;
  For SI:='A' To 'Z' Do If Have[SI] Then Begin
    NCur:=0;
    Add(RationalPoint(Rational(S[SI].P1.X,1),Rational(S[SI].P1.Y,1)),NCur,Cur);
    Add(RationalPoint(Rational(S[SI].P2.X,1),Rational(S[SI].P2.Y,1)),NCur,Cur);
    DXI:=S[SI].P2.X-S[SI].P1.X;
    DYI:=S[SI].P2.Y-S[SI].P1.Y;
    IA:=-DYI;
    IB:=DXI;
    IC:=-(IA*S[SI].P1.X+IB*S[SI].P1.Y);
    If (DXI<>0) Or (DYI<>0) Then
      For SJ:='A' To 'Z' Do If Have[SJ] Then Begin
        Z:=IA*S[SJ].P1.X+IB*S[SJ].P1.Y+IC;
        If Z=0 Then Begin
          DXJ:=S[SJ].P1.X-S[SI].P1.X;
          DYJ:=S[SJ].P1.Y-S[SI].P1.Y;
          If (DXI*DXJ+DYI*DYJ>0) Then Begin
            DXJ:=S[SJ].P1.X-S[SI].P2.X;
            DYJ:=S[SJ].P1.Y-S[SI].P2.Y;
            If (DXI*DXJ+DYI*DYJ<0) Then Begin
              Add(RationalPoint(Rational(S[SJ].P1.X,1),Rational(S[SJ].P1.Y,1)),NCur,Cur);
            End;
          End;
        End;
        Z:=IA*S[SJ].P2.X+IB*S[SJ].P2.Y+IC;
        If Z=0 Then Begin
          DXJ:=S[SJ].P2.X-S[SI].P1.X;
          DYJ:=S[SJ].P2.Y-S[SI].P1.Y;
          If (DXI*DXJ+DYI*DYJ>0) Then Begin
            DXJ:=S[SJ].P2.X-S[SI].P2.X;
            DYJ:=S[SJ].P2.Y-S[SI].P2.Y;
            If (DXI*DXJ+DYI*DYJ<0) Then Begin
              Add(RationalPoint(Rational(S[SJ].P2.X,1),Rational(S[SJ].P2.Y,1)),NCur,Cur);
            End;
          End;
        End;
        JA:=S[SJ].P1.Y-S[SJ].P2.Y;
        JB:=S[SJ].P2.X-S[SJ].P1.X;
        JC:=-(JA*S[SJ].P1.X+JB*S[SJ].P1.Y);
        SI1:=Sign(JA*S[SI].P1.X+JB*S[SI].P1.Y+JC);
        SI2:=Sign(JA*S[SI].P2.X+JB*S[SI].P2.Y+JC);
        SJ1:=Sign(IA*S[SJ].P1.X+IB*S[SJ].P1.Y+IC);
        SJ2:=Sign(IA*S[SJ].P2.X+IB*S[SJ].P2.Y+IC);
        If (SI1*SI2=-1) And (SJ1*SJ2=-1) Then Begin
          Add(RationalPoint(Rational(-(IC*JB-JC*IB),IA*JB-JA*IB),Rational(-(IA*JC-JA*IC),IA*JB-JA*IB)),NCur,Cur);
        End;
      End;
    For I:=1 To NCur Do Begin
      Add(Cur[I],NIP,IP);
      If I>1 Then Add(RationalPoint(
        Rational(Cur[I-1].X.P*Cur[I].X.Q+Cur[I-1].X.Q*Cur[I].X.P,2*Cur[I-1].X.Q*Cur[I].X.Q),
        Rational(Cur[I-1].Y.P*Cur[I].Y.Q+Cur[I-1].Y.Q*Cur[I].Y.P,2*Cur[I-1].Y.Q*Cur[I].Y.Q)),
        NIP,IP);
    End;
  End;
  FillChar(IPOn,SizeOf(IPOn),False);
  For SI:='A' To 'Z' Do If Have[SI] Then Begin
    TP1:=RationalPoint(Rational(S[SI].P1.X,1),Rational(S[SI].P1.Y,1));
    TP2:=RationalPoint(Rational(S[SI].P2.X,1),Rational(S[SI].P2.Y,1));
    IA:=S[SI].P1.Y-S[SI].P2.Y;
    IB:=S[SI].P2.X-S[SI].P1.X;
    IC:=-(IA*S[SI].P1.X+IB*S[SI].P1.Y);
    For I:=1 To NIP Do Begin
      UQ:=LCM(IP[I].X.Q,IP[I].Y.Q);
      UP:=IA*IP[I].X.P*(UQ Div IP[I].X.Q)+IB*IP[I].Y.P*(UQ Div IP[I].Y.Q)+IC*UQ;
      If (UP=0) Then Begin
        SI1:=ComparePoint(TP1,IP[I]);
        SI2:=ComparePoint(TP2,IP[I]);
        If SI1*SI2<=0 Then Begin
          IPOn[I,SI]:=True;          
        End;
      End;
    End;
  End;
End;

Function Parse1:PTree; Forward;

Function Parse4:PTree;
Begin
  Case St[Pos] Of
    'A'..'Z':Begin
      New(Result);
      Result^.Left:=Nil;
      Result^.Right:=Nil;
      Result^.Op:=St[Pos];
      Inc(Pos);
    End;
    '(':Begin
      Inc(Pos);
      Result:=Parse1;
      Assert(St[Pos]=')');
      Inc(Pos);
    End;
    Else Begin
      Result:=Nil;
      Assert(False);
    End;
  End;
End;

Function Parse3:PTree;
Var
  Tmp:PTree;
Begin
  Result:=Parse4;
  While St[Pos]='&' Do Begin
    Inc(Pos);
    New(Tmp);
    Tmp^.Left:=Result;
    Tmp^.Right:=Parse4;
    Tmp^.Op:='&';
    Result:=Tmp;
  End;
End;

Function Parse2:PTree;
Var
  Tmp:PTree;
Begin
  Result:=Parse3;
  While St[Pos]='+' Do Begin
    Inc(Pos);
    New(Tmp);
    Tmp^.Left:=Result;
    Tmp^.Right:=Parse3;
    Tmp^.Op:='+';
    Result:=Tmp;
  End;
End;

Function Parse1:PTree;
Var
  Tmp:PTree;
Begin
  Result:=Parse2;
  While St[Pos]='^' Do Begin
    Inc(Pos);
    New(Tmp);
    Tmp^.Left:=Result;
    Tmp^.Right:=Parse2;
    Tmp^.Op:='^';
    Result:=Tmp;
  End;
End;

Function Eval(Root:PTree; Var V:TVarArr):Boolean;
Begin
  Case Root.Op Of
    'A'..'Z':Result:=V[Root.Op];
    '^':Result:=Eval(Root.Left,V) Xor Eval(Root.Right,V);
    '+':Result:=Eval(Root.Left,V) Or Eval(Root.Right,V);
    '&':Result:=Eval(Root.Left,V) And Eval(Root.Right,V);
    Else Begin
      Result:=False;
      Assert(False);
    End;
  End;
End;

Procedure Solve;
Var
  L,R:PTree;
  Ok:Boolean;
  I:Integer;
Begin
  BuildImportantPoints;
  While Not SeekEOF Do Begin
    ReadLn(St);
    St:=St+'#';
    Pos:=1;
    L:=Parse1;
    Inc(Pos);
    R:=Parse1;
    Assert(Pos=Length(St));
    Ok:=True;
    For I:=1 To NIP Do Begin
      Ok:=Ok And (Eval(L,IPOn[I])=Eval(R,IPOn[I]));
    End;
    If Ok Then WriteLn('da') Else WriteLn('ne');
  End;
End;

Procedure Save;
Begin
End;

begin
  Load;
  Solve;
  Save;
end.
