#include <fstream>
#include <set>
#include <cmath>
#include <iostream>
#include <cstdio>
#include <vector>
#include <algorithm>
using namespace std;

const int MAXEDG = 20000;
const int MAXVER = 3100;
const long double eps = 1e-12;

class Edge
{
public:
	int v1, v2;
	long double cost;
};

int n;
vector<Edge> edg;
vector<long double> vals;
int first[MAXVER + 1];
int next[MAXEDG];

void AddEdge(int v1, int v2, long double cst)
{
	Edge a;
	a.v1 = v1;
	a.v2 = v2;
	a.cost = cst;
	edg.push_back(a);
	next[edg.size() - 1] = first[v1];
	first[v1] = edg.size() - 1;
}

int bver, ever;
long double a;

void Load()
{
	memset(first, 0xFF, sizeof(first));
	memset(next, 0xFF, sizeof(next));
	edg.clear();
	vals.clear();
	int m;
	cin >> n >> m;
	int i;
	for (i = 0; i < m; i++)
	{
		int v1, v2;
		double t;
		scanf("%d%d%lf", &v1, &v2, &t);
		AddEdge(v1, v2, t);
		AddEdge(v2, v1, t);
		vals.push_back((long double)t);
	}
	cin >> bver >> ever >> a;
}

class Vertex
{
public:
	long double dst;
	int id;
};

bool operator<(const Vertex &a, const Vertex &b)
{
	if (a.dst - b.dst < -eps) return true;
	if (a.dst - b.dst > eps) return false;
	if (a.id < b.id) return true;
	return false;
}

vector<int> ans, path;
long double dst[MAXVER + 1];
int prev[MAXVER + 1];
long double wgt[MAXVER + 1], owgt[MAXVER + 1];

long double FindPath(long double sa)
{
	set<Vertex> hp;
	hp.clear();
	int i;
	for (i = 1; i <= n; i++) 
	{            
		if (i != bver)
		{
			Vertex a;
			a.id = i;
			a.dst = 1e+100;
			hp.insert(a);
			dst[i] = 1e+100;
		}
	}
	memset(prev, 0, sizeof(prev));
	dst[bver] = 0;
	Vertex aa;
	aa.id = bver;
	aa.dst = 0;
	hp.insert(aa);
	while(hp.size() > 0)
	{	
		int mi = hp.begin() -> id;
		long double min = hp.begin() -> dst;
		if (min > 1e+99) break;
		hp.erase(hp.begin());
		for (i = first[mi]; i != -1; i = next[i])
		{
			long double nw = max((long double)0, edg[i].cost - sa);
			if (dst[edg[i].v2] - (dst[mi] + nw) > eps)
			{
				aa.id = edg[i].v2;
				aa.dst = dst[edg[i].v2];
				hp.erase(aa);
				dst[edg[i].v2] = dst[mi] + nw;
				prev[edg[i].v2] = mi;	
				wgt[edg[i].v2] = nw;
				aa.dst = dst[edg[i].v2];
				hp.insert(aa);
			}
		}
	}       
	path.clear();
	long double res = dst[ever] + sa / a;
	int cur = ever;
	while (cur != bver)
	{
		path.push_back(cur);
		cur = prev[cur];
	}
	path.push_back(bver);
	reverse(path.begin(), path.end());
	return res;
}

void Solve()
{
	long double min = 1e+100;
	long double mdisc = -1;
	vals.push_back(0);
	ans.clear();
	int i;
	for (i = 0; i < vals.size(); i++)
	{
		long double cur = FindPath(vals[i]);
		if (cur < min)
		{
			mdisc = vals[i] / a;
			min = cur;
			ans = path;
			for (int j = 1; j <= n; j++)
			{
				owgt[j]= wgt[j];
			}
		}
	}
	cout.setf(ios::fixed | ios::showpoint);
	cout.precision(6);
	cout << mdisc << " " << min << "\n";
	for (i = 0; i < ans.size(); i++)
	{
		cout << ans[i] << " ";
	}
}

int main()
{
	freopen("discount.in", "rt", stdin);
	freopen("discount.out", "wt", stdout);
	Load();
	Solve();
	return 0;
}
