using System;
using System.Collections.Generic;
using System.Drawing;
using System.IO;


class Program
{
	static void Main(string[] args)
	{
		new Program().Run();
	}

	void Sort(List<Point> points, int ox, int oy)
	{
		points.Sort(
			delegate(Point a, Point b)
			{
				int va = (a.X - ox) * (a.X - ox) + (a.Y - oy) * (a.Y - oy);
				int vb = (b.X - ox) * (b.X - ox) + (b.Y - oy) * (b.Y - oy);
				return va.CompareTo(vb);
			});
	}

	void Run()
	{
		int n;
		using (StreamReader reader = new StreamReader("wheel.in"))
		{
			n = int.Parse(reader.ReadLine());
		}

		int r = (int) (1.0 / Math.Sqrt(2) + Math.Sqrt(n / Math.PI) + 1);

		List<Point> points = new List<Point>();
		for (int i = -r; i <= r; i++)
			for (int j = -r; j <= r; j++)
				points.Add(new Point(n * i, n * j));

		long best = long.MaxValue;
		int bestox = 0;
		int bestoy = 0;

		for (int ox = 0; ox < n; ox++)
			for (int oy = 0; oy <= ox; oy ++)
			{
				Sort(points, ox, oy);

				long cur = 0;
				for (int i = 0; i < n; i++)
				{
					Point point = points[i];
					cur += (point.X - ox) * (point.X - ox) + (point.Y - oy) * (point.Y - oy);
				}

				if (cur < best)
				{
					best = cur;
					bestox = ox;
					bestoy = oy;
				}
			}

		Sort(points, bestox, bestoy);

		bool[][] result = new bool[2 * r + 1][];
		for (int i = 0; i < 2 * r + 1; i++)
			result[i] = new bool[2 * r + 1];

		for (int i = 0; i < n; i++)
			result[points[i].X / n + r][points[i].Y / n + r] = true;

		using (StreamWriter writer = new StreamWriter("wheel.out"))
		{
			writer.WriteLine((2 * r + 1) + " " + (2 * r + 1));
			for (int i = 0; i < 2 * r + 1; i++)
			{
				for (int j = 0; j < 2 * r + 1; j++)
					writer.Write(result[i][j] ? '*' : '.');
				writer.WriteLine();
			}
		}
	}
}