using System;
using System.Collections.Generic;
using System.IO;
using System.Text;


class Program
{
	static void Main(string[] args)
	{
		new Program().Run();
	}

	void Run()
	{
		int n;
		using (StreamReader reader = new StreamReader("wheel.in"))
		{
			n = int.Parse(reader.ReadLine());
		}

		int w = (int) (Math.Sqrt(n) * 3 + 1);
		int h = (int) (Math.Sqrt(n) * 3 + 1);

		bool[][] z = new bool[w][];
		for (int i = 0; i < w; i++)
			z[i] = new bool[h];

		z[w / 2][h / 2] = true;
		for (int i = 0; i < n - 1; i++)
			AddBest(z);

		do
		{
			Console.WriteLine(Eval(z));
		} while (Improve(z));

		using (StreamWriter writer = new StreamWriter("wheel.out"))
		{
			writer.WriteLine(z[0].Length + " " + z.Length);
			for (int i = 0; i < z.Length; i++)
			{
				for (int j = 0; j < z[i].Length; j++)
					writer.Write(z[i][j] ? '*' : '.');
				writer.WriteLine();
			}
		}
	}

	bool Improve(bool[][] z)
	{
		double old = Eval(z);
		for (int i = 0; i < z.Length; i++)
			for (int j = 0; j < z[i].Length; j++)
				if (z[i][j])
				{
					for (int i1 = 0; i1 < z.Length; i1++)
						for (int j1 = 0; j1 < z[i1].Length; j1++)
							if (!z[i1][j1])
							{
								z[i][j] = false;
								z[i1][j1] = true;
								double cur = Eval(z);
								if (cur < old - double.Epsilon)
									return true;
								z[i][j] = true;
								z[i1][j1] = false;
							}
				}

		return false;
	}

	void AddBest(bool[][] z)
	{
		double best = double.MaxValue;
		int besti = 0;
		int bestj = 0;
		for (int i = 0; i < z.Length; i++)
			for (int j = 0; j < z[i].Length; j++)
				if (!z[i][j])
				{
					z[i][j] = true;
					double cur = Eval(z);
					if (cur < best)
					{
						best = cur;
						besti = i;
						bestj = j;
					}
					z[i][j] = false;
				}

		z[besti][bestj] = true;
	}

	double Eval(bool[][] z)
	{
		double mx = 0;
		double my = 0;
		int n = 0;
		for (int i = 0; i < z.Length; i++)
			for (int j = 0; j < z[i].Length; j++)
				if (z[i][j])
				{
					mx += i;
					my += j;
					n++;
				}

		mx /= n;
		my /= n;


		double result = 0;
		for (int i = 0; i < z.Length; i++)
			for (int j = 0; j < z[i].Length; j++)
				if (z[i][j])
					result += (i - mx) * (i - mx) + (j - my) * (j - my);

		return result;
	}
}
