#include <stdio.h>
#include <string.h>

#include <algorithm>
using namespace std;

const int block = 256;
int Z[65536];
int S[65536 / block][block];
int W[256];

void init (int n)
{
  memset (W, 0, sizeof W);
  for (int i = 0, b = 0; i < n; i += block, b++)
  {
    W[b] = block;
    if (i + W[b] > n)
      W[b] = n - i;
    for (int j = 0; j < W[b]; j++)
      S[b][j] = Z[i + j];
    sort (S[b], S[b] + W[b]);
  }
}

void set (int x, int z)
{
  x--;
  int i = x / block;
  z *= 2;
  if (z < Z[x])
  {
    int pos = 0;
    for (; pos < W[i]; pos++)
      if (S[i][pos] == Z[x])
        break;
    while (pos > 0 && S[i][pos - 1] > z)
      S[i][pos] = S[i][pos - 1], pos--;
    S[i][pos] = z;
    Z[x] = z;
  }
  else
  {
    int pos = W[i] - 1;
    for (; pos >= 0; pos--)
      if (S[i][pos] == Z[x])
        break;
    while (pos < W[i] - 1 && S[i][pos + 1] < z)
      S[i][pos] = S[i][pos + 1], pos++;
    S[i][pos] = z;
    Z[x] = z;
  }
}
void stat (int i, int z, int& l, int& g, int& e)
{
  int _l = 0;
  int _r = W[i] - 1;
  while (_l < _r)
  {
    int m = (_l + _r) / 2;
    if (S[i][m] < z)
      _l = m + 1;
    else
      _r = m;
  }
  int first = _l;
  _l = 0;
  _r = W[i] - 1;
  while (_l < _r)
  {
    int m = (_l + _r + 1) / 2;
    if (S[i][m] <= z)
      _l = m;
    else
      _r = m - 1;
  }
  while (S[i][_l] > z)
    _l--;
  int last = _l;
  l += first;
  g += W[i] - last - 1;
  e += last - first + 1;
}
void mstat (int x0, int x1, int z, int& l, int& g, int& e)
{
  for (int x = x0; x <= x1; x++)
    if (Z[x] < z)
      l++;
    else if (Z[x] > z)
      g++;
    else
      e++;
}

int query (int x0, int x1, int y0, int y1)
{            
  x0--;
  x1--;
  int lt = 0, gt = 0, eq = 0;
  int cur = x0;
  int z = y0 + y1;
  while (cur <= x1)
  {
    int next = ((cur + block) & (-block)) - 1;
    if (next > x1)
      next = x1;
    if ((cur & (block - 1)) == 0 && ((next + 1) & (block - 1)) == 0)
      stat (cur / block, z, lt, gt, eq);
    else
      mstat (cur, next, z, lt, gt, eq);
    cur = next + 1;
  }
  int wd = x1 - x0 + 1;
//  printf ("S: %d %d %d\n", lt, gt, eq);
  if (lt > gt)
    return 1;
  if (gt > lt)
    return 2;
  return 0;
}
int squery (int x0, int x1, int y0, int y1)
{
  x0--;
  x1--;
  int l = 0, g = 0, e = 0;
  mstat (x0, x1, y0 + y1, l, g, e);
  if (l > g)
    return 1;
  else if (g > l)
    return 2;
  return 0;
}

void print (int n)
{
  for (int i = 0; i < n; i++)
    printf ("%d ", Z[i]);
  printf ("\n");
  printf ("{\n");
  for (int i = 0; W[i]; i++, printf ("\n"))
    for (int j = 0; j < W[i]; j++)
      printf (" %d", S[i][j]);
  printf ("}\n");
}

int main ()
{
  freopen ("rect2.in", "rt", stdin);
  freopen ("rect2.out", "wt", stdout);

  int n;
  scanf ("%d", &n);
  for (int i = 0; i < n; i++)
    scanf ("%d", &Z[i]), Z[i] *= 2;
  init (n);

  int q;
  scanf ("%d", &q);
  for (int i = 0; i < q; i++)
  {
//    print (n);
    char cmd[3];
    int a, b, c, d;
    scanf ("%s", cmd);
    if (cmd[0] == 'Q')
    {
      scanf ("%d %d %d %d", &a, &b, &c, &d);
      int r = query (a, c, b, d);
//      if (r != squery (a, c, b, d))
//        print (n);
      printf ("%d\n", r);
    }
    else
    {
      scanf ("%d %d", &a, &b);
      set (a, b);
    }
  }

  return 0;
}
