#include <algorithm>
#include <cstdio>
#include <vector>

using namespace std;

#define pb push_back

struct rect3
{
  int x1, x2, y1, y2, z1, z2;
  rect3( void )
  {
    x1 = x2 = y1 = y2 = z1 = z2 = 0;
  }
  rect3( int sx1, int sy1, int sz1, int sx2, int sy2, int sz2 )
  {
    x1 = sx1, x2 = sx2, y1 = sy1, y2 = sy2, z1 = sz1, z2 = sz2;
  }
};

struct rect2
{
  int x1, x2, y1, y2;
  rect2( int sx1, int sx2, int sy1, int sy2 )
  {
    x1 = sx1, x2 = sx2, y1 = sy1, y2 = sy2;
  }
  bool operator < ( rect2 b )
  {
    if (x1 < b.x1) return true;
    if (x1 > b.x1) return false;
    if (y1 < b.y1) return true;
    if (y1 > b.y1) return false;
    if (x2 < b.x2) return true;
    if (x2 > b.x2) return false;
    if (y2 < b.y2) return true;
    if (y2 > b.y2) return false;
    return false;
  }
};

struct event
{
  int time, st, fi, add;
  event( int stime, int sst, int sfi, int sadd )
  {
    time = stime, st = sst, fi = sfi, add = sadd;
  }
};

bool operator < ( event a, event b )
{
  if (a.time < b.time) return true;
  if (a.time > b.time) return false;
  if (a.add < b.add) return true;
  if (a.add > b.add) return false;
  return false;
}

#define maxmem 200010

int mem_first;
int tree_left[maxmem], tree_right[maxmem], tree_size[maxmem], tree_value[maxmem];

void mem_free( int pos )
{
  tree_value[pos] = mem_first;
  mem_first = pos;
}

int mem_alloc( void )
{
  int res = mem_first;
  if (mem_first == -1)
    exit(14 + fprintf(stderr, "not enought memory(\n"));
  mem_first = tree_value[mem_first];
  return res;
}

void mem_init( void )
{
  mem_first = 0;
  for (int i = 0; i < maxmem; i++)
    tree_value[i] = i + 1;
  tree_value[maxmem - 1] = -1;
}

void tree_upsize( int root )
{
  if (root == -1)
    return;
  int size = 1;
  if (tree_left[root] != -1)
    size += tree_size[tree_left[root]];
  if (tree_right[root] != -1)
    size += tree_size[tree_right[root]];
  tree_size[root] = size;
}

int tree_merge( int left, int right )
{
//  fprintf(stderr, "tree_merge(left = %d, right = %d)\n", left, right);
  if (left == -1)
    return right;
  if (right == -1)
    return left;
  if (rand() % (tree_size[left] + tree_size[right]) < tree_size[left])
  {
    tree_right[left] = tree_merge(tree_right[left], right);
    tree_upsize(left);
    return left;
  }
  else
  {
    tree_left[right] = tree_merge(left, tree_left[right]);
    tree_upsize(right);
    return right;
  }
}

int tree_erase( int root, int value )
{
//  fprintf(stderr, "  tree_erase(root = %d, value = %d)\n", root, value);
  if (root == -1)
    return root;
  if (tree_value[root] > value)
  {
//    fprintf(stderr, "  tree_erase: case 0\n");
    tree_left[root] = tree_erase(tree_left[root], value);
    tree_upsize(root);
    return root;
  }
  else if (tree_value[root] < value)
  {
//    fprintf(stderr, "  tree_erase: case 1\n");
    tree_right[root] = tree_erase(tree_right[root], value);
    tree_upsize(root);
    return root;
  }
  else
  {
//    fprintf(stderr, "  tree_erase: case 2\n");
    int left = tree_left[root], right = tree_right[root];
    mem_free(root);
//    fprintf(stderr, "  tree_erase: case 2.1\n");
    return tree_merge(left, right);
  }
}

int tree_getsize( int root )
{
  if (root == -1)
    return 0;
  else
    return tree_size[root];
}

int tree_get( int root, int value )
{
  if (root == -1)
    return 0;
  if (tree_value[root] <= value)
    return 1 + tree_getsize(tree_right[root]) + tree_get(tree_left[root], value);
  else
    return tree_get(tree_right[root], value);
}

void tree_split( int root, int value, int *left, int *right )
{
  if (root = -1)
    *left = *right = -1;
  else if (tree_value[root] > value)
  {
    tree_split(tree_left[root], value, left, &tree_left[root]);
    *right = root;
    tree_upsize(root);
  }
  else
  {
    tree_split(tree_right[root], value, &tree_right[root], left);
    *left = root;
    tree_upsize(root);
  }
}

int tree_insert( int root, int value )
{
//  fprintf(stderr, "  tree_insert(root = %d, value = %d)\n", root, value);
  if (rand() % (tree_getsize(root) + 1) != 0)
    if (tree_value[root] > value)
    {
      tree_left[root] = tree_insert(tree_left[root], value);
      tree_upsize(root);
      return root;
    }
    else
    {
      tree_right[root] = tree_insert(tree_right[root], value);
      tree_upsize(root);
      return root;
    }
  else
  {
//    fprintf(stderr, "  tree_insert: case 2\n");
    int temp = mem_alloc();
    tree_value[temp] = value;
    tree_split(root, value, &tree_left[temp], &tree_right[temp]);
    tree_upsize(temp);
    return temp;
  }
}

class tree
{
  private:
    int root;
  public:
    tree( void )
    {
      root = -1;
    }
    void erase( int value )
    {
      root = tree_erase(root, value);
    }
    int get( int value )
    {
      return tree_get(root, value);
    }
    void insert( int value )
    {
      root = tree_insert(root, value);
    }    
};

#define maxn 100010

int x1[maxn], x2[maxn], y1[maxn], y2[maxn], z1[maxn], z2[maxn];

int main( void )
{
  srand(301703);
  mem_init();
  freopen("rect3.in", "r", stdin);
  freopen("rect3.out", "w", stdout);

  int n;

  scanf("%d", &n);
  for (int i = 0; i < n; i++)
    scanf("%d%d%d%d%d%d", &x1[i], &y1[i], &z1[i], &x2[i], &y2[i], &z2[i]);

  for (int i = 0; i < n; i++)
  {
    if (x1[i] > x2[i])
      swap(x1[i], x2[i]);
    if (y1[i] > y2[i])
      swap(y1[i], y2[i]);
    if (z1[i] > z2[i])
      swap(z1[i], z2[i]);
  }

  if (n < 2000)
  {
    int ans = 0;
    for (int i = 0; i < n; i++)
      for (int j = 0; j < i; j++)
      {
        if (x1[i] == x2[i] && x1[j] == x2[j] && x1[i] != x2[j])
          continue;
        if (y1[i] == y2[i] && y1[j] == y2[j] && y1[i] != y2[j])
          continue;
        if (z1[i] == z2[i] && z1[j] == z2[j] && z1[i] != z2[j])
          continue;                    
        if (x1[i] == x2[i] && x1[j] == x2[j])
        {
          if (y1[i] <= y2[j] && y1[j] <= y2[i] && z1[i] <= z2[j] && z1[j] <= z2[i])
            ans++;
          continue;
        }
        if (y1[i] == y2[i] && y1[j] == y2[j])
        {
          if (x1[i] <= x2[j] && x1[j] <= x2[i] && z1[i] <= z2[j] && z1[j] <= z2[i])
            ans++;
          continue;
        }
        if (z1[i] == z2[i] && z1[j] == z2[j])
        {
          if (x1[i] <= x2[j] && x1[j] <= x2[i] && y1[i] <= y2[j] && y1[j] <= y2[i])
            ans++;
          continue;
        }
        if (x1[i] == x2[i])
        {
          if (x1[j] > x1[i] || x2[j] < x1[i])
            continue;
        }
        else if (x1[j] == x2[j])
        {
          if (x1[i] > x1[j] || x2[i] < x1[j])
            continue;
        }
        else
          if (x1[i] > x2[j] || x1[j] > x2[i])
            continue;
        if (y1[i] == y2[i])
        {
          if (y1[j] > y1[i] || y2[j] < y1[i])
            continue;
        }
        else if (y1[j] == y2[j])
        {
          if (y1[i] > y1[j] || y2[i] < y1[j])
            continue;
        }
        else
          if (y1[i] > y2[j] || y1[j] > y2[i])
            continue;
        if (z1[i] == z2[i])
        {
          if (z1[j] > z1[i] || z2[j] < z1[i])
            continue;
        }
        else if (z1[j] == z2[j])
        {
          if (z1[i] > z1[j] || z2[i] < z1[j])
            continue;
        }
        else
          if (z1[i] > z2[j] || z1[j] > z2[i])
            continue;
        ans++;
      }

    printf("%d\n", ans);

    return 0;
  }

  vector <rect3> px(0), py(0), pz(0);

  for (int i = 0; i < n; i++)
    if (x1[i] == x2[i])
      px.pb(rect3(x1[i], y1[i], z1[i], x2[i], y2[i], z2[i]));
    else if (y1[i] == y2[i])
      py.pb(rect3(x1[i], y1[i], z1[i], x2[i], y2[i], z2[i]));
    else
      pz.pb(rect3(x1[i], y1[i], z1[i], x2[i], y2[i], z2[i]));

  long long cnt = 0, cnt2 = 0;

  for (int x = 1; x < 999; x++)
  {
    vector <event> plane, planey, planez;
    for (int i = 0; i < (int)px.size(); i++)
      if (px[i].x1 == x)
      {
        plane.pb(event(px[i].y1, px[i].z1, px[i].z2, -1)),
        plane.pb(event(px[i].y2, px[i].z1, px[i].z2, +1)),
        planey.pb(event(px[i].y1, px[i].z1, px[i].z2, -1)),
        planey.pb(event(px[i].y2, px[i].z1, px[i].z2, +1)),
        planez.pb(event(px[i].z1, px[i].y1, px[i].y2, -1)),
        planez.pb(event(px[i].z2, px[i].y1, px[i].y2, +1));
      }
    for (int i = 0; i < (int)py.size(); i++)
      if (x >= py[i].x1 && x <= py[i].x2)
        planey.pb(event(py[i].y1, py[i].z1, py[i].z2, 0));
    for (int i = 0; i < (int)pz.size(); i++)
      if (x >= pz[i].x1 && x <= pz[i].x2)
        planez.pb(event(pz[i].z1, pz[i].y1, pz[i].y2, 0));
    sort(plane.begin(), plane.end());
    sort(planey.begin(), planey.end());
    sort(planez.begin(), planez.end());
    tree tree1, tree2;
    int count = 0, tmp = 0;
    for (int i = 0; i < (int)plane.size(); i++)
      if (plane[i].add == +1)
        tree1.erase(plane[i].st), tree2.erase(-plane[i].fi), count--;
      else
      {
        tmp += tree2.get(-plane[i].st) + tree1.get(plane[i].fi) - count;
        if (plane[i].add == -1)
          tree1.insert(plane[i].st), tree2.insert(-plane[i].fi), count++;
      }
    for (int i = 0; i < (int)planey.size(); i++)
      if (planey[i].add == +1)
        tree1.erase(planey[i].st), tree2.erase(-planey[i].fi), count--;
      else
      {
        cnt2 += tree2.get(-planey[i].st) + tree1.get(planey[i].fi) - count;
        if (planey[i].add == -1)
          tree1.insert(planey[i].st), tree2.insert(-planey[i].fi), count++;
      }
    for (int i = 0; i < (int)planez.size(); i++)
      if (planez[i].add == +1)
        tree1.erase(planez[i].st), tree2.erase(-planez[i].fi), count--;
      else
      {
        cnt2 += tree2.get(-planez[i].st) + tree1.get(planez[i].fi) - count;
        if (planez[i].add == -1)
          tree1.insert(planez[i].st), tree2.insert(-planez[i].fi), count++;
      }
    cnt += tmp;
    cnt2 -= 2 * tmp;
  }
  for (int y = 1; y < 999; y++)
  {
    vector <event> plane, planex, planez;
    for (int i = 0; i < (int)py.size(); i++)
      if (py[i].y1 == y)
      {
        plane.pb(event(py[i].x1, py[i].z1, py[i].z2, -1)),
        plane.pb(event(py[i].x2, py[i].z1, py[i].z2, +1)),
        planex.pb(event(py[i].x1, py[i].z1, py[i].z2, -1)),
        planex.pb(event(py[i].x2, py[i].z1, py[i].z2, +1)),
        planez.pb(event(py[i].z1, py[i].x1, py[i].x2, -1)),
        planez.pb(event(py[i].z2, py[i].x1, py[i].x2, +1));
      }
    for (int i = 0; i < (int)px.size(); i++)
      if (y >= px[i].y1 && y <= px[i].y2)
        planex.pb(event(px[i].x1, px[i].z1, px[i].z2, 0));
    for (int i = 0; i < (int)pz.size(); i++)
      if (y >= pz[i].y1 && y <= pz[i].y2)
        planez.pb(event(pz[i].z1, pz[i].x1, pz[i].x2, 0));
    sort(plane.begin(), plane.end());
    sort(planex.begin(), planex.end());
    sort(planez.begin(), planez.end());
    tree tree1, tree2;
    int count = 0, tmp = 0;
    for (int i = 0; i < (int)plane.size(); i++)
      if (plane[i].add == +1)
        tree1.erase(plane[i].st), tree2.erase(-plane[i].fi), count--;
      else
      {
        tmp += tree2.get(-plane[i].st) + tree1.get(plane[i].fi) - count;
        if (plane[i].add == -1)
          tree1.insert(plane[i].st), tree2.insert(-plane[i].fi), count++;
      }
    for (int i = 0; i < (int)planex.size(); i++)
      if (planex[i].add == +1)
        tree1.erase(planex[i].st), tree2.erase(-planex[i].fi), count--;
      else
      {
        cnt2 += tree2.get(-planex[i].st) + tree1.get(planex[i].fi) - count;
        if (planex[i].add == -1)
          tree1.insert(planex[i].st), tree2.insert(-planex[i].fi), count++;
      }
    for (int i = 0; i < (int)planez.size(); i++)
      if (planez[i].add == +1)
        tree1.erase(planez[i].st), tree2.erase(-planez[i].fi), count--;
      else
      {
        cnt2 += tree2.get(-planez[i].st) + tree1.get(planez[i].fi) - count;
        if (planez[i].add == -1)
          tree1.insert(planez[i].st), tree2.insert(-planez[i].fi), count++;
      }
    cnt += tmp;
    cnt2 -= tmp;
  }
  for (int z = 1; z < 999; z++)
  {
    vector <event> plane, planex, planey;
    for (int i = 0; i < (int)pz.size(); i++)
      if (pz[i].z1 == z)
      {
        plane.pb(event(pz[i].x1, pz[i].y1, pz[i].y2, -1)),
        plane.pb(event(pz[i].x2, pz[i].y1, pz[i].y2, +1)),
        planex.pb(event(pz[i].x1, pz[i].y1, pz[i].y2, -1)),
        planex.pb(event(pz[i].x2, pz[i].y1, pz[i].y2, +1)),
        planey.pb(event(pz[i].y1, pz[i].x1, pz[i].x2, -1)),
        planey.pb(event(pz[i].y2, pz[i].x1, pz[i].x2, +1));
      }
    for (int i = 0; i < (int)px.size(); i++)
      if (z >= px[i].z1 && z <= px[i].z2)
        planex.pb(event(px[i].x1, px[i].y1, px[i].y2, 0));
    for (int i = 0; i < (int)py.size(); i++)
      if (z >= py[i].z1 && z <= py[i].z2)
        planey.pb(event(py[i].y1, py[i].x1, py[i].x2, 0));
    sort(plane.begin(), plane.end());
    sort(planex.begin(), planex.end());
    sort(planey.begin(), planey.end());
    tree tree1, tree2;
    int count = 0;
    for (int i = 0; i < (int)plane.size(); i++)
      if (plane[i].add == +1)
        tree1.erase(plane[i].st), tree2.erase(-plane[i].fi), count--;
      else
      {
        cnt += tree2.get(-plane[i].st) + tree1.get(plane[i].fi) - count;
        if (plane[i].add == -1)
          tree1.insert(plane[i].st), tree2.insert(-plane[i].fi), count++;
      }
    for (int i = 0; i < (int)planex.size(); i++)
      if (planex[i].add == +1)
        tree1.erase(planex[i].st), tree2.erase(-planex[i].fi), count--;
      else
      {
        cnt2 += tree2.get(-planex[i].st) + tree1.get(planex[i].fi) - count;
        if (planex[i].add == -1)
          tree1.insert(planex[i].st), tree2.insert(-planex[i].fi), count++;
      }
    for (int i = 0; i < (int)planey.size(); i++)
      if (planey[i].add == +1)
        tree1.erase(planey[i].st), tree2.erase(-planey[i].fi), count--;
      else
      {
        cnt2 += tree2.get(-planey[i].st) + tree1.get(planey[i].fi) - count;
        if (planey[i].add == -1)
          tree1.insert(planey[i].st), tree2.insert(-planey[i].fi), count++;
      }
  }

  fprintf(stderr, " cnt: %d\n", cnt);
  fprintf(stderr, "cnt2: %d\n", cnt2);
  printf("%I64d\n", cnt + cnt2 / 2);

  return 0;
}
