program taska;

{$MODE DELPHI}
{$Q-,R-,S-,I-}

uses
  Math;

const
  MAXN = 200000;

type
  TArr  = array [0..MAXN] of Integer;
  PTree = ^TTree;
  TTree = record
    x, y, z: Integer;
    l, r: PTree;
  end;

procedure QSort(var a, b: TArr; n: Integer);

procedure sort(l, r: Integer);
var
  i, j, x, tmp: Integer;
begin
  i := l; j := r;
  x := a[l + Random(r-l+1)];
  while i <= j do
    begin
      while a[i] < x do inc(i);
      while x < a[j] do dec(j);
      if i <= j then
        begin
          tmp := a[i]; a[i] := a[j]; a[j] := tmp;
          tmp := b[i]; b[i] := b[j]; b[j] := tmp;
          inc(i); dec(j);
        end;
    end;
  if l < j then sort(l, j);
  if i < r then sort(i, r);
end;

begin // QSort
  sort(1, n);
end;

function merge(l, r: PTree): PTree;
begin
  if l = nil then
    Result := r
  else
    if r = nil then
      Result := l
    else
      if l^.y > r^.y then
        begin
          l^.r := merge(l^.r, r);
          Result := l;
        end
      else
        begin
          r^.l := merge(l, r^.l);
          Result := r;
        end;
end;

procedure split(p: PTree; x, z: Integer; var l, r: PTree);
begin
  if p = nil then
    begin
      l := nil;
      r := nil;
    end
  else
    if (p^.x > x) or ((p^.x = x) and (p^.z > z)) then
      begin
        split(p^.l, x, z, l, r);
        p^.l := r;
        r := p;
      end
    else
      begin
        split(p^.r, x, z, l, r);
        p^.r := l;
        l := p;
      end;
end;

procedure insert(var p: PTree; x, y, z: Integer); overload;
var
  t: PTree;
begin
  if p = nil then
    begin
      new(p);
      p^.x := x;
      p^.y := y;
      p^.z := z;
      p^.l := nil;
      p^.r := nil;
    end
  else
    if p^.y > y then
      if (p^.x > x) or ((p^.x = x) and (p^.z > z)) then
        insert(p^.l, x, y, z)
      else
        insert(p^.r, x, y, z)
    else
      begin
        new(t);
        t^.x := x;
        t^.y := y;
        t^.z := z;
        split(p, x, z, t^.l, t^.r);
        p := t;
      end;
end;

procedure insert(var p: PTree; x, z: Integer); overload;
begin
  insert(p, x, Random(MaxLongInt), z);
end;

procedure insert(var p: PTree; x: Integer); overload;
begin
  insert(p, x, Random(MaxLongInt), Random(MaxLongInt));
end;

procedure delete(var p: PTree; x: Integer); overload;
var
  t: PTree;
begin
  if p^.x > x then
    delete(p^.l, x)
  else
    if p^.x < x then
      delete(p^.r, x)
    else
      begin
        t := p;
        p := merge(p^.l, p^.r);
        dispose(t);
      end;
end;

procedure delete(var p: PTree; x, z: Integer); overload;
var
  t: PTree;
begin
  if (p^.x > x) or ((p^.x = x) and (p^.z > z)) then
    delete(p^.l, x)
  else
    if (p^.x < x) or ((p^.x = x) and (p^.z < z)) then
      delete(p^.r, x)
    else
      begin
        t := p;
        p := merge(p^.l, p^.r);
        dispose(t);
      end;
end;

function getmax(p: PTree): PTree;
begin
  if p^.r = nil then
    Result := p
  else
    Result := getmax(p^.r);
end;

procedure find(p: PTree; x: Integer; var l, r: Integer);
begin
  if p <> nil then
    begin
      if p^.x <= x then
        l := max(l, p^.x);
      if p^.x >= x then
        r := min(r, p^.x);

      if l = r then
        exit
      else
        if p^.x > x then
          find(p^.l, x, l, r)
        else
          find(p^.r, x, l, r);
    end;
end;

var
  n, a, b, i, j, ans, rx, ry, k: Integer;
  x, y: TArr;
  t, h, p: PTree;

procedure add(y: Integer);
var
  l, r: Integer;
begin
  l := 0; r := b;
  find(t, y, l, r);
  if l < r then
    begin
      delete(h, r - l, -l);
      insert(h, y - l, -l);
      insert(h, r - y, -y);
    end;
  insert(t, y);
end;

procedure remove(y: Integer);
var
  l, r: Integer;
begin
  delete(t, y);
  l := 0; r := b;
  find(t, y, l, r);
  if l < r then
    begin
      delete(h, y - l, -l);
      delete(h, r - y, -y);
      insert(h, r - l, -l);
    end;
end;

begin
  Assign(input, 'roi.in');
  Assign(output, 'roi.out');
  Reset(input); Rewrite(output);
  RandSeed := 158308;

  Read(a, b, n);
  for i := 1 to n do
    Read(x[i], y[i]);

  x[0] := 0;
  y[0] := 0;
  x[n+1] := a;
  y[n+1] := 0;

  QSort(x, y, n);

  t := nil;
  h := nil;
  insert(t, 0);
  insert(h, b, 0);
  i := 0; j := 1;
  ans := 0;
  rx := 0; ry := 0;
  while i <= n do
    begin
      p := getmax(h);
      k := min(p^.x, x[j] - x[i]);
      if (ans < k) or ((ans = k) and (rx = x[i]) and (ry > -p^.z)) then
        begin
          ans := k;
          rx := x[i];
          ry := -p^.z;
        end;

      if (i+1 < j) and (p^.x <= x[j] - x[i]) then
        begin
          inc(i);
          remove(y[i]);
        end
      else
        if j <= n then
          begin
            add(y[j]);
            inc(j);
          end
        else
          break;
    end;

  WriteLn(ans);
  Write(rx, ' ', ry);

  Close(input);
  Close(output);
end.
