#include <stdio.h>
#include <string.h>

#include <algorithm>
using namespace std;

struct seg
{
  int y;
  int x0, x1;
  seg* parent;
  seg* child;
  seg* sib;
};
const int maxSegs = 2000000;
seg* freeHead;
seg segs[maxSegs];
int numseg;
void init_segs ()
{
  numseg = 0;
  for (int i = 1; i < maxSegs; i++)
    segs[i - 1].parent = &segs[i];
  segs[maxSegs - 1].parent = NULL;
  freeHead = &segs[0];
}
seg* salloc ()
{
  numseg++;
  seg* val = freeHead;
  if (freeHead)
    freeHead = freeHead->parent;
  if (val)
  {
    val->parent = NULL;
    val->child = NULL;
    val->sib = NULL;
  }
  return val;
}
void sfree (seg* s)
{
  numseg--;
  while (s->child)
  {
    sfree (s->child);
    s->child = s->child->sib;
  }
  s->parent = freeHead;
  freeHead = s;
}

seg* root;
int cury;

struct tree
{
  int x, y;
};
inline bool operator < (tree const& a, tree const& b)
{
  return a.y < b.y || (a.y == b.y && a.x < b.x);
}
tree tr[262144];
int ntr;

int X, Y;

int boxs = 1;
int boxx = 0;
int boxy = 0;

void cut_seg (seg* s, int x, seg** lp, seg** rp)
{
//  printf ("CUT: %d %d %d - %d\n", s->y, s->x0, s->x1, x);
  *lp = NULL;
  *rp = NULL;
  if (cury - s->y >= s->x1 - s->x0)
  {
    if (s->x1 - s->x0 > boxs || (s->x1 - s->x0 == boxs && (s->x0 < boxx || (s->x0 == boxx && s->y < boxy))))
    {
      boxs = s->x1 - s->x0;
      boxx = s->x0;
      boxy = s->y;
    }
    if (s->child)
    {
      cut_seg (s->child, x, lp, rp);
      s->child = NULL;
    }
    sfree (s);
    return;
  }
  if (cury - s->y > boxs || (cury - s->y == boxs && (s->x0 < boxx || (s->x0 == boxx && s->y < boxy))))
  {
    boxs = cury - s->y;
    boxx = s->x0;
    boxy = s->y;
  }
  if (s->x0 >= x)
    *rp = s;
  else if (s->x1 <= x)
    *lp = s;
  else
  {
    seg* c = s->child;
    seg* l = s;
    seg* r = salloc ();
    r->x1 = s->x1;
    r->y = s->y;
    r->x0 = x;
    l->x1 = x;
    l->child = NULL;
    r->child = NULL;
    seg* cl;
    seg* cr;
    while (c)
    {
      seg* nx = c->sib;
      cut_seg (c, x, &cl, &cr);
      if (cl)
        cl->sib = l->child, l->child = cl, cl->parent = l;
      if (cr)
        cr->sib = r->child, r->child = cr, cr->parent = r;
      c = nx;
    }
    *lp = l;
    *rp = r;
  }
//  printf ("FINISH\n");
}

void check_seg (seg* s)
{
  if (cury - s->y >= s->x1 - s->x0)
  {
    if (s->x1 - s->x0 > boxs || (s->x1 - s->x0 == boxs && (s->x0 < boxx || (s->x0 == boxx && s->y < boxy))))
    {
      boxs = s->x1 - s->x0;
      boxx = s->x0;
      boxy = s->y;
    }
  }
  else
  {
    if (cury - s->y > boxs || (cury - s->y == boxs && (s->x0 < boxx || (s->x0 == boxx && s->y < boxy))))
    {
      boxs = cury - s->y;
      boxx = s->x0;
      boxy = s->y;
    }
    seg* cur = s->child;
    while (cur)
    {
      check_seg (cur);
      cur = cur->sib;
    }
  }
}

void cut_simp (seg* s, int x)
{
  seg* c = s->child;
  s->child = NULL;
  seg* l;
  seg* r;
  while (c)
  {
    seg* nx = c->sib;
    cut_seg (c, x, &l, &r);
    if (l)
      l->sib = s->child, s->child = l, l->parent = s;
    if (r)
      r->sib = s->child, s->child = r, r->parent = s;
    c = nx;
  }
}

int main ()
{
  freopen ("roi.in", "rt", stdin);
  freopen ("roi.out", "wt", stdout);

  scanf ("%d %d %d", &X, &Y, &ntr);
  for (int i = 0; i < ntr; i++)
  {
    scanf ("%d %d", &tr[i].x, &tr[i].y);
    if (tr[i].x == 0 || tr[i].x == X || tr[i].y == 0 || tr[i].y == Y)
      i--, ntr--;
  }
  sort (tr, tr + ntr);

//  for (int i = 0; i < ntr; i++)
//    printf ("%d %d\n", tr[i].x, tr[i].y);
// return 0;

  init_segs ();

  root = salloc ();
  root->y = 0;
  root->x0 = 0;
  root->x1 = X;


  for (int i = 0; i < ntr;)
  {
    cury = tr[i].y;
    seg* nroot = salloc ();
    nroot->y = cury;
    nroot->x0 = 0;
    nroot->x1 = X;
    nroot->child = root;
    root->parent = nroot;
    root = nroot;
    while (i < ntr && tr[i].y == cury)
    {
      cut_simp (root, tr[i].x);
      i++;
    }
  }
  cury = Y;
  check_seg (root);
  printf ("%d\n%d %d", boxs, boxx, boxy);

  return 0;
}
