#include <algorithm>
#include <cassert>
#include <cstdio>
#include <cstring>
#include <utility>

using namespace std;

int _stklen = 50 << 20;

typedef pair<int, int> ii;

#define fi first
#define se second
#define mp make_pair

int x0, y0;
int n, bound, lgbound;
ii tree[(1 << 18) + 10];
int pyramid[19][(1 << 18) + 10];

ii get_range(int x1, int x2)
{
	int l = -1, r = bound;
	while (r - l > 1)
	{
		int m = (l + r) / 2;
		if (tree[m].fi < x1) l = m;
		else r = m;
	}
	ii res;
	res.fi = r;
	l = -1, r = bound;
	while (r - l > 1)
	{
		int m = (l + r) / 2;
		if (tree[m].fi > x2) r = m;
		else l = m;
	}
	res.se = l;
	return res;
}

bool query_is(int x, int l0, int r0, int l, int r, int y1, int y2)
{
	if (l > r0 || r < l0) return false;
	if (l <= l0 && r >= r0)
	{
		int ll = l0 - 1, rr = r0 + 1;
		while (rr - ll > 1)
		{
			int mm = (ll + rr) / 2;
			if (pyramid[x][mm] < y1) ll = mm;
			else rr = mm;		
		}
		int r1 = rr;
		ll = l0 - 1, rr = r0 + 1;
		while (rr - ll > 1)
		{
			int mm = (ll + rr) / 2;
			if (pyramid[x][mm] > y2) rr = mm;
			else ll = mm;
		}
		int r2 = ll;
		return r1 <= r2;
	}
	int m = (l0 + r0) / 2;
	return
		query_is(x - 1, l0, m + 0, l, r, y1, y2) ||
		query_is(x - 1, m + 1, r0, l, r, y1, y2);
}

int query_bound(int x, int l0, int r0, int l, int r, int y1)
{
	if (l > r0 || r < l0) return 0;
	if (l <= l0 && r >= r0)
	{
		int ll = l0 - 1, rr = r0 + 1;
		while (rr - ll > 1)
		{
			int mm = (ll + rr) / 2;
			if (pyramid[x][mm] < y1) ll = mm;
			else rr = mm;		
		}
		if (ll < l0) return 0;
		return pyramid[x][ll];
	}
	int m = (l0 + r0) / 2;
	return max(
		query_bound(x - 1, l0, m + 0, l, r, y1),
		query_bound(x - 1, m + 1, r0, l, r, y1));
}

bool is_something(int x1, int x2, int y1, int y2)
{
	if (x1 > x2) return false;
	if (y1 > y2) return false;
	ii temp = get_range(x1, x2);
	if (temp.fi > temp.se) return false;
	if (temp.fi == -1 || temp.fi == bound) return false;
	if (temp.se == -1 || temp.se == bound) return false;
	return query_is(lgbound, 0, bound - 1, temp.fi, temp.se, y1, y2);
}

bool can_build_here(int cx, int cy, int cz)
{
	if (cx < 0) return false;
	if (cy < 0) return false;
	if (cx + cz > x0) return false;
	if (cy + cz > y0) return false;
	return !is_something(cx + 1, cx + cz - 1, cy + 1, cy + cz - 1);
}

int find_bound(int x1, int x2, int cy)
{
	if (x1 > x2) return 0;
	ii temp = get_range(x1, x2);
	if (temp.fi > temp.se) return 0;
	if (temp.fi == -1 || temp.fi == bound) return 0;
	if (temp.se == -1 || temp.se == bound) return 0;
	return query_bound(lgbound, 0, bound - 1, temp.fi, temp.se, cy);
}

bool can_build(int sz)
{
	if (sz > x0 || sz > y0) return false;
	if (can_build_here(0, 0, sz)) return true;
	for (int i = 0; i < n; i++)
		if (can_build_here(0, tree[i].se, sz))
			return true;
	for (int i = 0; i < n; i++)
	{
		if (tree[i].fi + sz > x0) continue;
		int cy = find_bound(tree[i].fi + 1, tree[i].fi + sz - 1, tree[i].se);
		if (can_build_here(tree[i].fi, cy, sz)) return true;
	}
	return false;
}

ii where(int sz)
{
	ii res = mp(1000000001, 1000000001);
	if (can_build_here(0, 0, sz)) res = min(res, mp(0, 0));
	for (int i = 0; i < n; i++)
		if (can_build_here(0, tree[i].se, sz))
			res = min(res, mp(0, tree[i].se));
	for (int i = 0; i < n; i++)
	{
		if (tree[i].fi + sz > x0) continue;
		int cy = find_bound(tree[i].fi + 1, tree[i].fi + sz - 1, tree[i].se);
		if (can_build_here(tree[i].fi, cy, sz)) res = min(res, mp(tree[i].fi, cy));
	}
	return res;
}

int lg(int x)
{
	int r = 0;
	while (x != 1) x /= 2, r++;
	return r;
}

void build_pyramid(int level, int l, int r)
{
	if (!level)
	{
		pyramid[0][l] = tree[l].se;
		return;
	}
	int m = (l + r) / 2;
	build_pyramid(level - 1, l, m + 0);
	build_pyramid(level - 1, m + 1, r);
	int c1 = l, c2 = m + 1;
	for (int i = l; i <= r; i++)
	{
		if ((c1 <= m) && ((c2 == r + 1) || (pyramid[level - 1][c1] < pyramid[level - 1][c2])))
			pyramid[level][i] = pyramid[level - 1][c1++];
		else pyramid[level][i] = pyramid[level - 1][c2++];
	}
}

int main()
{
	freopen("roi.in", "rt", stdin);
	freopen("roi.out", "wt", stdout);
	scanf("%d%d%d", &x0, &y0, &n);
	for (int i = 0; i < n; i++)
		scanf("%d%d", &tree[i].fi, &tree[i].se);
	sort(tree, tree + n);
	bound = n;
	while (bound & (bound - 1)) bound++;
	for (int i = n; i < bound; i++)
		tree[i] = mp(1000000001, 1000000001);
	lgbound = lg(bound);
	build_pyramid(lgbound, 0, bound - 1);
	int l = 0, r = 1000000001;
	while (r - l > 1)
	{
		int m = (l + r) / 2;
		if (can_build(m)) l = m;
		else r = m;
	}
	fprintf(stderr, "%d\n", l);
	printf("%d\n", l);
	ii ans = where(l);
	printf("%d %d\n", ans.fi, ans.se);
	return 0;
}
