uses math;

//{$DEFINE DEBUG}
{$UNDEF DEBUG}
{$IFDEF DEBUG}
  {$D+,L+,I+,Q+,R+,S+,O-}
{$ELSE}
  {$D-,L-,I-,Q-,R-,S-,O+}
  {$M 1000000,2097152}
{$ENDIF DEBUG}

type coor=record
     x,y:longint;
     end;

type heapelem=record
     n:longint;
     key:extended;
     end;

type heap=record
     a:array[1..100000] of heapelem;
     p:array[1..100000] of longint;
     n:longint;
     end;

type vector=record
     x,y:longint;
     end;

var a:array[1..100000] of coor;
    b,c:array[0..100000] of extended;
    heap1:heap;
    n,p,nn,i:longint;
    v1,v2:vector;
    x:extended;

const eps:extended=1e-8;

function more(const a,b:extended):boolean;
 begin
 more:= a-b>eps;
 end;

function eq(const a,b:extended):boolean;
 begin
 eq:= abs(a-b)<=eps;
 end;

function moreeq(const a,b:extended):boolean;
 begin
 moreeq:= more(a,b) or eq(a,b);
 end;

procedure normalize(var h:heap;i:integer);
var l,r,maxch:extended;
 procedure compare(i,j:longint);
 var buf:heapelem;
  begin
  with h do
   begin
   buf:= a[i];
   a[i]:= a[j];
   a[j]:= buf;
   p[a[i].n]:= i;
   p[a[j].n]:= j;
   end;
  end;

 begin
 with h do
  begin
  while i<=n do
   begin
   if 2*i<=n then
    l:= a[2*i].key
   else
    l:= -1e30;
   if 2*i+1<=n then
    r:= a[2*i+1].key
   else
    r:= -1e30;
   maxch:= max(l,r);
   if moreeq(a[i].key,maxch) then
    break
   else
    if eq(a[2*i].key,maxch) then
     begin
     compare(2*i,i);
     i:= 2*i;
     end
    else
     begin
     compare(2*i+1,i);
     i:=2*i+1;
     end;
   end;
  end;
 end;

procedure heap_del(var h:heap;i:integer);
var j:longint;
 begin
 with h do
  begin
  if p[i]=0 then
   exit;
  j:= p[i];
  p[i]:= 0;
  if n<>j then
   begin
   a[j]:= a[n];
   p[a[j].n]:= j;
   dec(n);
   normalize(h,j);
   end
  else
   dec(n);
  end;
 end;

procedure heap_changekey(var h:heap;i:integer;const newkey:extended);
var j,k:longint;
 procedure compare(i,j:longint);
 var buf:heapelem;
  begin
  with h do
   begin
   buf:= a[i];
   a[i]:= a[j];
   a[j]:= buf;
   p[a[i].n]:= i;
   p[a[j].n]:= j;
   end;
  end;

 begin
 j:= h.p[i];
 if j=0 then exit;
 with h do
  if more(newkey,a[j].key) then
   begin
   a[j].key:= newkey;
   k:= j div 2;
   while k>=1 do
    if more(a[j].key,a[k].key) then
     begin
     compare(j,k);
     j:= k;
     k:= k div 2;
     end
    else
     break;
   end
  else
   begin
   a[j].key:= newkey;
   normalize(h,j);
   end;
 end;

procedure initial;
 begin
 x:= 0.0;
 end;

procedure indata;
var i:longint;
 begin
 {$IFDEF DEBUG}
 assign(input,'input.txt');
 reset(input);
 {$ENDIF DEBUG}
 readln(n);
 for i:= 1 to n do
  with a[i] do
   readln(x,y);
 {$IFDEF DEBUG}
 close(input);
 {$ENDIF DEBUG}
 end;

procedure outdata;
 begin
 {$IFDEF DEBUG}
 assign(output,'output.txt');
 rewrite(output);
 {$ENDIF DEBUG}
 writeln(x:0:5);
 {$IFDEF DEBUG}
 close(output);
 {$ENDIF DEBUG}
 end;

function prev(i:longint):longint;
 begin
 if i=1 then prev:= n
 else prev:= i-1;
 end;

function next(i:longint):longint;
 begin
 if i=n then next:= 1
 else next:= i+1;
 end;

function corner(const v1,v2:vector):extended;
var sc,c:extended;
 begin
 sc:= extended(v1.x)*v2.x+extended(v1.y)*v2.y;
 sc:= sc/sqrt(sqr(v1.x)+sqr(v1.y))/sqrt(sqr(v2.x)+sqr(v2.y));
 if eq(sc,1.0) then sc:= 1.0;
 if eq(sc,-1.0) then sc:= -1.0;
 c:= arccos(sc);
 corner:= c*180.0/pi;
 end;

begin
initial;
indata;
for i:= 1 to n do
 begin
 p:= prev(i);
 nn:= next(i);
 v1.x:= a[p].x-a[i].x;
 v1.y:= a[p].y-a[i].y;
 v2.x:= a[nn].x-a[i].x;
 v2.y:= a[nn].y-a[i].y;
 b[i]:= corner(v1,v2);
 end;

for i:= 1 to n do
 c[i]:= b[i]*b[next(i)];

heap1.n:= n;
with heap1 do
 for i:= 1 to n do
  begin
  p[i]:= i;
  a[i].n:= i;
  a[i].key:= c[i]-c[prev(i)]-c[next(i)];
  end;

for i:= n downto 1 do
 normalize(heap1,i);

while heap1.n>0 do
 begin
 i:= heap1.a[1].n;
 x:= x+c[i];
 heap_del(heap1,i);
 p:= prev(i);
 nn:= next(i);
 c[i]:= 0.0;
 c[p]:= 0.0;
 c[nn]:= 0.0;
 heap_changekey(heap1,p,c[p]-c[prev(p)]-c[next(p)]);
 heap_changekey(heap1,nn,c[nn]-c[prev(nn)]-c[next(nn)]);
 p:= prev(p);
 nn:= next(nn);
 heap_changekey(heap1,p,c[p]-c[prev(p)]-c[next(p)]);
 heap_changekey(heap1,nn,c[nn]-c[prev(nn)]-c[next(nn)]);
 end;

outdata;
end.
