#include <algorithm>
#include <cmath>
#include <cstdio>
#include <cstring>
#include <string>
#include <utility>
#include <vector>

using namespace std;

typedef double dbl;
typedef pair <dbl, dbl> pdd;
typedef vector <int> vi;

#define fi first
#define mp make_pair
#define pb push_back
#define se second

#define eps 1e-10

class point
{
  public:
    dbl x, y;
    point( void )
      { x = y = 0; }
    point( int x, int y )
      { this->x = x, this->y = y; }
    point( dbl x, dbl y )
      { this->x = x, this->y = y; }
    bool operator == ( point b )
    {
      if (x < b.x - eps)  return false;
      if (x > b.x + eps)  return false;
      if (y < b.y - eps)  return false;
      if (y > b.y + eps)  return false;
      return true;
    }
    bool operator != ( point b )
    {
      if (x < b.x - eps)  return true;
      if (x > b.x + eps)  return true;
      if (y < b.y - eps)  return true;
      if (y > b.y + eps)  return true;
      return false;
    }
};

bool operator < ( point a, point b )
{
  if (a.x < b.x - eps)  return true;
  if (a.x > b.x + eps)  return false;
  if (a.y < b.y - eps)  return true;
  if (a.y > b.y + eps)  return false;
  return false;
}

class interval
{
  public:
    point a, b;
    interval( int x1, int y1, int x2, int y2 )
    {
      a = point(x1, y1);
      b = point(x2, y2);
      if (b < a)
        swap(a, b);
    }
    interval( dbl x1, dbl y1, dbl x2, dbl y2 )
    {
      a = point(x1, y1);
      b = point(x2, y2);
      if (b < a)
        swap(a, b);
    }
    interval( point a, point b )
    {
      if (b < a)
        swap(a, b);
      this->a = a, this->b = b;
    }
    bool operator != ( interval x )
    {
      if (a < x.a)  return true;
      if (x.a < a)  return true;
      if (b < x.b)  return true;
      if (x.b < b)  return true;
      return false;
    }
    bool operator > ( point x )
    {
      dbl la = a.y - b.y;
      dbl lb = b.x - a.x;
      dbl lc = -(la * a.x + lb * a.y);
      if (fabs(x.x * la + x.y * lb + lc) > eps)
        return false;
      if (!((x.x >= a.x - eps && x.x <= b.x + eps || x.x >= b.x - eps && x.x <= a.x + eps) &&
            (x.y >= a.y - eps && x.y <= b.y + eps || x.y >= b.y - eps && x.y <= a.y + eps)))
        return false;
      return x.x > a.x + eps && x.x < b.x - eps || x.x > b.x + eps && x.x < a.x - eps ||
             x.y > a.y + eps && x.y < b.y - eps || x.y > b.y + eps && x.y < a.y - eps;
    }
};

bool operator < ( interval x, interval y )
{
  if (x.a < y.a)  return true;
  if (y.a < x.a)  return false;
  if (x.b < y.b)  return true;
  if (y.b < x.b)  return false;
  return false;
}

class setpi
{
  private:
    vector <point> points;
    vector <interval> inter;
  public:
    setpi( void )
    {
      points.clear();
      inter.clear();
    }
    setpi( int x1, int y1, int x2, int y2 )
    {
      points.pb(point(x1, y1));
      points.pb(point(x2, y2));
      if (x1 != x2 || y1 != y2)
        inter.pb(interval(x1, y1, x2, y2));
    }
    void norm( void )
    {
      bool fl = true;
      while (fl)
      {
        fl = false;
        for (int i = 0; i < (int)inter.size() && !fl; i++)
          for (int j = 0; j < i && !fl; j++)
          {
            if (fabs((inter[i].b.x - inter[i].a.x) * (inter[j].b.y - inter[j].a.y) -
                     (inter[j].b.x - inter[j].a.x) * (inter[i].b.y - inter[i].a.y)) > eps)
              continue;
            if (inter[i].a != inter[j].a && inter[i].a != inter[j].b && inter[i].b != inter[j].a && inter[i].b != inter[j].b)
              continue;
            for (int k = 0; k < (int)points.size() && !fl; k++)
              if (inter[i].a == points[k] && inter[j].a == points[k])
                points.erase(points.begin() + k), inter[j] = interval(inter[i].b, inter[j].b),
                inter.erase(inter.begin() + i), fl = true;
              else if (inter[i].a == points[k] && inter[j].b == points[k])
                points.erase(points.begin() + k), inter[j] = interval(inter[i].b, inter[j].a),
                inter.erase(inter.begin() + i), fl = true;
              else if (inter[i].b == points[k] && inter[j].a == points[k])
                points.erase(points.begin() + k), inter[j] = interval(inter[i].a, inter[j].b),
                inter.erase(inter.begin() + i), fl = true;
              else if (inter[i].b == points[k] && inter[j].b == points[k])
                points.erase(points.begin() + k), inter[j] = interval(inter[i].a, inter[j].a),
                inter.erase(inter.begin() + i), fl = true;
          }
      }
    }
    setpi operator ^ ( setpi b )
    {
      setpi ans;
      for (int i = 0; i < (int)points.size(); i++)
      {
        bool fl = true;
        for (int j = 0; j < (int)b.points.size() && fl; j++)
          if (points[i] == b.points[j])
            fl = false;
        for (int j = 0; j < (int)b.inter.size() && fl; j++)
          if (b.inter[j] > points[i])
            fl = false;
        if (fl)
          ans.points.pb(points[i]);
      }
      for (int i = 0; i < (int)b.points.size(); i++)
      {
        bool fl = true;
        for (int j = 0; j < (int)points.size() && fl; j++)
          if (b.points[i] == points[j])
            fl = false;
        for (int j = 0; j < (int)inter.size() && fl; j++)
          if (inter[j] > b.points[i])
            fl = false;
        if (fl)
          ans.points.pb(b.points[i]);
      }
      vector <interval> t1 = inter;
      for (int i = 0;  i < (int)b.points.size(); i++)
      {
        vector <interval> t2;
        for (int j = 0; j < (int)t1.size(); j++)
          if (t1[j] > b.points[i])
            t2.pb(interval(t1[j].a, b.points[i])), t2.pb(interval(b.points[i], t1[j].b));
          else
            t2.pb(t1[j]);
        t1 = t2;
      }
      for (int i = 0; i < (int)b.inter.size(); i++)
      {
        vector <interval> t2;
        for (int j = 0; j < (int)t1.size(); j++)
        {
          dbl l1a = b.inter[i].a.y - b.inter[i].b.y;
          dbl l1b = b.inter[i].b.x - b.inter[i].a.x;
          dbl l1c = -(l1a * b.inter[i].a.x + l1b * b.inter[i].a.y);
          dbl l2a = t1[j].a.y - t1[j].b.y;
          dbl l2b = t1[j].b.x - t1[j].a.x;
          dbl l2c = -(l2a * t1[j].a.x + l2b * t1[j].a.y);
          if (fabs(l1a * l2b - l1b * l2a) <= eps)
            if (fabs(l1b * l2c - l1c * l2b) > eps)
              t2.pb(t1[j]);
            else
            {
              dbl div = l1a * l1a + l1b * l1b;
              dbl t1a = t1[j].a.x * l1b - t1[j].a.y * l1a;
              dbl t1b = t1[j].b.x * l1b - t1[j].b.y * l1a;
              dbl t2a = b.inter[i].a.x * l1b - b.inter[i].a.y * l1a;
              dbl t2b = b.inter[i].b.x * l1b - b.inter[i].b.y * l1a;
              dbl t1min = min(t1a, t1b), t1max = max(t1a, t1b);
              dbl t2min = min(t2a, t2b), t2max = max(t2a, t2b);
              dbl t1min_x = (t1min * l1b - l1a * l1c) / div, t1min_y = -(t1min * l1a + l1b * l1c) / div;
              dbl t1max_x = (t1max * l1b - l1a * l1c) / div, t1max_y = -(t1max * l1a + l1b * l1c) / div;
              dbl t2min_x = (t2min * l1b - l1a * l1c) / div, t2min_y = -(t2min * l1a + l1b * l1c) / div;
              dbl t2max_x = (t2max * l1b - l1a * l1c) / div, t2max_y = -(t2max * l1a + l1b * l1c) / div;
              if (t2min > t1min + eps && t2max < t1max - eps)
                t2.pb(interval(t1min_x, t1min_y, t2min_x, t2min_y)), t2.pb(interval(t2max_x, t2max_y, t1max_x, t1max_y));
              else if (t2min > t1min + eps)
                t2.pb(interval(t1min_x, t1min_y, t2min_x, t2min_y));
              else if (t2max < t1max - eps)
                t2.pb(interval(t2max_x, t2max_y, t1max_x, t1max_y));
            }
          else
          {
            point t = point((l1b * l2c - l1c * l2b) / (l1a * l2b - l1b * l2a),
                            (l2a * l1c - l2c * l1a) / (l1a * l2b - l1b * l2a));
            if (t1[j] > t)
              t2.pb(interval(t1[j].a, t)), t2.pb(interval(t, t1[j].b));
            else
              t2.pb(t1[j]);
          }
        }
        t1 = t2;
      }
      for (int i = 0; i < (int)t1.size(); i++)
        ans.inter.pb(t1[i]);
      t1 = b.inter;
      for (int i = 0;  i < (int)points.size(); i++)
      {
        vector <interval> t2;
        for (int j = 0; j < (int)t1.size(); j++)
          if (t1[j] > points[i])
            t2.pb(interval(t1[j].a, points[i])), t2.pb(interval(points[i], t1[j].b));
          else
            t2.pb(t1[j]);
        t1 = t2;
      }
      for (int i = 0; i < (int)inter.size(); i++)
      {
        vector <interval> t2;
        for (int j = 0; j < (int)t1.size(); j++)
        {
          dbl l1a = inter[i].a.y - inter[i].b.y;
          dbl l1b = inter[i].b.x - inter[i].a.x;
          dbl l1c = -(l1a * inter[i].a.x + l1b * inter[i].a.y);
          dbl l2a = t1[j].a.y - t1[j].b.y;
          dbl l2b = t1[j].b.x - t1[j].a.x;
          dbl l2c = -(l2a * t1[j].a.x + l2b * t1[j].a.y);
          if (fabs(l1a * l2b - l1b * l2a) <= eps)
            if (fabs(l1b * l2c - l1c * l2b) > eps)
              t2.pb(t1[j]);
            else
            {
              dbl div = l1a * l1a + l1b * l1b;
              dbl t1a = t1[j].a.x * l1b - t1[j].a.y * l1a;
              dbl t1b = t1[j].b.x * l1b - t1[j].b.y * l1a;
              dbl t2a = inter[i].a.x * l1b - inter[i].a.y * l1a;
              dbl t2b = inter[i].b.x * l1b - inter[i].b.y * l1a;
              dbl t1min = min(t1a, t1b), t1max = max(t1a, t1b);
              dbl t2min = min(t2a, t2b), t2max = max(t2a, t2b);
              dbl t1min_x = (t1min * l1b - l1a * l1c) / div, t1min_y = -(t1min * l1a + l1b * l1c) / div;
              dbl t1max_x = (t1max * l1b - l1a * l1c) / div, t1max_y = -(t1max * l1a + l1b * l1c) / div;
              dbl t2min_x = (t2min * l1b - l1a * l1c) / div, t2min_y = -(t2min * l1a + l1b * l1c) / div;
              dbl t2max_x = (t2max * l1b - l1a * l1c) / div, t2max_y = -(t2max * l1a + l1b * l1c) / div;
              if (t2min > t1min + eps && t2max < t1max - eps)
                t2.pb(interval(t1min_x, t1min_y, t2min_x, t2min_y)), t2.pb(interval(t2max_x, t2max_y, t1max_x, t1max_y));
              else if (t2min > t1min + eps)
                t2.pb(interval(t1min_x, t1min_y, t2min_x, t2min_y));
              else if (t2max < t1max - eps)
                t2.pb(interval(t2max_x, t2max_y, t1max_x, t1max_y));
            }
          else
          {
            point t = point((l1b * l2c - l1c * l2b) / (l1a * l2b - l1b * l2a),
                            (l2a * l1c - l2c * l1a) / (l1a * l2b - l1b * l2a));
            if (t1[j] > t)
              t2.pb(interval(t1[j].a, t)), t2.pb(interval(t, t1[j].b));
            else
              t2.pb(t1[j]);
          }
        }
        t1 = t2;
      }
      for (int i = 0; i < (int)t1.size(); i++)
        ans.inter.pb(t1[i]);
      ans.norm();
      return ans;
    }
    setpi operator + ( setpi b )
    {
      setpi ans;
      for (int i = 0; i < (int)b.points.size(); i++)
        ans.points.pb(b.points[i]);
      for (int i = 0; i < (int)b.inter.size(); i++)
        ans.inter.pb(b.inter[i]);
      for (int i = 0; i < (int)points.size(); i++)
      {
        bool fl = true;
        for (int j = 0; j < (int)b.points.size() && fl; j++)
          if (points[i] == b.points[j])
            fl = false;
        for (int j = 0; j < (int)b.inter.size() && fl; j++)
          if (b.inter[j] > points[i])
            fl = false;
        if (fl)
          ans.points.pb(points[i]);
      }
      vector <interval> t1 = inter;
      for (int i = 0;  i < (int)b.points.size(); i++)
      {
        vector <interval> t2;
        for (int j = 0; j < (int)t1.size(); j++)
          if (t1[j] > b.points[i])
            t2.pb(interval(t1[j].a, b.points[i])), t2.pb(interval(b.points[i], t1[j].b));
          else
            t2.pb(t1[j]);
        t1 = t2;
      }
      for (int i = 0; i < (int)b.inter.size(); i++)
      {
        vector <interval> t2;
        for (int j = 0; j < (int)t1.size(); j++)
        {
          dbl l1a = b.inter[i].a.y - b.inter[i].b.y;
          dbl l1b = b.inter[i].b.x - b.inter[i].a.x;
          dbl l1c = -(l1a * b.inter[i].a.x + l1b * b.inter[i].a.y);
          dbl l2a = t1[j].a.y - t1[j].b.y;
          dbl l2b = t1[j].b.x - t1[j].a.x;
          dbl l2c = -(l2a * t1[j].a.x + l2b * t1[j].a.y);
          if (fabs(l1a * l2b - l1b * l2a) <= eps)
            if (fabs(l1b * l2c - l1c * l2b) > eps)
              t2.pb(t1[j]);
            else
            {
              dbl div = l1a * l1a + l1b * l1b;
              dbl t1a = t1[j].a.x * l1b - t1[j].a.y * l1a;
              dbl t1b = t1[j].b.x * l1b - t1[j].b.y * l1a;
              dbl t2a = b.inter[i].a.x * l1b - b.inter[i].a.y * l1a;
              dbl t2b = b.inter[i].b.x * l1b - b.inter[i].b.y * l1a;
              dbl t1min = min(t1a, t1b), t1max = max(t1a, t1b);
              dbl t2min = min(t2a, t2b), t2max = max(t2a, t2b);
              dbl t1min_x = (t1min * l1b - l1a * l1c) / div, t1min_y = -(t1min * l1a + l1b * l1c) / div;
              dbl t1max_x = (t1max * l1b - l1a * l1c) / div, t1max_y = -(t1max * l1a + l1b * l1c) / div;
              dbl t2min_x = (t2min * l1b - l1a * l1c) / div, t2min_y = -(t2min * l1a + l1b * l1c) / div;
              dbl t2max_x = (t2max * l1b - l1a * l1c) / div, t2max_y = -(t2max * l1a + l1b * l1c) / div;
              if (t2min > t1min + eps && t2max < t1max - eps)
                t2.pb(interval(t1min_x, t1min_y, t2min_x, t2min_y)), t2.pb(interval(t2max_x, t2max_y, t1max_x, t1max_y));
              else if (t2min > t1min + eps)
                t2.pb(interval(t1min_x, t1min_y, t2min_x, t2min_y));
              else if (t2max < t1max - eps)
                t2.pb(interval(t2max_x, t2max_y, t1max_x, t1max_y));
            }
          else
          {
            point t = point((l1b * l2c - l1c * l2b) / (l1a * l2b - l1b * l2a),
                            (l2a * l1c - l2c * l1a) / (l1a * l2b - l1b * l2a));
            if (t1[j] > t)
              t2.pb(interval(t1[j].a, t)), t2.pb(interval(t, t1[j].b));
            else
              t2.pb(t1[j]);
          }
        }
        t1 = t2;
      }
      for (int i = 0; i < (int)t1.size(); i++)
        ans.inter.pb(t1[i]);
      ans.norm();
      return ans;
    }
    setpi operator * ( setpi b )
    {
      setpi ans;
      for (int i = 0; i < (int)points.size(); i++)
      {
        bool fl = true;
        for (int j = 0; j < (int)b.points.size() && fl; j++)
          if (points[i] == b.points[j])
            fl = false;
        for (int j = 0; j < (int)b.inter.size() && fl; j++)
          if (b.inter[j] > points[i])
            fl = false;
        if (!fl)
          ans.points.pb(points[i]);
      }
      vector <interval> t1 = inter;
      for (int i = 0;  i < (int)b.points.size(); i++)
        for (int j = 0; j < (int)t1.size(); j++)
          if (t1[j] > b.points[i])
            ans.points.pb(b.points[i]);
      for (int i = 0; i < (int)b.inter.size(); i++)
        for (int j = 0; j < (int)t1.size(); j++)
        {
          dbl l1a = b.inter[i].a.y - b.inter[i].b.y;
          dbl l1b = b.inter[i].b.x - b.inter[i].a.x;
          dbl l1c = -(l1a * b.inter[i].a.x + l1b * b.inter[i].a.y);
          dbl l2a = t1[j].a.y - t1[j].b.y;
          dbl l2b = t1[j].b.x - t1[j].a.x;
          dbl l2c = -(l2a * t1[j].a.x + l2b * t1[j].a.y);
          if (fabs(l1a * l2b - l1b * l2a) > eps)
          {
            point t = point((l1b * l2c - l1c * l2b) / (l1a * l2b - l1b * l2a),
                            (l2a * l1c - l2c * l1a) / (l1a * l2b - l1b * l2a));
            if (t1[j] > t)
              ans.points.pb(t);
          }
          else if (fabs(l1b * l2c - l1c * l2b) <= eps)
          {
            dbl div = l1a * l1a + l1b * l1b;
            dbl t1a = t1[j].a.x * l1b - t1[j].a.y * l1a;
            dbl t1b = t1[j].b.x * l1b - t1[j].b.y * l1a;
            dbl t2a = b.inter[i].a.x * l1b - b.inter[i].a.y * l1a;
            dbl t2b = b.inter[i].b.x * l1b - b.inter[i].b.y * l1a;
            dbl t1min = min(t1a, t1b), t1max = max(t1a, t1b);
            dbl t2min = min(t2a, t2b), t2max = max(t2a, t2b);
            dbl tmin = max(t1min, t2min), tmax = min(t1max, t2max);
            dbl tmin_x = (tmin * l1b - l1a * l1c) / div, tmin_y = -(tmin * l1a + l1b * l1c) / div;
            dbl tmax_x = (tmax * l1b - l1a * l1c) / div, tmax_y = -(tmax * l1a + l1b * l1c) / div;
            if (tmin < tmax - eps)
              ans.inter.pb(interval(tmin_x, tmin_y, tmax_x, tmax_y));
          }
        }
      ans.norm();
      return ans;
    }
    bool operator == ( setpi b )
    {
      sort(points.begin(), points.end());
      sort(b.points.begin(), b.points.end());
      sort(inter.begin(), inter.end());
      sort(b.inter.begin(), b.inter.end());
      if (points.size() != b.points.size() || inter.size() != b.inter.size())
        return false;
      for (int i = 0; i < (int)points.size(); i++)
        if (points[i] != b.points[i])
          return false;
      for (int i = 0; i < (int)inter.size(); i++)
        if (inter[i] != b.inter[i])
          return false;
      return true;
    }
};

#define maxl 30

setpi base[26];
char s[maxl];

setpi parse( string s )
{
//  fprintf(stderr, "parse(s = \"%s\")\n", s.c_str());
  vi cnt(s.size(), 0);
  for (int i = 0, t = 0; i < (int)s.length(); i++)
  {
    if (s[i] == '(')  t++;
    cnt[i] = t;
    if (s[i] == ')')  t--;
  }
  for (int i = 0; i < (int)s.length(); i++)
    if (s[i] == '^' && cnt[i] == 0)
      return parse(s.substr(0, i)) ^ parse(s.substr(i + 1, s.length() - i - 1));
  for (int i = 0; i < (int)s.length(); i++)
    if (s[i] == '+' && cnt[i] == 0)
      return parse(s.substr(0, i)) + parse(s.substr(i + 1, s.length() - i - 1));
  for (int i = 0; i < (int)s.length(); i++)
    if (s[i] == '&' && cnt[i] == 0)
      return parse(s.substr(0, i)) * parse(s.substr(i + 1, s.length() - i - 1));
  if (s[0] == '(' && s[s.length() - 1] == ')')
    return parse(s.substr(1, s.length() - 2));
  if (s.length() == 1)
    return base[s[0] - 'A'];
  fprintf(stderr, "shit happens\n");
  return setpi();
}

int main( void )
{
  char c;
  int x1, x2, y1, y2;

  while (scanf(" %c", &c) == 1 && c != '-')
    scanf("%d%d%d%d", &x1, &y1, &x2, &y2), base[c - 'A'] = setpi(x1, y1, x2, y2);

  gets(s);
  while (gets(s) && strcmp(s, ""))
  {
    string s1 = "", s2 = "" ;
    for (int i = 0, t = 0; s[i]; i++)
      if (s[i] == '=')
        t++;
      else if (t == 0)
        s1 += s[i];
      else
        s2 += s[i];
    setpi a = parse(s1);
    setpi b = parse(s2);
    printf("%s\n", a == b ? "da" : "ne");
  }

  return 0;
}
