{$MODE DELPHI}
{$M 60000000,60000000}
{$N+,O-,Q+,R+,S+}
uses
    math;
const
    NMAX = 1001;
    EPS = 1E-4;
type
    int = longint;
    real = extended;
    mass = record
        inf: int;
        v: boolean;
        x1, y1, x2, y2: array [1..NMAX] of real;
    end;
var
    con: array ['A'..'Z'] of mass;
    p: array [1..NMAX] of real;
    o: array [1..NMAX] of int;
    s: string;
    l: int;

procedure swap_int(var a, b: int);
var
    c: int;
begin
    c := a;
    a := b;
    b := c;
end;

procedure swap_real(var a, b: real);
var
    c: real;
begin
    c := a;
    a := b;
    b := c;
end;

procedure qsort(l, r: int);
var
    i, j, xx: int;
    x: real;
begin
    i := l;
    j := r;
    x := p[(l + r) div 2];
    xx := o[(l + r) div 2];
    while i <= j do begin
        while (p[i] > x + EPS) or ((abs(p[i] - x) < EPS) and (o[i] < xx)) do
            inc(i);
        while (p[j] < x - EPS) or ((abs(p[j] - x) < EPS) and (o[j] > xx)) do
            dec(j);
        if i <= j then begin
            swap_int(o[i], o[j]);
            swap_real(p[i], p[j]);
            inc(i);
            dec(j);
        end;
    end;
    if i < r then qsort(i, r);
    if l < j then qsort(l, j);
end;

function cross(x1, y1, x2, y2: real; a: mass): mass;
var
    m: int;

function get(x, y: real): real;
begin
    if abs(x1 - x2) > EPS then
        result := (x - x2) / (x1 - x2)
    else
        if abs(y1 - y2) > EPS then
            result := (y - y2) / (y1 - y2)
        else
            result := 1;
end;

function prin(x, y, x1, y1, x2, y2: real): boolean;
begin
    if x1 > x2 then swap_real(x1, x2);
    if y1 > y2 then swap_real(y1, y2);
    if (x > x1 - EPS) and (x < x2 + EPS) and (y > y1 - EPS) and (y < y2 + EPS) then
        result := true
    else
        result := false;
end;

procedure cross2(x3, y3, x4, y4: real);
var
    a1, a2, b1, b2, c1, c2, x, y: real;

procedure proc;
var
    l, r: real;
begin
    r := -1;
    l := 2;
    if prin(x1, y1, x3, y3, x4, y4) then begin
        l := min(l, get(x1, y1));
        r := max(r, get(x1, y1));
    end;
    if prin(x2, y2, x3, y3, x4, y4) then begin
        l := min(l, get(x2, y2));
        r := max(r, get(x2, y2));
    end;
    if prin(x3, y3, x1, y1, x2, y2) then begin
        l := min(l, get(x3, y3));
        r := max(r, get(x3, y3));
    end;
    if prin(x4, y4, x1, y1, x2, y2) then begin
        l := min(l, get(x4, y4));
        r := max(r, get(x4, y4));
    end;

    if r < 0 then exit;
    inc(m);
    o[m] := 0;
    p[m] := r;
    inc(m);
    o[m] := 1;
    p[m] := l;
end;

begin
    a1 := y2 - y1;
    b1 := x1 - x2;
    c1 := x2 * y1 - x1 * y2;
    a2 := y4 - y3;
    b2 := x3 - x4;
    c2 := x4 * y3 - x3 * y4;
    if abs(a1 * b2 - b1 * a2) < EPS then begin
        if abs(a1 * c2 - c1 * a2) < EPS then proc;
        exit;
    end;
    x := (c2 * b1 - c1 * b2) / (a1 * b2 - a2 * b1);
    y := (c1 * a2 - c2 * a1) / (a1 * b2 - a2 * b1);
    if prin(x, y, x1, y1, x2, y2) and prin(x, y, x3, y3, x4, y4) then begin
        inc(m);
        o[m] := 0;
        p[m] := get(x, y);
        inc(m);
        o[m] := 1;
        p[m] := get(x, y);
    end;
end;

var
    i, now: int;
    last: real;
begin
    m := 0;
    for i := 1 to a.inf do
        cross2(a.x1[i], a.y1[i], a.x2[i], a.y2[i]);
    if m > 1 then qsort(1, m);
    result.inf := 0;
    result.v := false;
    now := 0;
    last := 0;
    for i := 1 to m do
        if o[i] = 0 then begin
            if now = 0 then last := p[i];
            inc(now);
        end
        else begin
            dec(now);
            if now = 0 then begin
                inc(result.inf);
                result.x1[result.inf] := (x1 * last + (1 - last) * x2);
                result.y1[result.inf] := (y1 * last + (1 - last) * y2);
                result.x2[result.inf] := (x1 * p[i] + (1 - p[i]) * x2);
                result.y2[result.inf] := (y1 * p[i] + (1 - p[i]) * y2);
            end;
        end;
end;

function eq(a, b: mass): boolean;
var
    i: int;
    x1, y1, x2, y2: real;
    c: mass;
begin
    result := false;
    if a.v <> b.v then exit;
    for i := 1 to a.inf do begin
        c := cross(a.x1[i], a.y1[i], a.x2[i], a.y2[i], b);
        if (c.inf = 0) or (c.inf > 1) or (abs(c.x1[1] - a.x1[i]) > EPS)
            or (abs(c.y1[1] - a.y1[i]) > EPS) or (abs(c.x2[1] - a.x2[i]) > EPS)
            or (abs(c.y2[1] - a.y2[i]) > EPS) then exit;
    end;
    for i := 1 to b.inf do begin
        c := cross(b.x1[i], b.y1[i], b.x2[i], b.y2[i], a);
        if (c.inf = 0) or (c.inf > 1) or (abs(c.x1[1] - b.x1[i]) > EPS)
            or (abs(c.y1[1] - b.y1[i]) > EPS) or (abs(c.x2[1] - b.x2[i]) > EPS)
            or (abs(c.y2[1] - b.y2[i]) > EPS) then exit;
    end;
    result := true;
end;

procedure concat(var a: mass; b: mass);
var
    i: int;
begin
    if b.v then a.v := true;
    for i := 1 to b.inf do begin
        inc(a.inf);
        a.x1[a.inf] := b.x1[i];
        a.y1[a.inf] := b.y1[i];
        a.x2[a.inf] := b.x2[i];
        a.y2[a.inf] := b.y2[i];
    end;
end;

function make_fird(a, b: mass): mass;
var
    i: int;
    x1, y1, x2, y2: real;
begin
    result.inf := 0;
    result.v := false;
    for i := 1 to a.inf do
        concat(result, cross(a.x1[i], a.y1[i], a.x2[i], a.y2[i], b));
end;

function make_second(a, b: mass): mass;
var
    i: int;
begin
    result := b;
    result.v := false;
    for i := 1 to a.inf do begin
        inc(result.inf);
        result.x1[result.inf] := a.x1[i];
        result.y1[result.inf] := a.y1[i];
        result.x2[result.inf] := a.x2[i];
        result.y2[result.inf] := a.y2[i];
        if a.v then result.v := true;
    end;
end;

function make_first(a, b: mass): mass;
var
    c, d: mass;
begin
    result := make_second(a, b);
    d := make_fird(a, b);
    if d.inf > 0 then
        result.v := true;
end;

function first: mass; forward;

function doit: mass;
begin
    if s[l] in ['A'..'Z'] then begin
        result := con[s[l]];
        inc(l);
        exit;
    end;
    inc(l);
    result := first;
    inc(l);
end;

function fird: mass;
begin
    result := doit;
    while s[l] = '&' do begin
        inc(l);
        result := make_fird(result, doit);
    end;
end;

function second: mass;
begin
    result := fird;
    while s[l] = '+' do begin
        inc(l);
        result := make_second(result, fird);
    end;
end;

function first: mass;
begin
    result := second;
    while s[l] = '^' do begin
        inc(l);
        result := make_first(result, second);
    end;
end;

procedure make;
var
    i, n: int;
    ss: string;
    zn1, zn2: mass;

begin
    readln(ss);
    n := length(ss);
    for i := 1 to n do
        if ss[i] = '=' then begin
            s := copy(ss, 1, i - 1) + '@';
            l := 1;
            zn1 := first;

            s := copy(ss, i + 1, n - i) + '@';
            l := 1;
            zn2 := first;
            if eq(zn1, zn2) then
                writeln('da')
            else
                writeln('ne');
        end;
    writeln(s[1-346]);
end;

var
    ch: char;

begin
{    assign(input, 'input.txt');
    reset(input);
    assign(output, 'output.txt');
    rewrite(output);}

    read(ch);
    while ord(ch) <= 32 do
        read(ch);
    while ch <> '-' do begin
        read(con[ch].x1[1], con[ch].y1[1], con[ch].x2[1], con[ch].y2[1]);
        con[ch].inf := 1;
        read(ch);
        while ord(ch) <= 32 do
            read(ch);
    end;
    readln;
    while not seekeof do
        make;
end.