#include <cmath>
#include <cstdio>
#include <cstring>
#include <vector>

using namespace std;

int _stklen = 50 << 20;

#define EPS 1e-10
#define INF 1e+10

struct Edge
{
	int a, b;
	double w;
	Edge(int _a, int _b, double _w): a(_a), b(_b), w(_w) {}
};

int n, m, s, t, hl;
vector<Edge> e[3000];
double alpha;
vector<double> ws;
double d[3000];
int heap[3000], hpos[3000], prev[3000];
double sk;
vector<int> how;
vector<int> res;

void hswap(int x, int y)
{
	swap(heap[x], heap[y]);
	hpos[heap[x]] = x;
	hpos[heap[y]] = y;
}

void hup(int x)
{
	while (x && d[heap[x]] < d[heap[(x - 1) >> 1]] - EPS)
	{
		hswap(x, (x - 1) >> 1);
		x = (x - 1) >> 1;
	}
}

void hadd(int x)
{
	heap[hl++] = x;
	hpos[x] = hl - 1;
	hup(hl - 1);
}

void hdown(int x)
{
	int l = (x << 1) + 1;
	int r = (x << 1) + 2;
	int b = x;
	if (l < hl && d[heap[l]] < d[heap[b]] - EPS) b = l;
	if (r < hl && d[heap[r]] < d[heap[b]] - EPS) b = r;
	if (b != x)
	{
		hswap(b, x);
		hdown(b);
	}
}

int hext()
{
	int res = heap[0];
	hswap(0, --hl);
	if (hl) hdown(0);
	return res;
}

void relax(const Edge &e)
{
	double temp = e.w - sk;
	if (temp < 0) temp = 0;
	if (d[e.a] + temp < d[e.b] - EPS)
	{
		d[e.b] = d[e.a] + temp;
		prev[e.b] = e.a;
		hup(hpos[e.b]);
	}
}

void restore(int x)
{
	if (x != s) restore(prev[x]);
	how.push_back(x + 1);
}

int main()
{
	/*
	freopen("input.txt", "rt", stdin);
	freopen("output.txt", "wt", stdout);
        */
	scanf("%d%d", &n, &m);
	for (int i = 0; i < m; i++)
	{
		int a, b;
		double w;
		scanf("%d%d%lf", &a, &b, &w);
		a--, b--;
		e[a].push_back(Edge(a, b, w));
		e[b].push_back(Edge(b, a, w));
		ws.push_back(w);
	}
	scanf("%d%d%lf", &s, &t, &alpha);
	s--, t--;
	if (fabs(alpha) < EPS) ws.clear();
	else
	{
		for (int i = 0; i < ws.size(); i++)
			ws[i] /= alpha;
	}
	ws.push_back(0);
	double s0, best = INF;
	for (int i = 0; i < ws.size(); i++)
	{
		sk = alpha * ws[i];
		for (int j = 0; j < n; j++) d[j] = INF;
		d[s] = 0;
		prev[s] = -1;
		hl = 0;
		for (int j = 0; j < n; j++)
			hadd(j);
		for (;;)
		{
			if (!hl) break;
			int cnode = hext();
			if (cnode == t) break;
			for (int j = 0; j < e[cnode].size(); j++)
				relax(e[cnode][j]);
		}
		how.clear();
		restore(t);
		if (d[t] + ws[i] < best)
		{
			s0 = ws[i];
			best = d[t] + ws[i];
			res = how;
		}
	}
	printf("%.15lf %.15lf\n", s0, best);
	for (int i = 0; i < res.size(); i++)
		printf("%d ", res[i]);
	printf("\n");
	return 0;
}
