{$MODE DELPHI}
{$M 64000000,64000000,64000000}
{$R-}

const
 StreamIn='';
 StreamOut='';
 EPS=10e-8;
 NMAX=3100;
 INFVAL=10e10;

type
 integer=longint;
 real=extended;
 IntVect=array [0..NMAX] of integer;
 RealVect=array [0..NMAX] of real;
 IntList=array of integer;
 RealList=array of real;
 Graph1=array [0..NMAX] of IntList;
 Graph2=array [0..NMAX] of RealList;

var n,Vs,Vt:integer;
    Coff:real;
    G1:Graph1;
    Heap,Prev,Pos:IntVect;
    Val:RealVect;
    G2:Graph2;

procedure OpenFiles;
begin
 assign(input,StreamIn);
 assign(output,StreamOut);
 reset(input);
 rewrite(output)
end;

procedure CloseFiles;
begin
 close(input);
 close(output)
end;

procedure AddEdge(v1,v2:integer; w:real);
begin
 inc(G1[v1,0]);
 if G1[v1,0]=length(G1[v1]) then begin
   setlength(G1[v1],2*length(G1[v1]));
   setlength(G2[v1],2*length(G2[v1]))
  end;
 G1[v1,G1[v1,0]]:=v2;
 G2[v1,G1[v1,0]]:=w
end;

procedure LoadData;
var i,m,v1,v2:integer;
    w:real;
begin
 read(n,m);
 for i:=1 to n do begin
   setlength(G1[i],1);
   setlength(G2[i],1);
   G1[i,0]:=0
  end;
 for i:=1 to m do begin
   read(v1,v2,w);
   AddEdge(v1,v2,w);
   AddEdge(v2,v1,w)
  end;
 read(Vs,Vt,Coff)
end;

function Max(a,b:real):real;
begin
 if a>b then Result:=a
 else Result:=b
end;

procedure Mode1(v:integer);
var k:integer;
begin
 if v>1 then
  if Val[Heap[v]]<Val[Heap[v shr 1]] then begin
    k:=Heap[v];
    Heap[v]:=Heap[v shr 1];
    Heap[v shr 1]:=k;
    Pos[Heap[v]]:=v;
    Pos[Heap[v shr 1]]:=v shr 1;
    Mode1(v shr 1)
   end
end;

procedure Mode2(v:integer);
var Larg,k:integer;
begin
 Larg:=v;
 if (2*v)<=Heap[0] then
  if Val[Heap[2*v]]<Val[Heap[Larg]] then Larg:=2*v;
 if (2*v+1)<=Heap[0] then
  if Val[Heap[2*v+1]]<Val[Heap[Larg]] then Larg:=2*v+1;
 if Larg<>v then begin
   k:=Heap[v];
   Heap[v]:=Heap[Larg];
   Heap[Larg]:=k;
   Pos[Heap[v]]:=v;
   Pos[Heap[Larg]]:=Larg;
   Mode2(Larg)
  end
end;

procedure AddElem(v:integer);
begin
 inc(Heap[0]);
 Heap[Heap[0]]:=v;
 Pos[v]:=Heap[0];
 Mode1(Heap[0])
end;

procedure DelElem(v:integer);
begin
 Heap[v]:=Heap[Heap[0]];
 Pos[Heap[v]]:=v;
 dec(Heap[0]);
 Mode1(v);
 Mode2(v)
end;

function Calc(S:real):real;
var i,Vert:integer;
    Temp:real;
begin
 for i:=1 to n do Val[i]:=INFVAL;
 Val[Vs]:=0;
 Heap[0]:=0;
 AddElem(Vs);
 while Heap[0]>0 do begin
   Vert:=Heap[1];
   DelElem(1);
   for i:=1 to G1[Vert,0] do begin
     Temp:=Max(0,G2[Vert,i]-S*Coff);
     if Val[G1[Vert,i]]>(Val[Vert]+Temp) then begin
       if abs(Val[G1[Vert,i]]-INFVAL)>EPS then
        DelElem(Pos[G1[Vert,i]]);
       Val[G1[Vert,i]]:=Val[Vert]+Temp;
       Prev[G1[Vert,i]]:=Vert;
       AddElem(G1[Vert,i])
      end
    end
  end;
 Result:=Val[Vt]+S
end;

procedure SaveWay(t:integer);
begin
 if t<>Vs then SaveWay(Prev[t]);
 write(t,' ')
end;

procedure SolveAndSave;
var l,r,q,v,tmp1,tmp2,tmp3:real;
    t:integer;
begin
 l:=0;
 r:=10e10;
 while (l+EPS)<r do begin
   q:=(l+r)/2;
   tmp1:=Calc(q);
   v:=q+EPS;
   t:=0;
   repeat
    inc(t);
    tmp2:=Calc(v);
    v:=v+EPS
   until (abs(tmp2-tmp1)>EPS/100) or (t>10);
   v:=q-EPS;
   t:=0;
   repeat
    inc(t);
    tmp3:=Calc(v);
    v:=v-EPS/10
   until (abs(tmp3-tmp1)>EPS/100) or (t>10);
   if tmp2<tmp3 then l:=q else r:=q
  end;
 q:=(l+r)/2;
 writeln(q:0:7,' ',Calc(q):0:7);
 SaveWay(Vt)
end;

begin
 OpenFiles;
 LoadData;
 SolveAndSave;
 CloseFiles
end.
