#include <stdio.h>
#include <string.h>
#include <time.h>

#include <algorithm>
using namespace std;

const int maxn = 4096;
const double inf = 1e+12;
const double eps = 1e-8;

double c[maxn];
int n;

class tree
{
public:
  int t[maxn + maxn];
  double lc[maxn];
  void build ();
  void set (int i, double x);
  int get ();
};
void tree::build ()
{
  for (int i = 0; i < n; i++)
    lc[i] = c[i], t[i + maxn] = i;
  lc[n] = inf - 5;
  for (int i = n; i < maxn; i++)
    t[i + maxn] = n;
  for (int i = maxn - 1; i > 0; i--)
    if (c[t[i + i]] < c[t[i + i + 1]])
      t[i] = t[i + i];
    else
      t[i] = t[i + i + 1];
}
void tree::set (int i, double x)
{
  lc[i] = x;
  for (i = (i + maxn) >> 1; i > 0; i >>= 1)
    if (lc[t[i + i]] < lc[t[i + i + 1]])
      t[i] = t[i + i];
    else
      t[i] = t[i + i + 1];
}
int tree::get ()
{
  int l = maxn;
  int r = maxn + n;
  int b = t[l];
  if (lc[t[r]] < lc[t[l]])
    b = t[r];
  while (l < r)
  {
    if (!(l & 1))
      if (lc[t[l + 1]] < lc[b]) 
        b = t[l + 1];
    if (r & 1)
      if (lc[t[r - 1]] < lc[b])
        b = t[r - 1];
    l >>= 1;
    r >>= 1;
  }
  return b;
}
tree tr;

struct edge
{
  int a;
  int b;
  int i;
  edge* next;
};
edge ea[maxn + maxn];
int nea = 0;
edge* ealloc ()
{
  return &ea[nea++];
}

double ep[maxn];
struct pedge
{
  int a, b;
  double c;
  int tm;
};
inline bool operator < (pedge const& a, pedge const& b)
{
  return a.tm < b.tm;
}
pedge op[maxn];

int m;
edge* ve[maxn];
bool vis[maxn];
edge* by[maxn];
int s, t;

int index;

double best;
int bindex;

double coeff;

void path ()
{
  for (int i = 0; i < m; i++)
    if (op[i].c < op[index].c)
      ep[i] = 0;
    else
      ep[i] = op[i].c - op[index].c;
  for (int i = 0; i < n; i++)
    c[i] = inf, vis[i] = false, by[i] = NULL;
  c[s] = 0;
  tr.build ();
  while (!vis[t])
  {
    int v = tr.get ();
    if (v >= n) break;
    vis[v] = true;
    tr.set (v, inf);
    for (edge* e = ve[v]; e; e = e->next)
      if (!vis[e->b] && c[e->b] > c[v] + ep[e->i])
        tr.set (e->b, c[v] + ep[e->i]), c[e->b] = c[v] + ep[e->i], by[e->b] = e;
  }
  double cost = c[t] + op[index].c / coeff;
  if (cost < best)
    best = cost, bindex = index;
}

int _path[maxn];
int len;

int main ()
{
#ifdef _LOCAL_
  freopen ("discount.in", "rt", stdin);
  freopen ("discount.out", "wt", stdout);
#endif

  scanf ("%d %d", &n, &m);
  memset (ve, 0, sizeof ve);
  for (int i = 0; i < m; i++)
  {
    int a, b;
    double x;
    scanf ("%d %d %lf", &a, &b, &x), a--, b--;
    op[i].a = a, op[i].b = b, op[i].c = x, op[i].tm = rand ();
    edge* e1 = ealloc ();
    e1->a = a, e1->b = b, e1->i = i, e1->next = ve[a], ve[a] = e1;
    edge* e2 = ealloc ();
    e2->a = b, e2->b = a, e2->i = i, e2->next = ve[b], ve[b] = e2;
  }                     
  op[m].c = 0;
  scanf ("%d %d %lf", &s, &t, &coeff), s--, t--;
  best = inf;
  index = m;
  bindex = m;
  path ();
  if (coeff > eps)
    for (index = 0; index < m && clock () < (19 * CLOCKS_PER_SEC) / 10; index++)
      path ();
  index = bindex;
  path ();
  len = 0;
  for (int cur = t; cur != s; cur = by[cur]->a)
    _path[len++] = cur;
  if (coeff > eps)
    printf ("%.6lf", op[bindex].c / coeff);
  else
    printf ("0");
  printf (" %.6lf\n%d", best, s + 1);
  for (int i = len - 1; i >= 0; i--)
    printf (" %d", _path[i] + 1);

  return 0;
}
