#include <fstream>
#include <vector>
#include <set>
#include <algorithm>
#include <iostream>
#include <cstdio>
using namespace std;

#define FTC_DEBUG
#undef FTC_DEBUG

const int MAXVER = 110000;
const int MAXEDG = 810000;

class Edge
{
public:
	int id, be, en, clr;
};

int inv[MAXEDG];
int first[MAXVER + 1];
int next[MAXEDG];
Edge edg[MAXEDG];
int n, m;
int was[MAXEDG];
int edgsize;

void Qsort(int be, int en)
{
	int l, r, x, t;
	l = be;
	r = en;
	x = edg[l + rand() % (r - l + 1)].clr;
	while (l < r)
	{
		while (edg[l].clr > x) l++;
		while (edg[r].clr < x) r--;
		if (l <= r)
		{
			t = edg[l].be;
			edg[l].be = edg[r].be;
			edg[r].be = t;
			t = edg[l].en;
			edg[l].en = edg[r].en;
			edg[r].en = t;
			t = edg[l].id;
			edg[l].id = edg[r].id;
			edg[r].id = t;
			t = edg[l].clr;
			edg[l].clr = edg[r].clr;
			edg[r].clr = t;
			l++;
			r--;
		}
	}
	if (be < r) Qsort(be, r);
	if (l < en) Qsort(l, en);
}

void AddEdge(int v1, int v2, int c, int id)
{
	Edge a;
	a.be = v1;
	a.en = v2;
	a.clr = c;
	a.id = id;
	edg[edgsize] = a;
	edgsize++;
}

void Load()
{
	edgsize = 0;
	memset(first, 0xFF, sizeof(first));
	memset(next, 0xFF, sizeof(next));
	scanf("%d%d", &n, &m);
	int i;
	for (i = 0; i < m; i++)
	{
		int v1, v2, c;
		scanf("%d%d%d", &v1, &v2, &c);
		AddEdge(v1, v2, c, i + 1);
		AddEdge(v2, v1, c, i + 1);
	}
	Qsort(0, edgsize - 1);
	memset(was, 0xFF, sizeof(was));
	for (i = 0; i < edgsize; i++)
	{
		next[i] = first[edg[i].be];
		first[edg[i].be] = i;
		if (was[edg[i].id] != -1)
		{
			inv[i] = was[edg[i].id];
			inv[inv[i]] = i;
		}
		else was[edg[i].id] = i;
	}
}

class Color
{
public:
	int id, num;
};

bool operator<(const Color &a, const Color &b)
{
	if (a.num > b.num) return true;
	if (a.num < b.num) return false;
	if (a.id < b.id) return true;
	if (a.id > b.id) return false;
	return false;
}

int clrbeg[MAXEDG];
int match[MAXEDG];
int numclr[MAXEDG];
int someedge1[MAXVER + 1], someedge2[MAXVER + 1];
vector<int> q;
int wasv[MAXVER + 1];
int ne[MAXVER + 1];

void Solve()
{
	int i;
	// mapping of edges to construct sequence of cycles
	// for every vertex we map outcoming edges
	for (i = 1; i <= n; i++)
	{
		set<Color> colors;
		int j;
		int pedg = -2;
		for (j = first[i]; j != -1; j = next[j])
		{
			if ((pedg == -2) || (edg[pedg].clr != edg[j].clr))
			{
				clrbeg[edg[j].clr] = j;
				numclr[edg[j].clr] = 1;
			}
			else numclr[edg[j].clr]++;
			pedg = j;
		}
		pedg = -2;
		for (j = first[i]; j != -1; j = next[j])
		{
			if ((pedg == -2) || (edg[pedg].clr != edg[j].clr))
			{
				Color a;
				a.id = edg[j].clr;
				a.num = numclr[a.id];
				colors.insert(a);
			}
			pedg = j;
		}
		while (colors.size() != 0)
		{
			if (colors.size() == 1)
			{
				Color a = *colors.begin();
				int cpos = clrbeg[a.id];
				while ((cpos != -1) && (edg[cpos].clr == a.id))
				{
					match[cpos] = next[cpos];
					match[next[cpos]] = cpos;
					cpos = next[next[cpos]];
				}
				colors.erase(colors.begin());	
			}
			else
			{
				Color a, b;
				a = *(colors.begin());
				colors.erase(colors.begin());
				b = *(colors.begin());
				colors.erase(colors.begin());
				int cp1, cp2;
				cp1 = clrbeg[a.id];
				cp2 = clrbeg[b.id];
				match[cp1] = cp2;
				match[cp2] = cp1;
				a.num--;
				b.num--;
				clrbeg[a.id] = next[cp1];
				clrbeg[b.id] = next[cp2];
				if (a.num != 0) colors.insert(a);
				if (b.num != 0) colors.insert(b);
			}
		}
	}
	#ifdef FTC_DEBUG
	for (i = 0; i < edgsize; i++)
	{
		cout << i << ": " << edg[i].be << " " << edg[i].en << " " << edg[i].clr << " " << edg[i].id << " " << match[i] << "\n";
	}
	#endif	
	// we need to construct cycles and glue them
	//
	memset(was, 0, sizeof(was));
	memset(wasv, 0, sizeof(wasv));
	memset(someedge1, 0xFF, sizeof(someedge1));
	memset(someedge2, 0xFF, sizeof(someedge2));
	memset(ne, 0, sizeof(ne));
	for (i = 0; i < edgsize; i++)
	{
		ne[edg[i].be]++;
		ne[edg[i].en]++;
	}
	int cver = 1;
	while (ne[cver] == 0) cver++;
	q.clear();
	q.push_back(cver);
	#ifdef FTC_DEBUG
	cout << "Vertex added: " << cver << "\n";
	#endif
	wasv[1] = 1;
	int curcc = 0;
	for (i = 0; i < q.size(); i++)
	{
		int j;
		for (j = first[q[i]]; j != -1; j = next[j])
		{
			if (was[j] != 0) continue;			
			int cure = j;
			int glued = 0;
			#ifdef FTC_DEBUG
			cout << "Finding a cycle:\n";
			#endif
			curcc++;
			while (1)
			{
				int nxt = match[inv[cure]];
				cver = edg[cure].en;
				#ifdef FTC_DEBUG
				cout << cure << " " << nxt << " at vertex " << cver << "\n";
				#endif
				if ((someedge1[cver] != -1) && (glued == 0) && (was[someedge1[cver]] != curcc))
				{
					int nv1, nv2;
					nv1 = nv2 = 0;
					if (edg[someedge1[cver]].clr != edg[inv[cure]].clr) nv1++;
					if (edg[someedge2[cver]].clr != edg[nxt].clr) nv1++;
					if (edg[someedge2[cver]].clr != edg[inv[cure]].clr) nv2++;
					if (edg[someedge1[cver]].clr != edg[nxt].clr) nv2++;
					if (nv1 > nv2)
					{
						match[inv[cure]] = someedge1[cver];
						match[nxt] = someedge2[cver];
						match[someedge1[cver]] = inv[cure];
						match[someedge2[cver]] = nxt;
					}
					else
					{
						match[nxt] = someedge1[cver];
						match[inv[cure]] = someedge2[cver];
						match[someedge2[cver]] = inv[cure];
						match[someedge1[cver]] = nxt;
					}
					glued = 1;
				}
				someedge1[cver] = inv[cure];
				someedge2[cver] = nxt;
				if (wasv[cver] == 0)
				{
					q.push_back(cver);
					#ifdef FTC_DEBUG
					cout << "Vertex added: " << cver << "\n";
					#endif
				}
				wasv[cver] = 1;
				was[cure] = was[inv[cure]] = curcc;
				cure = nxt;
				if (was[cure] == 1) break;
			}
		}
	}
	#ifdef FTC_DEBUG
	cout << "after cycles glueing:\n";
	for (i = 0; i < edg.size(); i++)
	{
		cout << i << ": " << edg[i].be << " " << edg[i].en << " " << edg[i].clr << " " << edg[i].id << " " << match[i] << "\n";
	}
	#endif	
	
	// wow! all!
	memset(was, 0, sizeof(was));
	int cure = 0;
	while (1)
	{
		printf("%d ", edg[cure].id);
		was[cure] = 1;
		was[inv[cure]] = 1;
		cure = match[inv[cure]];
		if (was[cure] == 1) break;
	}
}

int main()
{
//	freopen("stripes.in", "rt", stdin);
//	freopen("stripes.out", "wt", stdout);
	Load();
	Solve();
	return 0;
}
