#include <fstream>
#include <vector>
#include <set>
#include <algorithm>
#include <iostream>
#include <cstdio>
using namespace std;

#define FTC_DEBUG
#undef FTC_DEBUG

const int MAXVER = 110000;
const int MAXEDG = 810000;

class Edge
{
public:
	int id, be, en, clr;
};

bool operator<(const Edge &a, const Edge &b)
{
	if (a.clr < b.clr) return true;
	if (a.clr > b.clr) return false;
	if (a.be < b.be) return true;
	if (a.be > b.be) return false;
	if (a.en < b.en) return true;
	if (a.en > b.en) return false;
	if (a.id < b.id) return true;
	if (a.id > b.id) return false;
	return false;
}

int inv[MAXEDG];
int first[MAXVER + 1];
int next[MAXEDG];
vector<Edge> edg;
int n, m;
int was[MAXEDG];

void AddEdge(int v1, int v2, int c, int id)
{
	Edge a;
	a.be = v1;
	a.en = v2;
	a.clr = c;
	a.id = id;
	edg.push_back(a);
}

void Load()
{
	memset(first, 0xFF, sizeof(first));
	memset(next, 0xFF, sizeof(next));
	scanf("%d%d", &n, &m);
	int i;
	for (i = 0; i < m; i++)
	{
		int v1, v2, c;
		scanf("%d%d%d", &v1, &v2, &c);
		AddEdge(v1, v2, c, i + 1);
		AddEdge(v2, v1, c, i + 1);
	}
	sort(edg.begin(), edg.end());
	memset(was, 0xFF, sizeof(was));
	for (i = 0; i < edg.size(); i++)
	{
		next[i] = first[edg[i].be];
		first[edg[i].be] = i;
		if (was[edg[i].id] != -1)
		{
			inv[i] = was[edg[i].id];
			inv[inv[i]] = i;
		}
		else was[edg[i].id] = i;
	}
}

class Color
{
public:
	int id, num;
};

bool operator<(const Color &a, const Color &b)
{
	if (a.num > b.num) return true;
	if (a.num < b.num) return false;
	if (a.id < b.id) return true;
	if (a.id > b.id) return false;
	return false;
}

int clrbeg[MAXEDG];
int match[MAXEDG];
int numclr[MAXEDG];
int someedge1[MAXVER + 1], someedge2[MAXVER + 1];
vector<int> q;
int wasv[MAXVER + 1];
int ne[MAXVER + 1];
int clrid[MAXEDG];
int clrnum[MAXEDG];

void Qsort(int be, int en)
{
	int l, r, x, t;
	l = be;
	r = en;
	x = clrnum[l + rand() % (r - l + 1)];
	while (l < r)
	{
		while (x < clrnum[l]) l++;
		while (x > clrnum[r]) r--;
		if (l <= r)
		{
			t = clrnum[l];
			clrnum[l] = clrnum[r];
			clrnum[r] = t;
			t = clrid[l];
			clrid[l] = clrid[r];
			clrid[r] = t;
			l++;
			r--;
		}
	}
	if (be < r) Qsort(be, r);
	if (l < en) Qsort(l, en);
}

void Solve()
{
	int i;
	// mapping of edges to construct sequence of cycles
	// for every vertex we map outcoming edges
	for (i = 1; i <= n; i++)
	{
		int colorssize = 0;
		int j;
		int pedg = -2;
		for (j = first[i]; j != -1; j = next[j])
		{
			if ((pedg == -2) || (edg[pedg].clr != edg[j].clr))
			{
				clrbeg[edg[j].clr] = j;
				numclr[edg[j].clr] = 1;
			}
			else numclr[edg[j].clr]++;
			pedg = j;
		}
		pedg = -2;
		for (j = first[i]; j != -1; j = next[j])
		{
			if ((pedg == -2) || (edg[pedg].clr != edg[j].clr))
			{
				clrid[colorssize] = edg[j].clr;
				clrnum[colorssize] = numclr[edg[j].clr];
				colorssize++;
			}
			pedg = j;
		}
		if (colorssize != 0) Qsort(0, colorssize - 1);
		while (colorssize != 0)
		{
			if (colorssize == 1)
			{
				int cid = clrid[0];
				int cpos = clrbeg[cid];
				while ((cpos != -1) && (edg[cpos].clr == cid))
				{
					match[cpos] = next[cpos];
					match[next[cpos]] = cpos;
					cpos = next[next[cpos]];
				}
				clrnum[0] = 0;
			}
			else
			{
				int ca, cb;
				ca = clrid[0];
				cb = clrid[1];
				int cp1, cp2;
				cp1 = clrbeg[ca];
				cp2 = clrbeg[cb];
				match[cp1] = cp2;
				match[cp2] = cp1;
				clrnum[0]--;
				clrnum[1]--;
				clrbeg[ca] = next[cp1];
				clrbeg[cb] = next[cp2];
				//resort
				for (j = 1; (j < colorssize - 1) && (clrnum[j + 1] > clrnum[j]); j++)
				{
					int t = clrid[j + 1];
					clrid[j + 1] = clrid[j];
					clrid[j] = t;
					t = clrnum[j + 1];
					clrnum[j + 1] = clrnum[j];
					clrnum[j] = t;
				}
				for (j = 0; (j < colorssize - 1) && (clrnum[j + 1] > clrnum[j]); j++)
				{
					int t = clrid[j + 1];
					clrid[j + 1] = clrid[j];
					clrid[j] = t;
					t = clrnum[j + 1];
					clrnum[j + 1] = clrnum[j];
					clrnum[j] = t;
				}
			}
			while ((colorssize > 0) && (clrnum[colorssize - 1] == 0)) colorssize--;
		}
	}
	#ifdef FTC_DEBUG
	for (i = 0; i < edg.size(); i++)
	{
		cout << i << ": " << edg[i].be << " " << edg[i].en << " " << edg[i].clr << " " << edg[i].id << " " << match[i] << "\n";
	}
	#endif	
	// we need to construct cycles and glue them
	//
	memset(was, 0, sizeof(was));
	memset(wasv, 0, sizeof(wasv));
	memset(someedge1, 0xFF, sizeof(someedge1));
	memset(someedge2, 0xFF, sizeof(someedge2));
	memset(ne, 0, sizeof(ne));
	for (i = 0; i < edg.size(); i++)
	{
		ne[edg[i].be]++;
		ne[edg[i].en]++;
	}
	int cver = 1;
	while (ne[cver] == 0) cver++;
	q.clear();
	q.push_back(cver);
	#ifdef FTC_DEBUG
	cout << "Vertex added: " << cver << "\n";
	#endif
	wasv[1] = 1;
	int curcc = 0;
	for (i = 0; i < q.size(); i++)
	{
		int j;
		for (j = first[q[i]]; j != -1; j = next[j])
		{
			if (was[j] != 0) continue;			
			int cure = j;
			int glued = 0;
			#ifdef FTC_DEBUG
			cout << "Finding a cycle:\n";
			#endif
			curcc++;
			while (1)
			{
				int nxt = match[inv[cure]];
				cver = edg[cure].en;
				#ifdef FTC_DEBUG
				cout << cure << " " << nxt << " at vertex " << cver << "\n";
				#endif
				if ((someedge1[cver] != -1) && (glued == 0) && (was[someedge1[cver]] != curcc))
				{
					int nv1, nv2;
					nv1 = nv2 = 0;
					if (edg[someedge1[cver]].clr != edg[inv[cure]].clr) nv1++;
					if (edg[someedge2[cver]].clr != edg[nxt].clr) nv1++;
					if (edg[someedge2[cver]].clr != edg[inv[cure]].clr) nv2++;
					if (edg[someedge1[cver]].clr != edg[nxt].clr) nv2++;
					if (nv1 > nv2)
					{
						match[inv[cure]] = someedge1[cver];
						match[nxt] = someedge2[cver];
						match[someedge1[cver]] = inv[cure];
						match[someedge2[cver]] = nxt;
					}
					else
					{
						match[nxt] = someedge1[cver];
						match[inv[cure]] = someedge2[cver];
						match[someedge2[cver]] = inv[cure];
						match[someedge1[cver]] = nxt;
					}
					glued = 1;
				}
				someedge1[cver] = inv[cure];
				someedge2[cver] = nxt;
				if (wasv[cver] == 0)
				{
					q.push_back(cver);
					#ifdef FTC_DEBUG
					cout << "Vertex added: " << cver << "\n";
					#endif
				}
				wasv[cver] = 1;
				was[cure] = was[inv[cure]] = curcc;
				cure = nxt;
				if (was[cure] == 1) break;
			}
		}
	}
	#ifdef FTC_DEBUG
	cout << "after cycles glueing:\n";
	for (i = 0; i < edg.size(); i++)
	{
		cout << i << ": " << edg[i].be << " " << edg[i].en << " " << edg[i].clr << " " << edg[i].id << " " << match[i] << "\n";
	}
	#endif	
	
	// wow! all!
	memset(was, 0, sizeof(was));
	int cure = 0;
	while (1)
	{
		printf("%d ", edg[cure].id);
		was[cure] = 1;
		was[inv[cure]] = 1;
		cure = match[inv[cure]];
		if (was[cure] == 1) break;
	}
}

int main()
{
//	freopen("stripes.in", "rt", stdin);
//	freopen("stripes.out", "wt", stdout);
	Load();
	Solve();
	return 0;
}
