#include <cassert>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include "chains.h"
#include "global.h"
#include "random.h"
#include "types.h"

#define TASKNAME "protein"

#define STAMP "[%016I64X]  "

const int64 MaxStamp = 0x3FFFFF;
const int MaxCut = 2, MaxCut2 = 3;

int64 laststamp, stamp;

bool check (void)
{
 if (res < cur)
 {
  res = cur;
  memmove (xr, x, sizeof (xr));
  memmove (yr, y, sizeof (yr));
  memmove (zr, z, sizeof (zr));
  memmove (dirr, dir, sizeof (dirr));
  printf (STAMP "New maximum found: %d!\n", stamp, res);
  report (stdout);
  return true;
 }
 return false;
}

int score (int k)
{
 int i, j, cur;
 cur = 0;
 for (i = 0; i < k; i++)
  switch (a[i])
  {
   case 0:
    for (j = 0; j < k; j++)
     if (a[j] == 0)
      if (abs (x[i] - x[j]) + abs (y[i] - y[j]) + abs (z[i] - z[j]) == 1)
       cur++;
    break;
   case 1:
    cur += MaxD;
    for (j = 0; j < k; j++)
     if (abs (x[i] - x[j]) + abs (y[i] - y[j]) + abs (z[i] - z[j]) == 1)
      cur--;
    break;
   default: assert (false);
  }
 return cur;
}

void search (int k)
{
 assert (k >= 2);
 if (k == n)
 {
  if (check ()) laststamp = stamp;
  return;
 }
 int64 oldstamp;
 oldstamp = stamp;
 stamp++;
 if (!((stamp - laststamp) & MaxStamp))
 {
  printf (STAMP "Reporting current state. Result %d/%d.\n", stamp, cur, res);
  report (stdout);
 }
 int d, i, xc, yc, zc, delta, t;
 for (d = 0; d < MaxD; d++) if (d != (dir[k - 1] ^ 1))
 {
  xc = x[k - 1] + dx[d];
  yc = y[k - 1] + dy[d];
  zc = z[k - 1] + dz[d];

  delta = a[k] * MaxD;
  for (i = k - 1; i >= 0; i--)
  {
   t = abs (x[i] - xc) + abs (y[i] - yc) + abs (z[i] - zc);
   if (t == 0) break;
   else if (t == 1)
   {
    if (a[k] == 0)
    {
     if (a[i] == 0) delta += 2;
    }
    else delta--;
    if (a[i] == 1) delta--;
   }
  }
  if (i >= 0) continue;

  x[k] = xc;
  y[k] = yc;
  z[k] = zc;
  dir[k] = d;
  cur += delta;
  search (k + 1);
  cur -= delta;

  if (stamp - laststamp > MaxStamp)
  {
   if (rndvalue (MaxCut2) == 0)
    break;
   if (stamp - oldstamp > MaxStamp)
   {
    if (rndvalue (MaxCut) == 0)
     break;
   }
  }
 }
}

void run_simple (void)
{
 int64 step, steps;
 int d, d1, d2, i, k, xc, yc, zc, t, delta;
 steps = 100000000000LL;
 for (step = 0; step < steps; step++)
 {
  k = rndvalue (n);
  if (k == 0)
  {
   d = rndvalue (MaxD);
   if (d == dir[1]) continue;
   d1 = 1;
   d2 = d;
   xc = x[1] - dx[d];
   yc = y[1] - dy[d];
   zc = z[1] - dz[d];
  }
  else if (k == n - 1)
  {
   d = rndvalue (MaxD);
   if (d == dir[k]) continue;
   d1 = d;
   d2 = 1;
   xc = x[k - 1] + dx[d];
   yc = y[k - 1] + dy[d];
   zc = z[k - 1] + dz[d];
  }
  else if (dir[k] != dir[k + 1])
  {
   d1 = dir[k + 1];
   d2 = dir[k];
   xc = x[k - 1] + dx[d1];
   yc = y[k - 1] + dy[d1];
   zc = z[k - 1] + dz[d1];
  }
  else continue;

  delta = 0;
  for (i = 0; i < n; i++) if (i != k)
  {
   t = abs (x[i] - x[k]) + abs (y[i] - y[k]) + abs (z[i] - z[k]);
   if (t == 1)
   {
    if (a[k] == 0)
    {
     if (a[i] == 0) delta -= 2;
    }
    else delta++;
    if (a[i] == 1) delta++;
   }
  }

  for (i = 0; i < n; i++) if (i != k)
  {
   t = abs (x[i] - xc) + abs (y[i] - yc) + abs (z[i] - zc);
   if (t == 0) break;
   else if (t == 1)
   {
    if (a[k] == 0)
    {
     if (a[i] == 0) delta += 2;
    }
    else delta--;
    if (a[i] == 1) delta--;
   }
  }

  if (i == n)
  {
   x[k] = xc;
   y[k] = yc;
   z[k] = zc;
   dir[k] = d1;
   dir[k + 1] = d2;
   cur += delta;
   stamp++;
   if (check ()) laststamp = stamp;
   else if (!((stamp - laststamp) & MaxStamp))
   {
    printf (STAMP "Reporting current state. Result %d/%d.\n",
     stamp, cur, res);
    report (stdout);
   }
  }
 }
}

typedef bool (* fun) (int delta, real temp);

bool fun_anneal (int delta, real temp)
{
 return (rndvalue () >= exp (delta * temp));
}

void local_change (real temp, fun accept_fun)
{
 int d, d1, d2, i, k, xc, yc, zc, t, delta;
 k = rndvalue (n);
 if (k == 0)
 {
  d = rndvalue (MaxD);
  if (d == dir[1]) return;
  d1 = 1;
  d2 = d;
  xc = x[1] - dx[d];
  yc = y[1] - dy[d];
  zc = z[1] - dz[d];
 }
 else if (k == n - 1)
 {
  d = rndvalue (MaxD);
  if (d == dir[k]) return;
  d1 = d;
  d2 = 1;
  xc = x[k - 1] + dx[d];
  yc = y[k - 1] + dy[d];
  zc = z[k - 1] + dz[d];
 }
 else if (dir[k] != dir[k + 1])
 {
  d1 = dir[k + 1];
  d2 = dir[k];
  xc = x[k - 1] + dx[d1];
  yc = y[k - 1] + dy[d1];
  zc = z[k - 1] + dz[d1];
 }
 else return;

 delta = 0;
 for (i = 0; i < n; i++) if (i != k)
 {
  t = abs (x[i] - x[k]) + abs (y[i] - y[k]) + abs (z[i] - z[k]);
  if (t == 1)
  {
   if (a[k] == 0)
   {
    if (a[i] == 0) delta -= 2;
   }
   else delta++;
   if (a[i] == 1) delta++;
  }
 }

 for (i = 0; i < n; i++) if (i != k)
 {
  t = abs (x[i] - xc) + abs (y[i] - yc) + abs (z[i] - zc);
  if (t == 0) break;
  else if (t == 1)
  {
   if (a[k] == 0)
   {
    if (a[i] == 0) delta += 2;
   }
   else delta--;
   if (a[i] == 1) delta--;
  }
 }

 if (i == n)
 {
  if (accept_fun (delta, temp)) return;
  x[k] = xc;
  y[k] = yc;
  z[k] = zc;
  dir[k] = d1;
  dir[k + 1] = d2;
  cur += delta;
  stamp++;
  if (check ()) laststamp = stamp;
  else if (!((stamp - laststamp) & MaxStamp))
  {
   printf (STAMP "Reporting current state. Result %d/%d.\n",
    stamp, cur, res);
   report (stdout);
  }
 }
}

void run_exp (int64 Steps, int64 StepDelta)
{
 const char NAME [MaxBuf] = "run_exp";
 int64 step, old_step;
 printf ("Started %s.\n", NAME);
 printf (" args: (" INT64 ", " INT64 ").\n", Steps, StepDelta);
 for (old_step = step = 0; step < Steps; step++)
 {
  local_change (1.0, fun_anneal);
  if (step >= old_step + StepDelta)
  {
   printf (">%s: step = " INT64 "\n", NAME, step);
   fflush (stdout);
   old_step = step;
  }
 }
 printf ("Done %s.\n", NAME);
}

void run_anneal (real TempMin, real TempMax, real TempMult, real TempDelta)
{
 const char NAME [MaxBuf] = "run_anneal";
 real temp, old_temp;
 printf ("Started %s.\n", NAME);
 printf (" args: (" REAL ", " REAL ", " REAL ", " REAL ").\n",
  TempMin, TempMax, TempMult, TempDelta);
 for (old_temp = temp = TempMin; temp <= TempMax; temp *= TempMult)
 {
  local_change (temp, fun_anneal);
  if (temp > old_temp * TempDelta * (1.0 - eps))
  {
   printf (">%s: temp = " REAL "\n", NAME, temp);
   fflush (stdout);
   old_temp = temp;
  }
 }
 printf ("Done %s.\n", NAME);
}

void run_anneal_add (real TempMin, real TempMax, real TempAdd, real TempDelta)
{
 const char NAME [MaxBuf] = "run_anneal_add";
 real temp, old_temp;
 printf ("Started %s.\n", NAME);
 printf (" args: (" REAL ", " REAL ", " REAL ", " REAL ").\n",
  TempMin, TempMax, TempAdd, TempDelta);
 for (old_temp = temp = TempMin; temp <= TempMax; temp += TempAdd)
 {
  local_change (temp, fun_anneal);
  if (temp > old_temp + TempDelta - eps)
  {
   printf (">%s: temp = " REAL "\n", NAME, temp);
   fflush (stdout);
   old_temp = temp;
  }
 }
 printf ("Done %s.\n", NAME);
}

int main (void)
{
 FILE * f;
 char buf [MaxBuf];
 int test;
 int i, k;
 freopen ("dat/" TASKNAME ".in", "rt", stdin);
 init_random ();
 test = 2;
 while (scanf (" %s", s) != EOF)
 {
  n = strlen (s);
  for (i = 0; i < n; i++)
   a[i] = s[i] - '0';
  res = 0;
  for (k = 0; k < n; k++)
  {
   for (i = 0; i < n; i++)
   {
    x[i] = i;
    y[i] = 0;
    z[i] = 0;
    dir[i] = 1;
   }
   cur = score (n);
   check ();
   laststamp = stamp = 0;
   run_anneal_add (0.0001, 2.0, 0.000000005, 0.2);
  }
/*
  run_exp (10000000, 1000000);
  run_anneal (0.01, 10.0, 1.0000001, 1.1);
  run_anneal_add (0.0001, 2.0, 0.00000001, 0.01);
*/

  test++;
  sprintf (buf, "dat/%02d", test);
  f = fopen (buf, "wt");
  fprintf (f, "%s\n", s);
  fclose (f);
  sprintf (buf, "dat/%02d.a", test);
  f = fopen (buf, "wt");
  fprintf (f, "%d\n", res);
  memmove (x, xr, sizeof (x));
  memmove (y, yr, sizeof (y));
  memmove (z, zr, sizeof (z));
  memmove (dir, dirr, sizeof (dir));
  canonize ();
  report (f);
  fclose (f);
 }
 return 0;
}
